/*------------------------------------------------------------------------------
 * MDK Middleware - Component ::Network
 * Copyright (c) 2004-2016 ARM Germany GmbH. All rights reserved.
 *------------------------------------------------------------------------------
 * Name:    net_evr.h
 * Purpose: Network definitions for Event Recorder
 * Rev.:    V7.3.0
 *----------------------------------------------------------------------------*/

#ifdef DEBUG_EVR
#include "EventRecorder.h"

#ifndef __STATIC_INLINE
  #define __STATIC_INLINE           static __forceinline
#endif


// Network components ----------------------------------------------------------
#define EvtNetSYS           0xC0        ///< System Core
#define EvtNetMEM           0xC1        ///< Memory Management
#define EvtNetETH           0xC2        ///< ETH Interface
#define EvtNetPPP           0xC3        ///< PPP Interface
#define EvtNetSLIP          0xC4        ///< SLIP Interface
#define EvtNetLOOP          0xC5        ///< Loopback Interface

#define EvtNetIP4           0xC6        ///< IPv4 Core
#define EvtNetICMP          0xC7        ///< ICMP Control
#define EvtNetIGMP          0xC8        ///< IGMP Group Management
#define EvtNetNBNS          0xC9        ///< NetBIOS Name Service Client
#define EvtNetDHCP          0xCA        ///< Dynamic Host Configuration Client
#define EvtNetARP           0xCB        ///< Ethernet Address Resolution

#define EvtNetIP6           0xCC        ///< IPv6 Core
#define EvtNetICMP6         0xCD        ///< ICMPv6 Control
#define EvtNetDHCP6         0xCE        ///< Dynamic Host Configuration Client for IPv6
#define EvtNetNDP           0xCF        ///< !Neighbor Discovery for IPv6

#define EvtNetUDP           0xD0        ///< Socket UDP
#define EvtNetTCP           0xD1        ///< Socket TCP
#define EvtNetBSD           0xD2        ///< Socket BSD

#define EvtNetHTTP          0xD3        ///< !Web Server
#define EvtNetFTPs          0xD4        ///< !File Transfer Server
#define EvtNetFTPc          0xD5        ///< !File Transfer Client
#define EvtNetTeln          0xD6        ///< !Telnet Server
#define EvtNetTFTPs         0xD7        ///< !Trivial File Transfer Server
#define EvtNetTFTPc         0xD8        ///< !Trivial File Transfer Client
#define EvtNetSMTP          0xD9        ///< !Simple Mail Transfer Client
#define EvtNetDNS           0xDA        ///< !Domain Name Service Client
#define EvtNetSNMP          0xDB        ///< !Simple Network Management Agent
#define EvtNetSNTP          0xDC        ///< !Simple Network Time Client
#endif


// NetSYS event identifiers ----------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetSYS_InitSystem            EventID (EventLevelOp,    EvtNetSYS, 0)
#define EvtNetSYS_ThreadCreateFailed    EventID (EventLevelError, EvtNetSYS, 1)
#define EvtNetSYS_TimerCreateFailed     EventID (EventLevelError, EvtNetSYS, 2)
#define EvtNetSYS_InitComplete          EventID (EventLevelOp,    EvtNetSYS, 3)
#define EvtNetSYS_SetHostName           EventID (EventLevelAPI,   EvtNetSYS, 4)
#endif

/**
  \brief  Event on \ref netInitialize start (Op)
  \param  lib_version   encoded library version BCD (MMmmbbbb)
                         - MM:   Major
                         - mm:   minor
                         - bbbb: build
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSYS_InitSystem(uint32_t lib_version) {
    uint16_t version = (uint16_t)(lib_version >> 16);
    uint16_t build   = (uint16_t)(lib_version);
    EventRecord2 (EvtNetSYS_InitSystem, version, build);
  }
#else
  #define EvrNetSYS_InitSystem(lib_version)
#endif

/**
  \brief  Event on \ref netInitialize thread create failed (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSYS_ThreadCreateFailed(void) {
    EventRecord2 (EvtNetSYS_ThreadCreateFailed, 0, 0);
  }
#else
  #define EvrNetSYS_ThreadCreateFailed()
#endif

/**
  \brief  Event on \ref netInitialize timer create failed (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSYS_TimerCreateFailed(void) {
    EventRecord2 (EvtNetSYS_TimerCreateFailed, 0, 0);
  }
#else
  #define EvrNetSYS_TimerCreateFailed()
#endif

/**
  \brief  Event on \ref netInitialize complete (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSYS_InitComplete(void) {
    EventRecord2 (EvtNetSYS_InitComplete, 0, 0);
  }
#else
  #define EvrNetSYS_InitComplete()
#endif

/**
  \brief  Event on \ref netSYS_SetHostName entry (API)
  \param  name          pointer to host name string
  \param  length        length of host name string
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSYS_SetHostName(const char *name, uint32_t length) {
    EventRecordData (EvtNetSYS_SetHostName, name, length);
  }
#else
  #define EvrNetSYS_SetHostName(name, length)
#endif



// NetMEM event identifiers ----------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetMEM_InitMemory                EventID (EventLevelOp,    EvtNetMEM,  0)
#define EvtNetMEM_AllocMemory               EventID (EventLevelOp,    EvtNetMEM,  1)
#define EvtNetMEM_AllocLimitExceeded        EventID (EventLevelOp,    EvtNetMEM,  2)
#define EvtNetMEM_AllocOutOfMemory          EventID (EventLevelError, EvtNetMEM,  3)
#define EvtNetMEM_ShrinkMemory              EventID (EventLevelOp,    EvtNetMEM,  4)
#define EvtNetMEM_FreeMemory                EventID (EventLevelOp,    EvtNetMEM,  5)
#define EvtNetMEM_FreeInvalidBlock          EventID (EventLevelError, EvtNetMEM,  6)
#define EvtNetMEM_FreeLinkCorrupted         EventID (EventLevelError, EvtNetMEM,  7)
#endif

/**
  \brief  Event on memory management initialize (Op)
  \param  pool_size     size of the memory pool
  \param  limit0        usage limit 0
                        (limit used in ethernet and bsd receive buffering)
  \param  limit1        usage limit 1
                        (limit used in TCP send buffering)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetMEM_InitMemory(uint32_t pool_size, uint32_t limit0, uint32_t limit1) {
    EventRecord4 (EvtNetMEM_InitMemory, pool_size, limit0, limit1, 0);
  }
#else
  #define EvrNetMEM_InitMemory(pool_size, limit0, limit1)
#endif

/**
  \brief  Event on memory allocate request (Op)
  \param  size          requested memory size in bytes
  \param  used          used memory status in bytes
  \param  blocks        number of used blocks status
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetMEM_AllocMemory(uint32_t size, uint32_t used, uint32_t blocks) {
    EventRecord4 (EvtNetMEM_AllocMemory, size, used, blocks, 0);
  }
#else
  #define EvrNetMEM_AllocMemory(size, used, blocks)
#endif

/**
  \brief  Event on memory allocate limit exceeded (Op)
  \param  size          requested memory size in bytes
  \param  used          used memory status in bytes
  \param  blocks        number of used blocks status
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetMEM_AllocLimitExceeded(uint32_t size, uint32_t used, uint32_t blocks) {
    EventRecord4 (EvtNetMEM_AllocLimitExceeded, size, used, blocks, 0);
  }
#else
  #define EvrNetMEM_AllocLimitExceeded(size, used, blocks)
#endif

/**
  \brief  Event on memory allocate out of memory error (Error)
  \param  size          requested memory size in bytes
  \param  used          used memory status in bytes
  \param  blocks        number of used blocks status
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetMEM_AllocOutOfMemory(uint32_t size, uint32_t used, uint32_t blocks) {
    EventRecord4 (EvtNetMEM_AllocOutOfMemory, size, used, blocks, 0);
  }
#else
  #define EvrNetMEM_AllocOutOfMemory(size, used, blocks)
#endif

/**
  \brief  Event on memory shrink block request (Op)
  \param  new_size      new block size
  \param  old_size      current block size
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetMEM_ShrinkMemory(uint32_t new_size, uint32_t old_size) {
    EventRecord2 (EvtNetMEM_ShrinkMemory, new_size, old_size);
  }
#else
  #define EvrNetMEM_ShrinkMemory(new_size, old_size)
#endif

/**
  \brief  Event on memory free request (Op)
  \param  size          size of the memory block to free
  \param  used          used memory status in bytes
  \param  blocks        number of used blocks status
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetMEM_FreeMemory(uint32_t size, uint32_t used, uint32_t blocks) {
    EventRecord4 (EvtNetMEM_FreeMemory, size, used, blocks, 0);
  }
#else
  #define EvrNetMEM_FreeMemory(size, used, blocks)
#endif

/**
  \brief  Event on memory free an invalid block (Error)
  \param  size          size of the memory block to free
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetMEM_FreeInvalidBlock(uint32_t size) {
    EventRecord2 (EvtNetMEM_FreeInvalidBlock, size, 0);
  }
#else
  #define EvrNetMEM_FreeInvalidBlock(size)
#endif

/**
  \brief  Event on memory free link corrupted (Error)
  \param  size          size of the memory block to free
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetMEM_FreeLinkCorrupted(uint32_t size) {
    EventRecord2 (EvtNetMEM_FreeLinkCorrupted, size, 0);
  }
#else
  #define EvrNetMEM_FreeLinkCorrupted(size)
#endif


// NetETH event identifiers ----------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetETH_InitInterface             EventID (EventLevelOp,    EvtNetETH,  0)
#define EvtNetETH_MacAddressConfigError     EventID (EventLevelError, EvtNetETH,  1)
#define EvtNetETH_MacAddressSetup           EventID (EventLevelDetail,EvtNetETH,  2)
#define EvtNetETH_PhyDriverConfigError      EventID (EventLevelError, EvtNetETH,  3)
#define EvtNetETH_PhyDriverInitError        EventID (EventLevelError, EvtNetETH,  4)
#define EvtNetETH_Ip4ConfigError            EventID (EventLevelError, EvtNetETH,  5)
#define EvtNetETH_Ip6ConfigError            EventID (EventLevelError, EvtNetETH,  6)
#define EvtNetETH_ThreadCreateFailed        EventID (EventLevelError, EvtNetETH,  7)
#define EvtNetETH_SendFrame                 EventID (EventLevelOp,    EvtNetETH,  8)
#define EvtNetETH_LinkDownError             EventID (EventLevelError, EvtNetETH,  9)
#define EvtNetETH_Ip4LocalAddressUndefined  EventID (EventLevelError, EvtNetETH, 10)
#define EvtNetETH_Ip4MacAddressUnresolved   EventID (EventLevelError, EvtNetETH, 11)
#define EvtNetETH_Ip6LocalAddressUndefined  EventID (EventLevelError, EvtNetETH, 12)
#define EvtNetETH_Ip6MacAddressUnresolved   EventID (EventLevelError, EvtNetETH, 13)
#define EvtNetETH_InvalidIpVersion          EventID (EventLevelError, EvtNetETH, 14)
#define EvtNetETH_HeaderInfo                EventID (EventLevelDetail,EvtNetETH, 15)
#define EvtNetETH_LinkDownStatus            EventID (EventLevelOp,    EvtNetETH, 16)
#define EvtNetETH_LinkUpStatus              EventID (EventLevelOp,    EvtNetETH, 17)
#define EvtNetETH_ReceiveFrame              EventID (EventLevelOp,    EvtNetETH, 18)
#define EvtNetETH_Ip4Disabled               EventID (EventLevelOp,    EvtNetETH, 19)
#define EvtNetETH_Ip6Disabled               EventID (EventLevelOp,    EvtNetETH, 20)
#define EvtNetETH_ProtocolUnknown           EventID (EventLevelOp,    EvtNetETH, 21)
#endif

/**
  \brief  Event on Ethernet interface initialize (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_InitInterface(void) {
    EventRecord2 (EvtNetETH_InitInterface, 0, 0);
  }
#else
  #define EvrNetETH_InitInterface()
#endif

/**
  \brief  Event on Ethernet MAC address configuration error (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_MacAddressConfigError(void) {
    EventRecord2 (EvtNetETH_MacAddressConfigError, 0, 0);
  }
#else
  #define EvrNetETH_MacAddressConfigError()
#endif

/**
  \brief  Event on Ethernet MAC address setup (Detail)
  \param  mac_address   pointer to MAC address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_MacAddressSetup(const uint8_t *mac_address) {
    EventRecordData (EvtNetETH_MacAddressSetup, mac_address, 6);
  }
#else
  #define EvrNetETH_MacAddressSetup(mac_address)
#endif

/**
  \brief  Event on Ethernet PHY configuration error (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_PhyDriverConfigError(void) {
    EventRecord2 (EvtNetETH_PhyDriverConfigError, 0, 0);
  }
#else
  #define EvrNetETH_PhyDriverConfigError()
#endif

/**
  \brief  Event on Ethernet PHY initialization error (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_PhyDriverInitError(void) {
    EventRecord2 (EvtNetETH_PhyDriverInitError, 0, 0);
  }
#else
  #define EvrNetETH_PhyDriverInitError()
#endif

/**
  \brief  Event on Ethernet IPv4 configuration error (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_Ip4ConfigError(void) {
    EventRecord2 (EvtNetETH_Ip4ConfigError, 0, 0);
  }
#else
  #define EvrNetETH_Ip4ConfigError()
#endif

/**
  \brief  Event on Ethernet IPv6 configuration error (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_Ip6ConfigError(void) {
    EventRecord2 (EvtNetETH_Ip6ConfigError, 0, 0);
  }
#else
  #define EvrNetETH_Ip6ConfigError()
#endif

/**
  \brief  Event on Ethernet thread create failed (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_ThreadCreateFailed(void) {
    EventRecord2 (EvtNetETH_ThreadCreateFailed, 0, 0);
  }
#else
  #define EvrNetETH_ThreadCreateFailed()
#endif

/**
  \brief  Event on Ethernet send frame (Op)
  \param  length        frame length in bytes
  \param  ip_version    internet protocol version
                         - 0: IPv4
                         - 1: IPv6
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_SendFrame(uint32_t length, uint8_t ip_version) {
    EventRecord2 (EvtNetETH_SendFrame, length, ip_version);
  }
#else
  #define EvrNetETH_SendFrame(length, ip_version)
#endif

/**
  \brief  Event on Ethernet link down error (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_LinkDownError(void) {
    EventRecord2 (EvtNetETH_LinkDownError, 0, 0);
  }
#else
  #define EvrNetETH_LinkDownError()
#endif

/**
  \brief  Event on Ethernet local IPv4 address undefined (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_Ip4LocalAddressUndefined(void) {
    EventRecord2 (EvtNetETH_Ip4LocalAddressUndefined, 0, 0);
  }
#else
  #define EvrNetETH_Ip4LocalAddressUndefined()
#endif

/**
  \brief  Event on Ethernet MAC address unresolved (Error)
  \param  ip4_address   pointer to IPv4 destination address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_Ip4MacAddressUnresolved(const uint8_t *ip4_address) {
    EventRecordData (EvtNetETH_Ip4MacAddressUnresolved, ip4_address, 4);
  }
#else
  #define EvrNetETH_Ip4MacAddressUnresolved(ip4_address)
#endif

/**
  \brief  Event on Ethernet local IPv6 address undefined (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_Ip6LocalAddressUndefined(void) {
    EventRecord2 (EvtNetETH_Ip6LocalAddressUndefined, 0, 0);
  }
#else
  #define EvrNetETH_Ip6LocalAddressUndefined()
#endif

/**
  \brief  Event on Ethernet MAC address unresolved (Error)
  \param  ip6_address   pointer to IPv6 destination address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_Ip6MacAddressUnresolved(const uint8_t *ip6_address) {
    EventRecordData (EvtNetETH_Ip6MacAddressUnresolved, ip6_address, 16);
  }
#else
  #define EvrNetETH_Ip6MacAddressUnresolved(ip6_address)
#endif

/**
  \brief  Event on Ethernet invalid IP version (Error)
  \param  ip_version    invalid IP protocol version value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_InvalidIpVersion(uint8_t ip_version) {
    EventRecord2 (EvtNetETH_InvalidIpVersion, ip_version, 0);
  }
#else
  #define EvrNetETH_InvalidIpVersion(ip_version)
#endif

/**
  \brief  Event on Ethernet send/receive frame header info (Detail)
  \param  eth_header    pointer to ethernet frame header of 14 bytes
                         - DstAddr  (6 bytes)
                         - SrcAddr  (6 bytes)
                         - Protocol (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_HeaderInfo(const void *eth_header) {
    EventRecordData (EvtNetETH_HeaderInfo, eth_header, 14);
  }
#else
  #define EvrNetETH_HeaderInfo(eth_header)
#endif

/**
  \brief  Event on Ethernet link down status (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_LinkDownStatus(void) {
    EventRecord2 (EvtNetETH_LinkDownStatus, 0, 0);
  }
#else
  #define EvrNetETH_LinkDownStatus()
#endif

/**
  \brief  Event on Ethernet link up status (Op)
  \param  speed         link speed
                         - 0: 10 Mbit
                         - 1: 100 Mbit
                         - 2: 1 Gbit
  \param  duplex        link duplex
                         - 0: half duplex
                         - 1: full duplex
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_LinkUpStatus(int32_t speed, int32_t duplex) {
    EventRecord2 (EvtNetETH_LinkUpStatus, speed, duplex);
  }
#else
  #define EvrNetETH_LinkUpStatus(speed, duplex)
#endif

/**
  \brief  Event on Ethernet receive frame (Op)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_ReceiveFrame(uint32_t length) {
    EventRecord2 (EvtNetETH_ReceiveFrame, length, 0);
  }
#else
  #define EvrNetETH_ReceiveFrame(length)
#endif

/**
  \brief  Event on Ethernet receive IPv4 disabled (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_Ip4Disabled(void) {
    EventRecord2 (EvtNetETH_Ip4Disabled, 0, 0);
  }
#else
  #define EvrNetETH_Ip4Disabled()
#endif

/**
  \brief  Event on Ethernet receive IPv6 disabled (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_Ip6Disabled(void) {
    EventRecord2 (EvtNetETH_Ip6Disabled, 0, 0);
  }
#else
  #define EvrNetETH_Ip6Disabled()
#endif

/**
  \brief  Event on Ethernet receive protocol unknown (Op)
  \param  protocol      unknown ethernet protocol type
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetETH_ProtocolUnknown(uint16_t protocol) {
    EventRecord2 (EvtNetETH_ProtocolUnknown, protocol, 0);
  }
#else
  #define EvrNetETH_ProtocolUnknown(protocol)
#endif



// NetPPP event identifiers ----------------------------------------------------
#ifdef DEBUG_EVR
/* PPP-Core events */
#define EvtNetPPP_InitInterface             EventID (EventLevelOp,    EvtNetPPP,  0)
#define EvtNetPPP_ThreadCreateFailed        EventID (EventLevelError, EvtNetPPP,  1)
#define EvtNetPPP_ReceiveFrame              EventID (EventLevelOp,    EvtNetPPP,  2)
#define EvtNetPPP_FrameTooShort             EventID (EventLevelOp,    EvtNetPPP,  3)
#define EvtNetPPP_ChecksumFailed            EventID (EventLevelError, EvtNetPPP,  4)
#define EvtNetPPP_CtrlByteInvalid           EventID (EventLevelError, EvtNetPPP,  5)
#define EvtNetPPP_SendFrame                 EventID (EventLevelOp,    EvtNetPPP,  6)
#define EvtNetPPP_NetworkLayerDown          EventID (EventLevelError, EvtNetPPP,  7)
#define EvtNetPPP_NoMemoryError             EventID (EventLevelError, EvtNetPPP,  8)
#define EvtNetPPP_QueueAddTransmit          EventID (EventLevelOp,    EvtNetPPP,  9)
#define EvtNetPPP_RejectProtocol            EventID (EventLevelOp,    EvtNetPPP, 10)
#define EvtNetPPP_RejectCode                EventID (EventLevelOp,    EvtNetPPP, 11)
#define EvtNetPPP_Connect                   EventID (EventLevelAPI,   EvtNetPPP, 12)
#define EvtNetPPP_Listen                    EventID (EventLevelAPI,   EvtNetPPP, 13)
#define EvtNetPPP_Close                     EventID (EventLevelAPI,   EvtNetPPP, 14)
#define EvtNetPPP_ShowUsername              EventID (EventLevelOp,    EvtNetPPP, 15)
#define EvtNetPPP_ShowPassword              EventID (EventLevelOp,    EvtNetPPP, 16)
#define EvtNetPPP_ModemOffline              EventID (EventLevelOp,    EvtNetPPP, 17)
#define EvtNetPPP_DataLinkDown              EventID (EventLevelOp,    EvtNetPPP, 18)
/* PPP-LCP events */
#define EvtNetPPP_LcpInit                   EventID (EventLevelOp,    EvtNetPPP, 19)
#define EvtNetPPP_LcpSendConfigRequest      EventID (EventLevelOp,    EvtNetPPP, 20)
#define EvtNetPPP_LcpNoRetriesLeft          EventID (EventLevelError, EvtNetPPP, 21)
#define EvtNetPPP_LcpOptionCharMap          EventID (EventLevelOp,    EvtNetPPP, 22)
#define EvtNetPPP_LcpOptionPfc              EventID (EventLevelOp,    EvtNetPPP, 23)
#define EvtNetPPP_LcpOptionAcfc             EventID (EventLevelOp,    EvtNetPPP, 24)
#define EvtNetPPP_LcpOptionMagicNumber      EventID (EventLevelOp,    EvtNetPPP, 25)
#define EvtNetPPP_LcpOptionAuthPap          EventID (EventLevelOp,    EvtNetPPP, 26)
#define EvtNetPPP_LcpOptionAuthChapMd5      EventID (EventLevelOp,    EvtNetPPP, 27)
#define EvtNetPPP_LcpSendEchoRequest        EventID (EventLevelOp,    EvtNetPPP, 28)
#define EvtNetPPP_LcpSendTerminateRequest   EventID (EventLevelOp,    EvtNetPPP, 29)
#define EvtNetPPP_LcpSendFrame              EventID (EventLevelOp,    EvtNetPPP, 30)
#define EvtNetPPP_LcpReceiveFrame           EventID (EventLevelOp,    EvtNetPPP, 31)
#define EvtNetPPP_LcpDataLinkUp             EventID (EventLevelOp,    EvtNetPPP, 32)
#define EvtNetPPP_LcpOptionMru              EventID (EventLevelOp,    EvtNetPPP, 33)
#define EvtNetPPP_LcpOptionAuth             EventID (EventLevelOp,    EvtNetPPP, 34)
#define EvtNetPPP_LcpOptionAuthChapNotMd5   EventID (EventLevelOp,    EvtNetPPP, 35)
#define EvtNetPPP_LcpOptionUnknown          EventID (EventLevelOp,    EvtNetPPP, 36)
#define EvtNetPPP_LcpSendReject             EventID (EventLevelOp,    EvtNetPPP, 37)
#define EvtNetPPP_LcpSendNak                EventID (EventLevelOp,    EvtNetPPP, 38)
#define EvtNetPPP_LcpSendAck                EventID (EventLevelOp,    EvtNetPPP, 39)
#define EvtNetPPP_LcpWrongAckReceived       EventID (EventLevelOp,    EvtNetPPP, 40)
#define EvtNetPPP_LcpWrongNakReceived       EventID (EventLevelOp,    EvtNetPPP, 41)
#define EvtNetPPP_LcpConfigAuthFailed       EventID (EventLevelError, EvtNetPPP, 42)
#define EvtNetPPP_LcpWrongRejectReceived    EventID (EventLevelOp,    EvtNetPPP, 43)
#define EvtNetPPP_LcpEchoMagicNumber        EventID (EventLevelOp,    EvtNetPPP, 44)
#define EvtNetPPP_LcpWrongPeerMagicNumber   EventID (EventLevelOp,    EvtNetPPP, 45)
#define EvtNetPPP_LcpSendEchoReply          EventID (EventLevelOp,    EvtNetPPP, 46)
#define EvtNetPPP_LcpWrongEchoReplyReceived EventID (EventLevelOp,    EvtNetPPP, 47)
#define EvtNetPPP_LcpSendTerminateAck       EventID (EventLevelOp,    EvtNetPPP, 48)
/* PPP-PAP events */
#define EvtNetPPP_PapInit                   EventID (EventLevelOp,    EvtNetPPP, 49)
#define EvtNetPPP_PapSendAuthRequest        EventID (EventLevelOp,    EvtNetPPP, 50)
#define EvtNetPPP_PapShowPassword           EventID (EventLevelOp,    EvtNetPPP, 51)
#define EvtNetPPP_PapSendFrame              EventID (EventLevelOp,    EvtNetPPP, 52)
#define EvtNetPPP_PapReceiveFrame           EventID (EventLevelOp,    EvtNetPPP, 53)
#define EvtNetPPP_PapLoginSuccess           EventID (EventLevelOp,    EvtNetPPP, 54)
#define EvtNetPPP_PapLoginFailed            EventID (EventLevelError, EvtNetPPP, 55)
#define EvtNetPPP_PapWrongAckReceived       EventID (EventLevelOp,    EvtNetPPP, 56)
#define EvtNetPPP_PapWrongNakReceived       EventID (EventLevelOp,    EvtNetPPP, 57)
/* PPP-CHAP events */
#define EvtNetPPP_ChapInit                  EventID (EventLevelOp,    EvtNetPPP, 58)
#define EvtNetPPP_ChapSendChallenge         EventID (EventLevelOp,    EvtNetPPP, 59)
#define EvtNetPPP_ChapSendFrame             EventID (EventLevelOp,    EvtNetPPP, 60)
#define EvtNetPPP_ChapReceiveFrame          EventID (EventLevelOp,    EvtNetPPP, 61)
#define EvtNetPPP_ChapWrongResponseReceived EventID (EventLevelOp,    EvtNetPPP, 62)
#define EvtNetPPP_ChapWrongSuccessReceived  EventID (EventLevelOp,    EvtNetPPP, 63)
#define EvtNetPPP_ChapWrongFailureReceived  EventID (EventLevelOp,    EvtNetPPP, 64)
#define EvtNetPPP_ChapLoginSuccess          EventID (EventLevelOp,    EvtNetPPP, 65)
#define EvtNetPPP_ChapLoginFailed           EventID (EventLevelError, EvtNetPPP, 66)
/* PPP-IPCP events */
#define EvtNetPPP_IpcpInit                  EventID (EventLevelOp,    EvtNetPPP, 67)
#define EvtNetPPP_IpcpIp4ConfigError        EventID (EventLevelError, EvtNetPPP, 68)
#define EvtNetPPP_IpcpSendConfigRequest     EventID (EventLevelOp,    EvtNetPPP, 69)
#define EvtNetPPP_IpcpOptionIpAddress       EventID (EventLevelOp,    EvtNetPPP, 70)
#define EvtNetPPP_IpcpOptionPrimaryDns      EventID (EventLevelOp,    EvtNetPPP, 71)
#define EvtNetPPP_IpcpOptionSecondaryDns    EventID (EventLevelOp,    EvtNetPPP, 72)
#define EvtNetPPP_IpcpSendFrame             EventID (EventLevelOp,    EvtNetPPP, 73)
#define EvtNetPPP_IpcpReceiveFrame          EventID (EventLevelOp,    EvtNetPPP, 74)
#define EvtNetPPP_IpcpOptionUnknown         EventID (EventLevelOp,    EvtNetPPP, 75)
#define EvtNetPPP_IpcpSendReject            EventID (EventLevelOp,    EvtNetPPP, 76)
#define EvtNetPPP_IpcpSendNak               EventID (EventLevelOp,    EvtNetPPP, 77)
#define EvtNetPPP_IpcpSendAck               EventID (EventLevelOp,    EvtNetPPP, 78)
#define EvtNetPPP_IpcpWrongAckReceived      EventID (EventLevelOp,    EvtNetPPP, 79)
#define EvtNetPPP_IpcpNetworkLayerUp        EventID (EventLevelOp,    EvtNetPPP, 80)
#define EvtNetPPP_IpcpWrongNakReceived      EventID (EventLevelOp,    EvtNetPPP, 81)
#define EvtNetPPP_IpcpWrongRejectReceived   EventID (EventLevelOp,    EvtNetPPP, 82)
#define EvtNetPPP_IpcpWrongSubnet           EventID (EventLevelOp,    EvtNetPPP, 83)
#define EvtNetPPP_IpcpPrimaryDnsRejected    EventID (EventLevelOp,    EvtNetPPP, 84)
#define EvtNetPPP_IpcpSecondaryDnsRejected  EventID (EventLevelOp,    EvtNetPPP, 85)
#define EvtNetPPP_IpcpIpAddressRejected     EventID (EventLevelError, EvtNetPPP, 86)
#define EvtNetPPP_IpcpNotRequestedOption    EventID (EventLevelError, EvtNetPPP, 87)
#endif

// PPP core event recorder functions -------------------------------------------

/**
  \brief  Event on PPP interface initialize (Op)
  \note   Point-to-Point Protocol
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_InitInterface(void) {
    EventRecord2 (EvtNetPPP_InitInterface, 0, 0);
  }
#else
  #define EvrNetPPP_InitInterface()
#endif

/**
  \brief  Event on PPP interface thread create failed (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ThreadCreateFailed(void) {
    EventRecord2 (EvtNetPPP_ThreadCreateFailed, 0, 0);
  }
#else
  #define EvrNetPPP_ThreadCreateFailed()
#endif

/**
  \brief  Event on PPP interface receive frame (Op)
  \param  protocol      PPP protocol type
                         - 0xC021: LCP
                         - 0xC023: PAP
                         - 0xC223: CHAP
                         - 0x8021: IPCP
                         - 0x0021: IP
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ReceiveFrame(uint16_t protocol, uint32_t length) {
    EventRecord2 (EvtNetPPP_ReceiveFrame, protocol, length);
  }
#else
  #define EvrNetPPP_ReceiveFrame(protocol, length)
#endif

/**
  \brief  Event on PPP interface received frame too short (Op)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_FrameTooShort(uint32_t length) {
    if (length > 1536) length = 0;
    EventRecord2 (EvtNetPPP_FrameTooShort, length, 0);
  }
#else
  #define EvrNetPPP_FrameTooShort(length)
#endif

/**
  \brief  Event on PPP interface frame checksum check failed (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ChecksumFailed(uint32_t length) {
    EventRecord2 (EvtNetPPP_ChecksumFailed, length, 0);
  }
#else
  #define EvrNetPPP_ChecksumFailed(length)
#endif

/**
  \brief  Event on PPP interface frame control byte invalid (Error)
  \param  ctrl_byte     invalid control byte value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_CtrlByteInvalid(uint8_t ctrl_byte) {
    EventRecord2 (EvtNetPPP_CtrlByteInvalid, ctrl_byte, 0);
  }
#else
  #define EvrNetPPP_CtrlByteInvalid(ctrl_byte)
#endif

/**
  \brief  Event on PPP interface send frame (Op)
  \param  protocol      PPP protocol type
                         - 0xC021: LCP
                         - 0xC023: PAP
                         - 0xC223: CHAP
                         - 0x8021: IPCP
                         - 0x0021: IP
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_SendFrame(uint16_t protocol, uint32_t length) {
    EventRecord2 (EvtNetPPP_SendFrame, protocol, length);
  }
#else
  #define EvrNetPPP_SendFrame(protocol, length)
#endif

/**
  \brief  Event on PPP interface network layer down (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_NetworkLayerDown(void) {
    EventRecord2 (EvtNetPPP_NetworkLayerDown, 0, 0);
  }
#else
  #define EvrNetPPP_NetworkLayerDown()
#endif

/**
  \brief  Event on PPP interface out of memory error (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_NoMemoryError(void) {
    EventRecord2 (EvtNetPPP_NoMemoryError, 0, 0);
  }
#else
  #define EvrNetPPP_NoMemoryError()
#endif

/**
  \brief  Event on PPP interface add frame to transmit queue (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_QueueAddTransmit(void) {
    EventRecord2 (EvtNetPPP_QueueAddTransmit, 0, 0);
  }
#else
  #define EvrNetPPP_QueueAddTransmit()
#endif

/**
  \brief  Event on PPP interface reject unsupported protocol type (Op)
  \param  protocol      unsupported protocol type value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_RejectProtocol(uint16_t protocol) {
    EventRecord2 (EvtNetPPP_RejectProtocol, protocol, 0);
  }
#else
  #define EvrNetPPP_RejectProtocol(protocol)
#endif

/**
  \brief  Event on PPP interface reject unsupported cp code (Op)
  \param  protocol      PPP protocol type
                         - 0xC021: LCP
                         - 0x8021: IPCP
  \param  code          unsupported control code value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_RejectCode(uint16_t protocol, uint8_t code) {
    EventRecord2 (EvtNetPPP_RejectCode, protocol, code);
  }
#else
  #define EvrNetPPP_RejectCode(protocol, code)
#endif

/**
  \brief  Event on PPP interface \ref netPPP_Connect start (API)
  \param  dial_number   pointer to a dial number string
  \param  length        length of the dial number string
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_Connect(const char *dial_number, uint32_t length) {
    if (length > 24) length = 24;
    EventRecordData (EvtNetPPP_Connect, dial_number, length);
  }
#else
  #define EvrNetPPP_Connect(dial_number, length)
#endif

/**
  \brief  Event on PPP interface \ref netPPP_Listen start (API)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_Listen(void) {
    EventRecord2 (EvtNetPPP_Listen, 0, 0);
  }
#else
  #define EvrNetPPP_Listen()
#endif

/**
  \brief  Event on PPP interface \ref netPPP_Close start (API)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_Close(void) {
    EventRecord2 (EvtNetPPP_Close, 0, 0);
  }
#else
  #define EvrNetPPP_Close()
#endif

/**
  \brief  Event on PPP interface display username (Op)
  \param  username      pointer to a username string
  \param  length        length of the username string
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ShowUsername(const char *username, uint32_t length) {
    if (length > 24) length = 24;
    EventRecordData (EvtNetPPP_ShowUsername, username, length);
  }
#else
  #define EvrNetPPP_ShowUsername(username, length)
#endif

/**
  \brief  Event on PPP interface display password (Op)
  \param  password      pointer to a password string
  \param  length        length of the password string
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ShowPassword(const char *password, uint32_t length) {
    if (length > 24) length = 24;
    EventRecordData (EvtNetPPP_ShowPassword, password, length);
  }
#else
  #define EvrNetPPP_ShowPassword(password, length)
#endif

/**
  \brief  Event on PPP interface modem offline (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ModemOffline(void) {
    EventRecord2 (EvtNetPPP_ModemOffline, 0, 0);
  }
#else
  #define EvrNetPPP_ModemOffline()
#endif

/**
  \brief  Event on PPP interface data-link layer down (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_DataLinkDown(void) {
    EventRecord2 (EvtNetPPP_DataLinkDown, 0, 0);
  }
#else
  #define EvrNetPPP_DataLinkDown()
#endif

// PPP-LCP event recorder functions --------------------------------------------

/**
  \brief  Event on PPP-LCP initialize (Op)
  \note   Point-to-Point Link Control Protocol
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpInit(void) {
    EventRecord2 (EvtNetPPP_LcpInit, 0, 0);
  }
#else
  #define EvrNetPPP_LcpInit()
#endif

/**
  \brief  Event on PPP-LCP send configuration request (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpSendConfigRequest(void) {
    EventRecord2 (EvtNetPPP_LcpSendConfigRequest, 0, 0);
  }
#else
  #define EvrNetPPP_LcpSendConfigRequest()
#endif

/**
  \brief  Event on PPP-LCP no retries left for LCP negotiation (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpNoRetriesLeft(void) {
    EventRecord2 (EvtNetPPP_LcpNoRetriesLeft, 0, 0);
  }
#else
  #define EvrNetPPP_LcpNoRetriesLeft()
#endif

/**
  \brief  Event on PPP-LCP option character map (Op)
  \param  char_map      character bit-map for non printable characters
                         - bit 0: ascii character 0
                         - bit 1: ascii character 1
                         - bit 2: ascii character 2
                         -  ...
                         - bit 31: ascii character 31
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpOptionCharMap(uint32_t char_map) {
    EventRecord2 (EvtNetPPP_LcpOptionCharMap, char_map, 0);
  }
#else
  #define EvrNetPPP_LcpOptionCharMap(char_map)
#endif

/**
  \brief  Event on PPP-LCP option PFC (Protocol Field Compression) (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpOptionPfc(void) {
    EventRecord2 (EvtNetPPP_LcpOptionPfc, 0, 0);
  }
#else
  #define EvrNetPPP_LcpOptionPfc()
#endif

/**
  \brief  Event on PPP-LCP option ACFC (Address and Control Field Compression) (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpOptionAcfc(void) {
    EventRecord2 (EvtNetPPP_LcpOptionAcfc, 0, 0);
  }
#else
  #define EvrNetPPP_LcpOptionAcfc()
#endif

/**
  \brief  Event on PPP-LCP option magic number (Op)
  \param  magic_number  magic random number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpOptionMagicNumber(uint32_t magic_number) {
    EventRecord2 (EvtNetPPP_LcpOptionMagicNumber, magic_number, 0);
  }
#else
  #define EvrNetPPP_LcpOptionMagicNumber(magic_number)
#endif

/**
  \brief  Event on PPP-LCP option Authentication PAP (Op)
  \note   Password Authentication Protocol - plain text
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpOptionAuthPap(void) {
    EventRecord2 (EvtNetPPP_LcpOptionAuthPap, 0, 0);
  }
#else
  #define EvrNetPPP_LcpOptionAuthPap()
#endif

/**
  \brief  Event on PPP-LCP option Authentication CHAP (Op)
  \note   Challenge Handshake Authentication Protocol with MD5
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpOptionAuthChapMd5(void) {
    EventRecord2 (EvtNetPPP_LcpOptionAuthChapMd5, 0, 0);
  }
#else
  #define EvrNetPPP_LcpOptionAuthChapMd5()
#endif

/**
  \brief  Event on PPP-LCP send echo request (Op)
  \param  magic_number  magic random number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpSendEchoRequest(uint32_t magic_number) {
    EventRecord2 (EvtNetPPP_LcpSendEchoRequest, magic_number, 0);
  }
#else
  #define EvrNetPPP_LcpSendEchoRequest(magic_number)
#endif

/**
  \brief  Event on PPP-LCP send LCP terminate request (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpSendTerminateRequest(void) {
    EventRecord2 (EvtNetPPP_LcpSendTerminateRequest, 0, 0);
  }
#else
  #define EvrNetPPP_LcpSendTerminateRequest()
#endif

/**
  \brief  Event on PPP-LCP send frame (Op)
  \param  lcp_header    pointer to LCP frame header of 4 bytes
                         - Code (1 byte)
                         - Id   (1 byte)
                         - Len  (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpSendFrame(const void *lcp_header) {
    EventRecordData (EvtNetPPP_LcpSendFrame, lcp_header, 4);
  }
#else
  #define EvrNetPPP_LcpSendFrame(lcp_header)
#endif

/**
  \brief  Event on PPP-LCP receive frame (Op)
  \param  lcp_header    pointer to LCP frame header of 4 bytes
                         - Code (1 byte)
                         - Id   (1 byte)
                         - Len  (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpReceiveFrame(const void *lcp_header) {
    EventRecordData (EvtNetPPP_LcpReceiveFrame, lcp_header, 4);
  }
#else
  #define EvrNetPPP_LcpReceiveFrame(lcp_header)
#endif

/**
  \brief  Event on PPP-LCP data-link layer established (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpDataLinkUp(void) {
    EventRecord2 (EvtNetPPP_LcpDataLinkUp, 0, 0);
  }
#else
  #define EvrNetPPP_LcpDataLinkUp()
#endif

/**
  \brief  Event on PPP-LCP option MRU (Op)
  \param  mru_size      maximum receive unit size
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpOptionMru(uint16_t mru_size) {
    EventRecord2 (EvtNetPPP_LcpOptionMru, mru_size, 0);
  }
#else
  #define EvrNetPPP_LcpOptionMru(mru_size)
#endif

/**
  \brief  Event on PPP-LCP option authentication type (Op)
  \param  auth_type     authentication type code
                         - 0xC023: PAP
                         - 0xC223: CHAP
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpOptionAuth(uint16_t auth_type) {
    EventRecord2 (EvtNetPPP_LcpOptionAuth, auth_type, 0);
  }
#else
  #define EvrNetPPP_LcpOptionAuth(auth_type)
#endif

/**
  \brief  Event on PPP-LCP option CHAP authentication not MD5 type (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpOptionAuthChapNotMd5(void) {
    EventRecord2 (EvtNetPPP_LcpOptionAuthChapNotMd5, 0, 0);
  }
#else
  #define EvrNetPPP_LcpOptionAuthChapNotMd5()
#endif

/**
  \brief  Event on PPP-LCP unknown option received (Op)
  \param  lcp_option    unknown LCP option value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpOptionUnknown(uint8_t lcp_option) {
    EventRecord2 (EvtNetPPP_LcpOptionUnknown, lcp_option, 0);
  }
#else
  #define EvrNetPPP_LcpOptionUnknown(lcp_option)
#endif

/**
  \brief  Event on PPP-LCP send reject (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpSendReject(void) {
    EventRecord2 (EvtNetPPP_LcpSendReject, 0, 0);
  }
#else
  #define EvrNetPPP_LcpSendReject()
#endif

/**
  \brief  Event on PPP-LCP send not acknowledge (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpSendNak(void) {
    EventRecord2 (EvtNetPPP_LcpSendNak, 0, 0);
  }
#else
  #define EvrNetPPP_LcpSendNak()
#endif

/**
  \brief  Event on PPP-LCP send acknowledge (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpSendAck(void) {
    EventRecord2 (EvtNetPPP_LcpSendAck, 0, 0);
  }
#else
  #define EvrNetPPP_LcpSendAck()
#endif

/**
  \brief  Event on PPP-LCP wrong acknowledge received (Op)
  \param  lcp_id        wrong LCP identification value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpWrongAckReceived(uint8_t lcp_id) {
    EventRecord2 (EvtNetPPP_LcpWrongAckReceived, lcp_id, 0);
  }
#else
  #define EvrNetPPP_LcpWrongAckReceived(lcp_id)
#endif

/**
  \brief  Event on PPP-LCP wrong not-acknowledge received (Op)
  \param  lcp_id        wrong LCP identification value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpWrongNakReceived(uint8_t lcp_id) {
    EventRecord2 (EvtNetPPP_LcpWrongNakReceived, lcp_id, 0);
  }
#else
  #define EvrNetPPP_LcpWrongNakReceived(lcp_id)
#endif

/**
  \brief  Event on PPP-LCP authentication type negotiation failed (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpConfigAuthFailed(void) {
    EventRecord2 (EvtNetPPP_LcpConfigAuthFailed, 0, 0);
  }
#else
  #define EvrNetPPP_LcpConfigAuthFailed()
#endif

/**
  \brief  Event on PPP-LCP wrong reject received (Op)
  \param  lcp_id        wrong LCP identification value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpWrongRejectReceived(uint8_t lcp_id) {
    EventRecord2 (EvtNetPPP_LcpWrongRejectReceived, lcp_id, 0);
  }
#else
  #define EvrNetPPP_LcpWrongRejectReceived(lcp_id)
#endif

/**
  \brief  Event on PPP-LCP echo magic number (Op)
  \param  magic_number  echo magic number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpEchoMagicNumber(uint32_t magic_number) {
    EventRecord2 (EvtNetPPP_LcpEchoMagicNumber, magic_number, 0);
  }
#else
  #define EvrNetPPP_LcpEchoMagicNumber(magic_number)
#endif

/**
  \brief  Event on PPP-LCP wrong peer magic number (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpWrongPeerMagicNumber(void) {
    EventRecord2 (EvtNetPPP_LcpWrongPeerMagicNumber, 0, 0);
  }
#else
  #define EvrNetPPP_LcpWrongPeerMagicNumber()
#endif

/**
  \brief  Event on PPP-LCP send echo reply (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpSendEchoReply(void) {
    EventRecord2 (EvtNetPPP_LcpSendEchoReply, 0, 0);
  }
#else
  #define EvrNetPPP_LcpSendEchoReply()
#endif

/**
  \brief  Event on PPP-LCP wrong echo reply received (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpWrongEchoReplyReceived(void) {
    EventRecord2 (EvtNetPPP_LcpWrongEchoReplyReceived, 0, 0);
  }
#else
  #define EvrNetPPP_LcpWrongEchoReplyReceived()
#endif

/**
  \brief  Event on PPP-LCP send terminate acknowledge (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_LcpSendTerminateAck(void) {
    EventRecord2 (EvtNetPPP_LcpSendTerminateAck, 0, 0);
  }
#else
  #define EvrNetPPP_LcpSendTerminateAck()
#endif

// PPP-PAP event recorder functions --------------------------------------------

/**
  \brief  Event on PPP-PAP initialize (Op)
  \note   Password Authentication Protocol
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_PapInit(void) {
    EventRecord2 (EvtNetPPP_PapInit, 0, 0);
  }
#else
  #define EvrNetPPP_PapInit()
#endif

/**
  \brief  Event on PPP-PAP send authentication request (Op)
  \param  peer_id       peer identifier string (username)
  \param  length        length of the peer identifier
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_PapSendAuthRequest(const char *peer_id, uint32_t length) {
    if (length > 24) length = 24;
    EventRecordData (EvtNetPPP_PapSendAuthRequest, peer_id, length);
  }
#else
  #define EvrNetPPP_PapSendAuthRequest(peer_id, length)
#endif

/**
  \brief  Event on PPP-PAP display password (Op)
  \param  password      authentication password
  \param  length        length of authentication password
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_PapShowPassword(const char *password, uint32_t length) {
    if (length > 24) length = 24;
    EventRecordData (EvtNetPPP_PapShowPassword, password, length);
  }
#else
  #define EvrNetPPP_PapShowPassword(password, length)
#endif

/**
  \brief  Event on PPP-PAP send frame (Op)
  \param  pap_header    pointer to PAP frame header of 4 bytes
                         - Code (1 byte)
                         - Id   (1 byte)
                         - Len  (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_PapSendFrame(const void *pap_header) {
    EventRecordData (EvtNetPPP_PapSendFrame, pap_header, 4);
  }
#else
  #define EvrNetPPP_PapSendFrame(pap_header)
#endif

/**
  \brief  Event on PPP-PAP receive frame (Op)
  \param  pap_header    pointer to PAP frame header of 4 bytes
                         - Code (1 byte)
                         - Id   (1 byte)
                         - Len  (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_PapReceiveFrame(const void *pap_header) {
    EventRecordData (EvtNetPPP_PapReceiveFrame, pap_header, 4);
  }
#else
  #define EvrNetPPP_PapReceiveFrame(pap_header)
#endif

/**
  \brief  Event on PPP-PAP login success (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_PapLoginSuccess(void) {
    EventRecord2 (EvtNetPPP_PapLoginSuccess, 0, 0);
  }
#else
  #define EvrNetPPP_PapLoginSuccess()
#endif

/**
  \brief  Event on PPP-PAP login failed (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_PapLoginFailed(void) {
    EventRecord2 (EvtNetPPP_PapLoginFailed, 0, 0);
  }
#else
  #define EvrNetPPP_PapLoginFailed()
#endif

/**
  \brief  Event on PPP-PAP wrong acknowledge received (Op)
  \param  pap_id        wrong PAP identification value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_PapWrongAckReceived(uint8_t pap_id) {
    EventRecord2 (EvtNetPPP_PapWrongAckReceived, pap_id, 0);
  }
#else
  #define EvrNetPPP_PapWrongAckReceived(pap_id)
#endif

/**
  \brief  Event on PPP-PAP wrong not-acknowledge received (Op)
  \param  pap_id        wrong PAP identification value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_PapWrongNakReceived(uint8_t pap_id) {
    EventRecord2 (EvtNetPPP_PapWrongNakReceived, pap_id, 0);
  }
#else
  #define EvrNetPPP_PapWrongNakReceived(pap_id)
#endif


// PPP-CHAP event recorder functions -------------------------------------------

/**
  \brief  Event on PPP-CHAP initialize (Op)
  \note   Challenge-Handshake Authentication Protocol
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ChapInit(void) {
    EventRecord2 (EvtNetPPP_ChapInit, 0, 0);
  }
#else
  #define EvrNetPPP_ChapInit()
#endif

/**
  \brief  Event on PPP-CHAP send challenge (Op)
  \param  name          system identification string
  \param  length        length of the system identification string
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ChapSendChallenge(const char *name, uint32_t length) {
    EventRecordData (EvtNetPPP_ChapSendChallenge, name, length);
  }
#else
  #define EvrNetPPP_ChapSendChallenge(name, length)
#endif

/**
  \brief  Event on PPP-CHAP send frame (Op)
  \param  chap_header   pointer to CHAP frame header of 4 bytes
                         - Code (1 byte)
                         - Id   (1 byte)
                         - Len  (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ChapSendFrame(const void *chap_header) {
    EventRecordData (EvtNetPPP_ChapSendFrame, chap_header, 4);
  }
#else
  #define EvrNetPPP_ChapSendFrame(chap_header)
#endif

/**
  \brief  Event on PPP-CHAP receive frame (Op)
  \param  chap_header   pointer to CHAP frame header of 4 bytes
                         - Code (1 byte)
                         - Id   (1 byte)
                         - Len  (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ChapReceiveFrame(const void *chap_header) {
    EventRecordData (EvtNetPPP_ChapReceiveFrame, chap_header, 4);
  }
#else
  #define EvrNetPPP_ChapReceiveFrame(chap_header)
#endif

/**
  \brief  Event on PPP-CHAP wrong response received (Op)
  \param  chap_id       wrong CHAP identification value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ChapWrongResponseReceived(uint8_t chap_id) {
    EventRecord2 (EvtNetPPP_ChapWrongResponseReceived, chap_id, 0);
  }
#else
  #define EvrNetPPP_ChapWrongResponseReceived(chap_id)
#endif

/**
  \brief  Event on PPP-CHAP wrong success received (Op)
  \param  chap_id       wrong CHAP identification value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ChapWrongSuccessReceived(uint8_t chap_id) {
    EventRecord2 (EvtNetPPP_ChapWrongSuccessReceived, chap_id, 0);
  }
#else
  #define EvrNetPPP_ChapWrongSuccessReceived(chap_id)
#endif

/**
  \brief  Event on PPP-CHAP wrong failure received (Op)
  \param  chap_id       wrong CHAP identification value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ChapWrongFailureReceived(uint8_t chap_id) {
    EventRecord2 (EvtNetPPP_ChapWrongFailureReceived, chap_id, 0);
  }
#else
  #define EvrNetPPP_ChapWrongFailureReceived(chap_id)
#endif

/**
  \brief  Event on PPP-CHAP login success (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ChapLoginSuccess(void) {
    EventRecord2 (EvtNetPPP_ChapLoginSuccess, 0, 0);
  }
#else
  #define EvrNetPPP_ChapLoginSuccess()
#endif

/**
  \brief  Event on PPP-CHAP login failed (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_ChapLoginFailed(void) {
    EventRecord2 (EvtNetPPP_ChapLoginFailed, 0, 0);
  }
#else
  #define EvrNetPPP_ChapLoginFailed()
#endif


// PPP-IPCP event recorder functions -------------------------------------------

/**
  \brief  Event on PPP-IPCP initialize (Op)
  \note   PPP Internet Protocol Control Protocol
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpInit(void) {
    EventRecord2 (EvtNetPPP_IpcpInit, 0, 0);
  }
#else
  #define EvrNetPPP_IpcpInit()
#endif

/**
  \brief  Event on PPP-IPCP interface IPv4 configuration error (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpIp4ConfigError(void) {
    EventRecord2 (EvtNetPPP_IpcpIp4ConfigError, 0, 0);
  }
#else
  #define EvrNetPPP_IpcpIp4ConfigError()
#endif

/**
  \brief  Event on PPP-IPCP send configuration request (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpSendConfigRequest(void) {
    EventRecord2 (EvtNetPPP_IpcpSendConfigRequest, 0, 0);
  }
#else
  #define EvrNetPPP_IpcpSendConfigRequest()
#endif

/**
  \brief  Event on PPP-IPCP option IP-address (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpOptionIpAddress(const uint8_t *ip4_address) {
    EventRecordData (EvtNetPPP_IpcpOptionIpAddress, ip4_address, 4);
  }
#else
  #define EvrNetPPP_IpcpOptionIpAddress(ip4_address)
#endif

/**
  \brief  Event on PPP-IPCP option primary DNS server address (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpOptionPrimaryDns(const uint8_t *ip4_address) {
    EventRecordData (EvtNetPPP_IpcpOptionPrimaryDns, ip4_address, 4);
  }
#else
  #define EvrNetPPP_IpcpOptionPrimaryDns(ip4_address)
#endif
/**
  \brief  Event on PPP-IPCP option secondary DNS server address (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpOptionSecondaryDns(const uint8_t *ip4_address) {
    EventRecordData (EvtNetPPP_IpcpOptionSecondaryDns, ip4_address, 4);
  }
#else
  #define EvrNetPPP_IpcpOptionSecondaryDns(ip4_address)
#endif

/**
  \brief  Event on PPP-IPCP send frame (Op)
  \param  ipcp_header   pointer to IPCP frame header of 4 bytes
                         - Code (1 byte)
                         - Id   (1 byte)
                         - Len  (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpSendFrame(const void *ipcp_header) {
    EventRecordData (EvtNetPPP_IpcpSendFrame, ipcp_header, 4);
  }
#else
  #define EvrNetPPP_IpcpSendFrame(ipcp_header)
#endif

/**
  \brief  Event on PPP-IPCP receive frame (Op)
  \param  ipcp_header   pointer to IPCP frame header of 4 bytes
                         - Code (1 byte)
                         - Id   (1 byte)
                         - Len  (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpReceiveFrame(const void *ipcp_header) {
    EventRecordData (EvtNetPPP_IpcpReceiveFrame, ipcp_header, 4);
  }
#else
  #define EvrNetPPP_IpcpReceiveFrame(ipcp_header)
#endif

/**
  \brief  Event on PPP-IPCP unknown option received (Op)
  \param  ipcp_option   unknown IPCP option value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpOptionUnknown(uint8_t ipcp_option) {
    EventRecord2 (EvtNetPPP_IpcpOptionUnknown, ipcp_option, 0);
  }
#else
  #define EvrNetPPP_IpcpOptionUnknown(ipcp_option)
#endif

/**
  \brief  Event on PPP-IPCP send reject (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpSendReject(void) {
    EventRecord2 (EvtNetPPP_IpcpSendReject, 0, 0);
  }
#else
  #define EvrNetPPP_IpcpSendReject()
#endif

/**
  \brief  Event on PPP-IPCP send not acknowledge (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpSendNak(void) {
    EventRecord2 (EvtNetPPP_IpcpSendNak, 0, 0);
  }
#else
  #define EvrNetPPP_IpcpSendNak()
#endif

/**
  \brief  Event on PPP-IPCP send acknowledge (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpSendAck(void) {
    EventRecord2 (EvtNetPPP_IpcpSendAck, 0, 0);
  }
#else
  #define EvrNetPPP_IpcpSendAck()
#endif

/**
  \brief  Event on PPP-IPCP wrong acknowledge received (Op)
  \param  ipcp_id       wrong IPCP identification value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpWrongAckReceived(uint8_t ipcp_id) {
    EventRecord2 (EvtNetPPP_IpcpWrongAckReceived, ipcp_id, 0);
  }
#else
  #define EvrNetPPP_IpcpWrongAckReceived(ipcp_id)
#endif

/**
  \brief  Event on PPP-IPCP network-layer established (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpNetworkLayerUp(void) {
    EventRecord2 (EvtNetPPP_IpcpNetworkLayerUp, 0, 0);
  }
#else
  #define EvrNetPPP_IpcpNetworkLayerUp()
#endif

/**
  \brief  Event on PPP-IPCP wrong not-acknowledge received (Op)
  \param  ipcp_id       wrong IPCP identification value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpWrongNakReceived(uint8_t ipcp_id) {
    EventRecord2 (EvtNetPPP_IpcpWrongNakReceived, ipcp_id, 0);
  }
#else
  #define EvrNetPPP_IpcpWrongNakReceived(ipcp_id)
#endif

/**
  \brief  Event on PPP-IPCP wrong reject received (Op)
  \param  ipcp_id       wrong IPCP identification value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpWrongRejectReceived(uint8_t ipcp_id) {
    EventRecord2 (EvtNetPPP_IpcpWrongRejectReceived, ipcp_id, 0);
  }
#else
  #define EvrNetPPP_IpcpWrongRejectReceived(ipcp_id)
#endif

/**
  \brief  Event on PPP-IPCP advertised IP-address not in subnet (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpWrongSubnet(const uint8_t *ip4_address) {
    EventRecordData (EvtNetPPP_IpcpWrongSubnet, ip4_address, 4);
  }
#else
  #define EvrNetPPP_IpcpWrongSubnet(ip4_address)
#endif

/**
  \brief  Event on PPP-IPCP primary DNS server option rejected (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpPrimaryDnsRejected(void) {
    EventRecord2 (EvtNetPPP_IpcpPrimaryDnsRejected, 0, 0);
  }
#else
  #define EvrNetPPP_IpcpPrimaryDnsRejected()
#endif

/**
  \brief  Event on PPP-IPCP secondary DNS server option rejected (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpSecondaryDnsRejected(void) {
    EventRecord2 (EvtNetPPP_IpcpSecondaryDnsRejected, 0, 0);
  }
#else
  #define EvrNetPPP_IpcpSecondaryDnsRejected()
#endif

/**
  \brief  Event on PPP-IPCP IP-address option rejected (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpIpAddressRejected(void) {
    EventRecord2 (EvtNetPPP_IpcpIpAddressRejected, 0, 0);
  }
#else
  #define EvrNetPPP_IpcpIpAddressRejected()
#endif

/**
  \brief  Event on PPP-IPCP not requested option rejected (Error)
  \param  ipcp_option   rejected option value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetPPP_IpcpNotRequestedOption(uint8_t ipcp_option) {
    EventRecord2 (EvtNetPPP_IpcpNotRequestedOption, ipcp_option, 0);
  }
#else
  #define EvrNetPPP_IpcpNotRequestedOption(ipcp_option)
#endif


// NetSLIP event identifiers ---------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetSLIP_InitInterface            EventID (EventLevelOp,    EvtNetSLIP,  0)
#define EvtNetSLIP_Ip4ConfigError           EventID (EventLevelError, EvtNetSLIP,  1)
#define EvtNetSLIP_ThreadCreateFailed       EventID (EventLevelError, EvtNetSLIP,  2)
#define EvtNetSLIP_Connect                  EventID (EventLevelAPI,   EvtNetSLIP,  3)
#define EvtNetSLIP_Listen                   EventID (EventLevelAPI,   EvtNetSLIP,  4)
#define EvtNetSLIP_Close                    EventID (EventLevelAPI,   EvtNetSLIP,  5)
#define EvtNetSLIP_SendFrame                EventID (EventLevelOp,    EvtNetSLIP,  6)
#define EvtNetSLIP_InvalidIpVersion         EventID (EventLevelError, EvtNetSLIP,  7)
#define EvtNetSLIP_NoMemoryError            EventID (EventLevelError, EvtNetSLIP,  8)
#define EvtNetSLIP_QueueAddTransmit         EventID (EventLevelOp,    EvtNetSLIP,  9)
#define EvtNetSLIP_ModemOffline             EventID (EventLevelOp,    EvtNetSLIP, 10)
#define EvtNetSLIP_ReceiveFrame             EventID (EventLevelOp,    EvtNetSLIP, 11)
#endif

/**
  \brief  Event on SLIP interface initialize (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSLIP_InitInterface(void) {
    EventRecord2 (EvtNetSLIP_InitInterface, 0, 0);
  }
#else
  #define EvrNetSLIP_InitInterface()
#endif

/**
  \brief  Event on SLIP interface IPv4 configuration error (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSLIP_Ip4ConfigError(void) {
    EventRecord2 (EvtNetSLIP_Ip4ConfigError, 0, 0);
  }
#else
  #define EvrNetSLIP_Ip4ConfigError()
#endif

/**
  \brief  Event on SLIP interface thread create failed (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSLIP_ThreadCreateFailed(void) {
    EventRecord2 (EvtNetSLIP_ThreadCreateFailed, 0, 0);
  }
#else
  #define EvrNetSLIP_ThreadCreateFailed()
#endif

/**
  \brief  Event on SLIP interface \ref netSLIP_Connect start (API)
  \param  dial_number   pointer to a number to dial string
  \param  length        length of the dial number string
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSLIP_Connect(const char *dial_number, uint32_t length) {
    if (length > 24) length = 24;
    EventRecordData (EvtNetSLIP_Connect, dial_number, length);
  }
#else
  #define EvrNetSLIP_Connect(dial_number, length)
#endif

/**
  \brief  Event on SLIP interface \ref netSLIP_Listen start (API)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSLIP_Listen(void) {
    EventRecord2 (EvtNetSLIP_Listen, 0, 0);
  }
#else
  #define EvrNetSLIP_Listen()
#endif

/**
  \brief  Event on SLIP interface \ref netSLIP_Close start (API)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSLIP_Close(void) {
    EventRecord2 (EvtNetSLIP_Close, 0, 0);
  }
#else
  #define EvrNetSLIP_Close()
#endif

/**
  \brief  Event on SLIP interface send frame (Op)
  \param  length        frame length in bytes
  \param  ip_version    internet protocol version
                         - 0: IPv4
                         - 1: IPv6
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSLIP_SendFrame(uint32_t length, uint8_t ip_version) {
    EventRecord2 (EvtNetSLIP_SendFrame, length, ip_version);
  }
#else
  #define EvrNetSLIP_SendFrame(length, ip_version)
#endif

/**
  \brief  Event on SLIP interface invalid IP version (Error)
  \param  ip_version    invalid IP protocol version value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSLIP_InvalidIpVersion(uint8_t ip_version) {
    EventRecord2 (EvtNetSLIP_InvalidIpVersion, ip_version, 0);
  }
#else
  #define EvrNetSLIP_InvalidIpVersion(ip_version)
#endif

/**
  \brief  Event on SLIP interface out of memory error (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSLIP_NoMemoryError(void) {
    EventRecord2 (EvtNetSLIP_NoMemoryError, 0, 0);
  }
#else
  #define EvrNetSLIP_NoMemoryError()
#endif

/**
  \brief  Event on SLIP interface add frame to transmit queue (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSLIP_QueueAddTransmit(void) {
    EventRecord2 (EvtNetSLIP_QueueAddTransmit, 0, 0);
  }
#else
  #define EvrNetSLIP_QueueAddTransmit()
#endif

/**
  \brief  Event on SLIP interface modem offline (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSLIP_ModemOffline(void) {
    EventRecord2 (EvtNetSLIP_ModemOffline, 0, 0);
  }
#else
  #define EvrNetSLIP_ModemOffline()
#endif

/**
  \brief  Event on SLIP interface receive frame (Op)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetSLIP_ReceiveFrame(uint32_t length) {
    EventRecord2 (EvtNetSLIP_ReceiveFrame, length, 0);
  }
#else
  #define EvrNetSLIP_ReceiveFrame(length)
#endif


// NetLOOP event identifiers ---------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetLOOP_InitInterface            EventID (EventLevelOp,    EvtNetLOOP, 0)
#define EvtNetLOOP_SendFrame                EventID (EventLevelOp,    EvtNetLOOP, 1)
#define EvtNetLOOP_NoMemoryError            EventID (EventLevelError, EvtNetLOOP, 2)
#define EvtNetLOOP_ReceiveFrame             EventID (EventLevelOp,    EvtNetLOOP, 3)
#endif

/**
  \brief  Event on Loopback interface initialize (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetLOOP_InitInterface(void) {
    EventRecord2 (EvtNetLOOP_InitInterface, 0, 0);
  }
#else
  #define EvrNetLOOP_InitInterface()
#endif

/**
  \brief  Event on Loopback interface send frame (Op)
  \param  length        frame length in bytes
  \param  ip_version    internet protocol version
                         - 0: IPv4
                         - 1: IPv6
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetLOOP_SendFrame(uint32_t length, uint8_t ip_version) {
    EventRecord2 (EvtNetLOOP_SendFrame, length, ip_version);
  }
#else
  #define EvrNetLOOP_SendFrame(length, ip_version)
#endif

/**
  \brief  Event on Loopback interface out of memory error (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetLOOP_NoMemoryError(void) {
    EventRecord2 (EvtNetLOOP_NoMemoryError, 0, 0);
  }
#else
  #define EvrNetLOOP_NoMemoryError()
#endif

/**
  \brief  Event on Loopback interface receive frame (Op)
  \param  length        frame length in bytes
  \param  ip_version    internet protocol version
                         - 0: IPv4
                         - 1: IPv6
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetLOOP_ReceiveFrame(uint32_t length, uint8_t ip_version) {
    EventRecord2 (EvtNetLOOP_ReceiveFrame, length, ip_version);
  }
#else
  #define EvrNetLOOP_ReceiveFrame(length, ip_version)
#endif


// NetIP4 event identifiers ----------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetIP4_InitCore                  EventID (EventLevelOp,    EvtNetIP4,  0)
#define EvtNetIP4_ReceiveFrame              EventID (EventLevelOp,    EvtNetIP4,  1)
#define EvtNetIP4_FrameTooShort             EventID (EventLevelError, EvtNetIP4,  2)
#define EvtNetIP4_InvalidIpVersion          EventID (EventLevelError, EvtNetIP4,  3)
#define EvtNetIP4_HeaderInfo                EventID (EventLevelDetail,EvtNetIP4,  4)
#define EvtNetIP4_SourceIpAddressInvalid    EventID (EventLevelError, EvtNetIP4,  5)
#define EvtNetIP4_WrongMulticastProtocol    EventID (EventLevelError, EvtNetIP4,  6)
#define EvtNetIP4_WrongDestinationAddress   EventID (EventLevelOp,    EvtNetIP4,  7)
#define EvtNetIP4_ChecksumFailed            EventID (EventLevelError, EvtNetIP4,  8)
#define EvtNetIP4_FragmentsNotSupported     EventID (EventLevelError, EvtNetIP4,  9)
#define EvtNetIP4_SendFrame                 EventID (EventLevelOp,    EvtNetIP4, 10)
#define EvtNetIP4_ProtocolUnknown           EventID (EventLevelError, EvtNetIP4, 11)
#define EvtNetIP4_DestinationAddressNull    EventID (EventLevelError, EvtNetIP4, 12)
#endif

/**
  \brief  Event on IPv4 core initialize (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP4_InitCore(void) {
    EventRecord2 (EvtNetIP4_InitCore, 0, 0);
  }
#else
  #define EvrNetIP4_InitCore()
#endif

/**
  \brief  Event on IPv4 receive frame (Op)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP4_ReceiveFrame(uint32_t length) {
    EventRecord2 (EvtNetIP4_ReceiveFrame, length, 0);
  }
#else
  #define EvrNetIP4_ReceiveFrame(length)
#endif

/**
  \brief  Event on IPv4 received frame too short (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP4_FrameTooShort(uint32_t length) {
    EventRecord2 (EvtNetIP4_FrameTooShort, length, 0);
  }
#else
  #define EvrNetIP4_FrameTooShort(length)
#endif

/**
  \brief  Event on IPv4 invalid protocol version (Error)
  \param  ip_version    not IPv4 protocol version value
                         - 0..3
                         - 5..15
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP4_InvalidIpVersion(uint8_t ip_version) {
    EventRecord2 (EvtNetIP4_InvalidIpVersion, ip_version, 0);
  }
#else
  #define EvrNetIP4_InvalidIpVersion(ip_version)
#endif

/**
  \brief  Event on IPv4 frame header info (Detail)
  \param  ip4_header    pointer to IPv4 frame header of 20 bytes
                         - VerHlen  (1 byte)
                         - Tos      (1 byte)
                         - Len      (2 bytes)
                         - Id       (2 bytes)
                         - FragOffs (2 bytes)
                         - Ttl      (1 byte)
                         - Proto    (1 byte)
                         - Chksum   (2 bytes)
                         - SrcAddr  (4 bytes)
                         - DstAddr  (4 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP4_HeaderInfo(const void *ip4_header) {
    EventRecordData (EvtNetIP4_HeaderInfo, ip4_header, 20);
  }
#else
  #define EvrNetIP4_HeaderInfo(ip4_header)
#endif

/**
  \brief  Event on IPv4 source IP address invalid (Error)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP4_SourceIpAddressInvalid(const uint8_t *ip4_address) {
    EventRecordData (EvtNetIP4_SourceIpAddressInvalid, ip4_address, 4);
  }
#else
  #define EvrNetIP4_SourceIpAddressInvalid(ip4_address)
#endif

/**
  \brief  Event on IPv4 wrong multicast protocol type (Error)
  \param  ip4_protocol  wrong protocol type value
  \note   Only UDP and IGMP multicast frames are allowed!
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP4_WrongMulticastProtocol(uint8_t ip4_protocol) {
    EventRecord2 (EvtNetIP4_WrongMulticastProtocol, ip4_protocol, 0);
  }
#else
  #define EvrNetIP4_WrongMulticastProtocol(ip4_protocol)
#endif

/**
  \brief  Event on IPv4 wrong destination address (Op)
  \param  ip4_address   pointer to IPv4 destination address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP4_WrongDestinationAddress(const uint8_t *ip4_address) {
    EventRecordData (EvtNetIP4_WrongDestinationAddress, ip4_address, 4);
  }
#else
  #define EvrNetIP4_WrongDestinationAddress(ip4_address)
#endif

/**
  \brief  Event on IP4 frame checksum check failed (Error)
  \param  length        header length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP4_ChecksumFailed(uint32_t length) {
    EventRecord2 (EvtNetIP4_ChecksumFailed, length, 0);
  }
#else
  #define EvrNetIP4_ChecksumFailed(length)
#endif

/**
  \brief  Event on IP4 fragmented frame received (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP4_FragmentsNotSupported(void) {
    EventRecord2 (EvtNetIP4_FragmentsNotSupported, 0, 0);
  }
#else
  #define EvrNetIP4_FragmentsNotSupported()
#endif

/**
  \brief  Event on IP4 send frame (Op)
  \param  ip4_protocol  IPv4 protocol type
                         - 1:  ICMP
                         - 2:  IGMP
                         - 6:  TCP
                         - 17: UDP
  \param  length        frame length
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP4_SendFrame(uint8_t ip4_protocol, uint32_t length) {
    EventRecord2 (EvtNetIP4_SendFrame, ip4_protocol, length);
  }
#else
  #define EvrNetIP4_SendFrame(ip4_protocol, length)
#endif

/**
  \brief  Event on IP4 unknown protocol type in sending frame (Error)
  \param  ip4_protocol  unknown IPv4 protocol type value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP4_ProtocolUnknown(uint8_t ip4_protocol) {
    EventRecord2 (EvtNetIP4_ProtocolUnknown, ip4_protocol, 0);
  }
#else
  #define EvrNetIP4_ProtocolUnknown(ip4_protocol)
#endif

/**
  \brief  Event on IP4 destination address not provided (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP4_DestinationAddressNull(void) {
    EventRecord2 (EvtNetIP4_DestinationAddressNull, 0, 0);
  }
#else
  #define EvrNetIP4_DestinationAddressNull()
#endif

// NetICMP event identifiers ---------------------------------------------------
#ifdef DEBUG_EVR
/* ICMP-Core events */
#define EvtNetICMP_ReceiveFrame             EventID (EventLevelOp,    EvtNetICMP,  0)
#define EvtNetICMP_FrameTooShort            EventID (EventLevelError, EvtNetICMP,  1)
#define EvtNetICMP_ChecksumFailed           EventID (EventLevelError, EvtNetICMP,  2)
#define EvtNetICMP_EchoRequestWrongCode     EventID (EventLevelError, EvtNetICMP,  3)
#define EvtNetICMP_EchoRequestReceived      EventID (EventLevelOp,    EvtNetICMP,  4)
#define EvtNetICMP_SendEchoReply            EventID (EventLevelOp,    EvtNetICMP,  5)
#define EvtNetICMP_EchoReplyReceived        EventID (EventLevelOp,    EvtNetICMP,  6)
#define EvtNetICMP_EchoReplyWrongState      EventID (EventLevelError, EvtNetICMP,  7)
#define EvtNetICMP_EchoReplyWrongCode       EventID (EventLevelError, EvtNetICMP,  8)
#define EvtNetICMP_EchoReplyWrongIpAddress  EventID (EventLevelError, EvtNetICMP,  9)
#define EvtNetICMP_EchoReplyWrongId         EventID (EventLevelError, EvtNetICMP, 10)
#define EvtNetICMP_EchoReplyWrongPayload    EventID (EventLevelError, EvtNetICMP, 11)
#define EvtNetICMP_MessageTypeUnknown       EventID (EventLevelOp,    EvtNetICMP, 12)
#define EvtNetICMP_SendEchoRequest          EventID (EventLevelOp,    EvtNetICMP, 13)
/* ICMP-Ping client events */
#define EvtNetICMP_PingInit                 EventID (EventLevelOp,    EvtNetICMP, 14)
#define EvtNetICMP_PingInvalidParameter     EventID (EventLevelError, EvtNetICMP, 15)
#define EvtNetICMP_PingClientBusy           EventID (EventLevelError, EvtNetICMP, 16)
#define EvtNetICMP_PingSendRequest          EventID (EventLevelAPI,   EvtNetICMP, 17)
#define EvtNetICMP_PingRetransmitRequest    EventID (EventLevelOp,    EvtNetICMP, 18)
#define EvtNetICMP_PingTimeout              EventID (EventLevelOp,    EvtNetICMP, 19)
#endif

/**
  \brief  Event on ICMP receive frame (Op)
  \param  icmp_header   pointer to ICMP frame header of 8 bytes
                         - Type    (1 byte)
                         - Code    (1 byte)
                         - Chksum  (2 bytes)
                         - EchoId  (2 bytes)
                         - EchoSeq (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_ReceiveFrame(const void *icmp_header) {
    EventRecordData (EvtNetICMP_ReceiveFrame, icmp_header, 8);
  }
#else
  #define EvrNetICMP_ReceiveFrame(icmp_header)
#endif

/**
  \brief  Event on ICMP received frame is too short (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_FrameTooShort(uint32_t length) {
    EventRecord2 (EvtNetICMP_FrameTooShort, length, 0);
  }
#else
  #define EvrNetICMP_FrameTooShort(length)
#endif

/**
  \brief  Event on ICMP frame checksum check failed (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_ChecksumFailed(uint32_t length) {
    EventRecord2 (EvtNetICMP_ChecksumFailed, length, 0);
  }
#else
  #define EvrNetICMP_ChecksumFailed(length)
#endif

/**
  \brief  Event on ICMP wrong code in echo request received (Error)
  \param  icmp_code     wrong ICMP code value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_EchoRequestWrongCode(uint8_t icmp_code) {
    EventRecord2 (EvtNetICMP_EchoRequestWrongCode, icmp_code, 0);
  }
#else
  #define EvrNetICMP_EchoRequestWrongCode(icmp_code)
#endif

/**
  \brief  Event on ICMP echo request received (Op)
  \param  data_length   length of the payload data
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_EchoRequestReceived(uint32_t data_length) {
    EventRecord2 (EvtNetICMP_EchoRequestReceived, data_length, 0);
  }
#else
  #define EvrNetICMP_EchoRequestReceived(data_length)
#endif

/**
  \brief  Event on ICMP send echo reply (Op)
  \param  icmp_header   pointer to ICMP frame header of 8 bytes
                         - Type    (1 byte)
                         - Code    (1 byte)
                         - Chksum  (2 bytes)
                         - EchoId  (2 bytes)
                         - EchoSeq (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_SendEchoReply(const void *icmp_header) {
    EventRecordData (EvtNetICMP_SendEchoReply, icmp_header, 8);
  }
#else
  #define EvrNetICMP_SendEchoReply(icmp_header)
#endif

/**
  \brief  Event on ICMP echo reply received (Op)
  \param  data_length   length of the payload data
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_EchoReplyReceived(uint32_t data_length) {
    EventRecord2 (EvtNetICMP_EchoReplyReceived, data_length, 0);
  }
#else
  #define EvrNetICMP_EchoReplyReceived(data_length)
#endif

/**
  \brief  Event on ICMP echo reply received in wrong ping process state (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_EchoReplyWrongState(void) {
    EventRecord2 (EvtNetICMP_EchoReplyWrongState, 0, 0);
  }
#else
  #define EvrNetICMP_EchoReplyWrongState()
#endif

/**
  \brief  Event on ICMP wrong code in echo reply received (Error)
  \param  icmp_code     wrong ICMP code value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_EchoReplyWrongCode(uint8_t icmp_code) {
    EventRecord2 (EvtNetICMP_EchoReplyWrongCode, icmp_code, 0);
  }
#else
  #define EvrNetICMP_EchoReplyWrongCode(icmp_code)
#endif

/**
  \brief  Event on ICMP wrong source IPv4 address of echo reply (Error)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_EchoReplyWrongIpAddress(const uint8_t *ip4_address) {
    EventRecordData (EvtNetICMP_EchoReplyWrongIpAddress, ip4_address, 4);
  }
#else
  #define EvrNetICMP_EchoReplyWrongIpAddress(ip4_address)
#endif

/**
  \brief  Event on ICMP wrong echo identifier value in echo reply (Error)
  \param  echo_id       wrong echo identifier value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_EchoReplyWrongId(uint16_t echo_id) {
    EventRecord2 (EvtNetICMP_EchoReplyWrongId, echo_id, 0);
  }
#else
  #define EvrNetICMP_EchoReplyWrongId(echo_id)
#endif

/**
  \brief  Event on ICMP echo reply payload data invalid (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_EchoReplyWrongPayload(void) {
    EventRecord2 (EvtNetICMP_EchoReplyWrongPayload, 0, 0);
  }
#else
  #define EvrNetICMP_EchoReplyWrongPayload()
#endif

/**
  \brief  Event on ICMP message type unknown (Op)
  \param  icmp_type     wrong ICMP message type value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_MessageTypeUnknown(uint8_t icmp_type) {
    EventRecord2 (EvtNetICMP_MessageTypeUnknown, icmp_type, 0);
  }
#else
  #define EvrNetICMP_MessageTypeUnknown(icmp_type)
#endif

/**
  \brief  Event on ICMP send echo request (Op)
  \param  icmp_header   pointer to ICMP frame header of 8 bytes
                         - Type    (1 byte)
                         - Code    (1 byte)
                         - Chksum  (2 bytes)
                         - EchoId  (2 bytes)
                         - EchoSeq (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_SendEchoRequest(const void *icmp_header) {
    EventRecordData (EvtNetICMP_SendEchoRequest, icmp_header, 8);
  }
#else
  #define EvrNetICMP_SendEchoRequest(icmp_header)
#endif

// ICMP ping client event recorder functions -----------------------------------

/**
  \brief  Event on ICMP ping client initialize (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_PingInit(void) {
    EventRecord2 (EvtNetICMP_PingInit, 0, 0);
  }
#else
  #define EvrNetICMP_PingInit()
#endif

/**
  \brief  Event on ICMP \ref netPing_Echo invalid parameter (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_PingInvalidParameter(void) {
    EventRecord2 (EvtNetICMP_PingInvalidParameter, 0, 0);
  }
#else
  #define EvrNetICMP_PingInvalidParameter()
#endif

/**
  \brief  Event on ICMP \ref netPing_Echo client busy (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_PingClientBusy(void) {
    EventRecord2 (EvtNetICMP_PingClientBusy, 0, 0);
  }
#else
  #define EvrNetICMP_PingClientBusy()
#endif

/**
  \brief  Event on ICMP \ref netPing_Echo send echo request (API)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_PingSendRequest(void) {
    EventRecord2 (EvtNetICMP_PingSendRequest, 0, 0);
  }
#else
  #define EvrNetICMP_PingSendRequest()
#endif

/**
  \brief  Event on ICMP retransmit echo request (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_PingRetransmitRequest(void) {
    EventRecord2 (EvtNetICMP_PingRetransmitRequest, 0, 0);
  }
#else
  #define EvrNetICMP_PingRetransmitRequest()
#endif

/**
  \brief  Event on ICMP timeout on ping send echo request (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP_PingTimeout(void) {
    EventRecord2 (EvtNetICMP_PingTimeout, 0, 0);
  }
#else
  #define EvrNetICMP_PingTimeout()
#endif

// NetIGMP event identifiers ---------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetIGMP_InitManager              EventID (EventLevelOp,    EvtNetIGMP,  0)
#define EvtNetIGMP_Join                     EventID (EventLevelAPI,   EvtNetIGMP,  1)
#define EvtNetIGMP_AlreadyInGroup           EventID (EventLevelOp,    EvtNetIGMP,  2)
#define EvtNetIGMP_NoFreeEntries            EventID (EventLevelError, EvtNetIGMP,  3)
#define EvtNetIGMP_SendReport               EventID (EventLevelOp,    EvtNetIGMP,  4)
#define EvtNetIGMP_Leave                    EventID (EventLevelAPI,   EvtNetIGMP,  5)
#define EvtNetIGMP_NotInGroup               EventID (EventLevelError, EvtNetIGMP,  6)
#define EvtNetIGMP_SendLeave                EventID (EventLevelOp,    EvtNetIGMP,  7)
#define EvtNetIGMP_ReceiveFrame             EventID (EventLevelOp,    EvtNetIGMP,  8)
#define EvtNetIGMP_FrameTooShort            EventID (EventLevelError, EvtNetIGMP,  9)
#define EvtNetIGMP_ChecksumFailed           EventID (EventLevelError, EvtNetIGMP, 10)
#define EvtNetIGMP_GroupSpecificQuery       EventID (EventLevelOp,    EvtNetIGMP, 11)
#define EvtNetIGMP_DestAddressWrong         EventID (EventLevelError, EvtNetIGMP, 12)
#define EvtNetIGMP_DelayedReportScheduled   EventID (EventLevelOp,    EvtNetIGMP, 13)
#define EvtNetIGMP_GeneralQuery             EventID (EventLevelOp,    EvtNetIGMP, 14)
#define EvtNetIGMP_StartModeIGMPv1          EventID (EventLevelOp,    EvtNetIGMP, 15)
#define EvtNetIGMP_MaxTimeForReport         EventID (EventLevelOp,    EvtNetIGMP, 16)
#define EvtNetIGMP_GroupReportsScheduled    EventID (EventLevelOp,    EvtNetIGMP, 17)
#define EvtNetIGMP_ReportReceived           EventID (EventLevelOp,    EvtNetIGMP, 18)
#define EvtNetIGMP_OwnReportCanceled        EventID (EventLevelOp,    EvtNetIGMP, 19)
#define EvtNetIGMP_StartModeIGMPv2          EventID (EventLevelOp,    EvtNetIGMP, 20)
#define EvtNetIGMP_SendDelayedReport        EventID (EventLevelOp,    EvtNetIGMP, 21)
#endif

/**
  \brief  Event on IGMP manager initialize (Op)
  \param  entries       number of entries available in membership table
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_InitManager(uint32_t entries) {
    EventRecord2 (EvtNetIGMP_InitManager, entries, 0);
  }
#else
  #define EvrNetIGMP_InitManager(entries)
#endif

/**
  \brief  Event on IGMP \ref netIGMP_Join start (API)
  \param  ip4_address   pointer to IPv4 address of a group
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_Join(const uint8_t *ip4_address) {
    EventRecordData (EvtNetIGMP_Join, ip4_address, 4);
  }
#else
  #define EvrNetIGMP_Join(ip4_address)
#endif

/**
  \brief  Event on IGMP \ref netIGMP_Join already a member (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_AlreadyInGroup(void) {
    EventRecord2 (EvtNetIGMP_AlreadyInGroup, 0, 0);
  }
#else
  #define EvrNetIGMP_AlreadyInGroup()
#endif

/**
  \brief  Event on IGMP \ref netIGMP_Join no free entries available (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_NoFreeEntries(void) {
    EventRecord2 (EvtNetIGMP_NoFreeEntries, 0, 0);
  }
#else
  #define EvrNetIGMP_NoFreeEntries()
#endif

/**
  \brief  Event on IGMP send report message (Op)
  \param  ip4_address   pointer to IPv4 address of a group
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_SendReport(const uint8_t *ip4_address) {
    EventRecordData (EvtNetIGMP_SendReport, ip4_address, 4);
  }
#else
  #define EvrNetIGMP_SendReport(ip4_address)
#endif

/**
  \brief  Event on IGMP \ref netIGMP_Leave start (API)
  \param  ip4_address   pointer to IPv4 address of a group
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_Leave(const uint8_t *ip4_address) {
    EventRecordData (EvtNetIGMP_Leave, ip4_address, 4);
  }
#else
  #define EvrNetIGMP_Leave(ip4_address)
#endif

/**
  \brief  Event on IGMP \ref netIGMP_Leave not a member (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_NotInGroup(void) {
    EventRecord2 (EvtNetIGMP_NotInGroup, 0, 0);
  }
#else
  #define EvrNetIGMP_NotInGroup()
#endif

/**
  \brief  Event on IGMP send leave message (Op)
  \param  ip4_address   pointer to IPv4 address of a group
*/
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_SendLeave(const uint8_t *ip4_address) {
    EventRecordData (EvtNetIGMP_SendLeave, ip4_address, 4);
  }
#else
  #define EvrNetIGMP_SendLeave(ip4_address)
#endif

/**
  \brief  Event on IGMP receive frame (Op)
  \param  message_type  type of received message
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_ReceiveFrame(uint8_t message_type) {
    EventRecord2 (EvtNetIGMP_ReceiveFrame, message_type, 0);
  }
#else
  #define EvrNetIGMP_ReceiveFrame(message_type)
#endif

/**
  \brief  Event on IGMP received frame is too short (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_FrameTooShort(uint32_t length) {
    EventRecord2 (EvtNetIGMP_FrameTooShort, length, 0);
  }
#else
  #define EvrNetIGMP_FrameTooShort(length)
#endif

/**
  \brief  Event on IGMP frame checksum check failed (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_ChecksumFailed(void) {
    EventRecord2 (EvtNetIGMP_ChecksumFailed, 0, 0);
  }
#else
  #define EvrNetIGMP_ChecksumFailed()
#endif

/**
  \brief  Event on IGMPv2 group specific query (Op)
  \param  ip4_address   pointer to IPv4 address of a group
*/
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_GroupSpecificQuery(const uint8_t *ip4_address) {
    EventRecordData (EvtNetIGMP_GroupSpecificQuery, ip4_address, 4);
  }
#else
  #define EvrNetIGMP_GroupSpecificQuery(ip4_address)
#endif

/**
  \brief  Event on IGMPv2 destination address wrong (Error)
  \param  ip4_address   pointer to IPv4 address of a group
*/
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_DestAddressWrong(const uint8_t *ip4_address) {
    EventRecordData (EvtNetIGMP_DestAddressWrong, ip4_address, 4);
  }
#else
  #define EvrNetIGMP_DestAddressWrong(ip4_address)
#endif

/**
  \brief  Event on IGMPv2 report message delayed (Op)
  \param  max_time      maximum delay time in 100 ms ticks
*/
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_DelayedReportScheduled(uint8_t max_time) {
    EventRecord2 (EvtNetIGMP_DelayedReportScheduled, max_time, 0);
  }
#else
  #define EvrNetIGMP_DelayedReportScheduled(max_time)
#endif

/**
  \brief  Event on IGMPv1 general query (Op)
  \param  ip4_address   pointer to IPv4 address of a group
*/
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_GeneralQuery(const uint8_t *ip4_address) {
    EventRecordData (EvtNetIGMP_GeneralQuery, ip4_address, 4);
  }
#else
  #define EvrNetIGMP_GeneralQuery(ip4_address)
#endif

/**
  \brief  Event on start IGMPv1 mode (Op)
*/
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_StartModeIGMPv1(void) {
    EventRecord2 (EvtNetIGMP_StartModeIGMPv1, 0, 0);
  }
#else
  #define EvrNetIGMP_StartModeIGMPv1()
#endif

/**
  \brief  Event on IGMPv2 maximum time for report messages (Op)
  \param  max_time      maximum delay time in 100 ms ticks
*/
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_MaxTimeForReport(uint8_t max_time) {
    EventRecord2 (EvtNetIGMP_MaxTimeForReport, max_time, 0);
  }
#else
  #define EvrNetIGMP_MaxTimeForReport(max_time)
#endif

/**
  \brief  Event on IGMP scheduled reports for all active groups (Op)
  \param  n_reports     number of scheduled reports
*/
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_GroupReportsScheduled(uint32_t n_reports) {
    EventRecord2 (EvtNetIGMP_GroupReportsScheduled, n_reports, 0);
  }
#else
  #define EvrNetIGMP_GroupReportsScheduled(n_reports)
#endif

/**
  \brief  Event on IGMP received report message (Op)
  \param  ip4_address   pointer to IPv4 address of a group
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_ReportReceived(const uint8_t *ip4_address) {
    EventRecordData (EvtNetIGMP_ReportReceived, ip4_address, 4);
  }
#else
  #define EvrNetIGMP_ReportReceived(ip4_address)
#endif

/**
  \brief  Event on own report canceled (Op)
*/
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_OwnReportCanceled(void) {
    EventRecord2 (EvtNetIGMP_OwnReportCanceled, 0, 0);
  }
#else
  #define EvrNetIGMP_OwnReportCanceled()
#endif

/**
  \brief  Event on start IGMPv2 mode (Op)
*/
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_StartModeIGMPv2(void) {
    EventRecord2 (EvtNetIGMP_StartModeIGMPv2, 0, 0);
  }
#else
  #define EvrNetIGMP_StartModeIGMPv2()
#endif

/**
  \brief  Event on IGMP send delayed report message (Op)
  \param  ip4_address   pointer to IPv4 address of a group
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIGMP_SendDelayedReport(const uint8_t *ip4_address) {
    EventRecordData (EvtNetIGMP_SendDelayedReport, ip4_address, 4);
  }
#else
  #define EvrNetIGMP_SendDelayedReport(ip4_address)
#endif


// NetNBNS event identifiers ---------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetNBNS_InitService              EventID (EventLevelOp,    EvtNetNBNS, 0)
#define EvtNetNBNS_GetSocketFailed          EventID (EventLevelError, EvtNetNBNS, 1)
#define EvtNetNBNS_ReceiveFrame             EventID (EventLevelOp,    EvtNetNBNS, 2)
#define EvtNetNBNS_WrongPort                EventID (EventLevelError, EvtNetNBNS, 3)
#define EvtNetNBNS_FrameTooShort            EventID (EventLevelError, EvtNetNBNS, 4)
#define EvtNetNBNS_NameQueryRequest         EventID (EventLevelOp,    EvtNetNBNS, 5)
#define EvtNetNBNS_QueryFromAddress         EventID (EventLevelOp,    EvtNetNBNS, 6)
#define EvtNetNBNS_NameQueryResponse        EventID (EventLevelOp,    EvtNetNBNS, 7)
#endif

/**
  \brief  Event on NBNS name service initialize (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNBNS_InitService(void) {
    EventRecord2 (EvtNetNBNS_InitService, 0, 0);
  }
#else
  #define EvrNetNBNS_InitService()
#endif

/**
  \brief  Event on NBNS failed to allocate UDP socket (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNBNS_GetSocketFailed(void) {
    EventRecord2 (EvtNetNBNS_GetSocketFailed, 0, 0);
  }
#else
  #define EvrNetNBNS_GetSocketFailed()
#endif

/**
  \brief  Event on NBNS receive frame (Op)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNBNS_ReceiveFrame(uint32_t length) {
    EventRecord2 (EvtNetNBNS_ReceiveFrame, length, 0);
  }
#else
  #define EvrNetNBNS_ReceiveFrame(length)
#endif

/**
  \brief  Event on NBNS wrong UDP source port (Error)
  \param  udp_port      wrong port number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNBNS_WrongPort(uint16_t udp_port) {
    EventRecord2 (EvtNetNBNS_WrongPort, udp_port, 0);
  }
#else
  #define EvrNetNBNS_WrongPort(udp_port)
#endif

/**
  \brief  Event on NBNS received frame is too short (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNBNS_FrameTooShort(uint32_t length) {
    EventRecord2 (EvtNetNBNS_FrameTooShort, length, 0);
  }
#else
  #define EvrNetNBNS_FrameTooShort(length)
#endif

/**
  \brief  Event on NBNS name query request received (Op)
  \param  q_name        pointer to a question name string
  \param  length        length of the question name string
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNBNS_NameQueryRequest(const char *q_name, uint32_t length) {
    if (length > 16) length = 16;
    EventRecordData (EvtNetNBNS_NameQueryRequest, q_name, length);
  }
#else
  #define EvrNetNBNS_NameQueryRequest(q_name, length)
#endif

/**
  \brief  Event on NBNS name query from IP-address (Op)
  \param  ip4_address   pointer to IPv4 address of a host
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNBNS_QueryFromAddress(const uint8_t *ip4_address) {
    EventRecordData (EvtNetNBNS_QueryFromAddress, ip4_address, 4);
  }
#else
  #define EvrNetNBNS_QueryFromAddress(ip4_address)
#endif

/**
  \brief  Event on NBNS response to a name query (Op)
  \param  ip4_address   pointer to local IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNBNS_NameQueryResponse(const uint8_t *ip4_address) {
    EventRecordData (EvtNetNBNS_NameQueryResponse, ip4_address, 4);
  }
#else
  #define EvrNetNBNS_NameQueryResponse(ip4_address)
#endif


// NetDHCP event identifiers ---------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetDHCP_InitClient               EventID (EventLevelOp,    EvtNetDHCP,  0)
#define EvtNetDHCP_GetSocketFailed          EventID (EventLevelError, EvtNetDHCP,  1)
#define EvtNetDHCP_StartClient              EventID (EventLevelOp,    EvtNetDHCP,  2)
#define EvtNetDHCP_StopClient               EventID (EventLevelOp,    EvtNetDHCP,  3)
#define EvtNetDHCP_ClientState              EventID (EventLevelOp,    EvtNetDHCP,  4)
#define EvtNetDHCP_NextState                EventID (EventLevelOp,    EvtNetDHCP,  5)
#define EvtNetDHCP_StateRetransmit          EventID (EventLevelOp,    EvtNetDHCP,  6)
#define EvtNetDHCP_ChangeStateOnTimeout     EventID (EventLevelOp,    EvtNetDHCP,  7)
#define EvtNetDHCP_AutoIpAddressProbe       EventID (EventLevelOp,    EvtNetDHCP,  8)
#define EvtNetDHCP_AutoIpSuccess            EventID (EventLevelOp,    EvtNetDHCP,  9)
#define EvtNetDHCP_T2Expired                EventID (EventLevelOp,    EvtNetDHCP, 10)
#define EvtNetDHCP_LeaseExpired             EventID (EventLevelError, EvtNetDHCP, 11)
#define EvtNetDHCP_SendDhcpMessage          EventID (EventLevelOp,    EvtNetDHCP, 12)
#define EvtNetDHCP_ReceiveFrame             EventID (EventLevelOp,    EvtNetDHCP, 13)
#define EvtNetDHCP_WrongServerPort          EventID (EventLevelError, EvtNetDHCP, 14)
#define EvtNetDHCP_FrameTooShort            EventID (EventLevelError, EvtNetDHCP, 15)
#define EvtNetDHCP_MisformedReply           EventID (EventLevelError, EvtNetDHCP, 16)
#define EvtNetDHCP_WrongTransactionId       EventID (EventLevelError, EvtNetDHCP, 17)
#define EvtNetDHCP_WrongClientHwAddress     EventID (EventLevelError, EvtNetDHCP, 18)
#define EvtNetDHCP_WrongMagicCookie         EventID (EventLevelError, EvtNetDHCP, 19)
#define EvtNetDHCP_NotDhcpOfferMessage      EventID (EventLevelOp,    EvtNetDHCP, 20)
#define EvtNetDHCP_DhcpOfferReceived        EventID (EventLevelOp,    EvtNetDHCP, 21)
#define EvtNetDHCP_FileOverloadedOptions    EventID (EventLevelOp,    EvtNetDHCP, 22)
#define EvtNetDHCP_SnameOverloadedOptions   EventID (EventLevelOp,    EvtNetDHCP, 23)
#define EvtNetDHCP_DhcpOfferServerIdMissing EventID (EventLevelOp,    EvtNetDHCP, 24)
#define EvtNetDHCP_ForwardedMessage         EventID (EventLevelOp,    EvtNetDHCP, 25)
#define EvtNetDHCP_RelayAgentAddressInvalid EventID (EventLevelError, EvtNetDHCP, 26)
#define EvtNetDHCP_ShowRelayAgentAddress    EventID (EventLevelOp,    EvtNetDHCP, 27)
#define EvtNetDHCP_ShowOfferedIpAddress     EventID (EventLevelOp,    EvtNetDHCP, 28)
#define EvtNetDHCP_ServerAddressNotSelected EventID (EventLevelOp,    EvtNetDHCP, 29)
#define EvtNetDHCP_AssignedAddrNotRequested EventID (EventLevelOp,    EvtNetDHCP, 30)
#define EvtNetDHCP_NotDhcpAckMessage        EventID (EventLevelOp,    EvtNetDHCP, 31)
#define EvtNetDHCP_DhcpAckReceived          EventID (EventLevelOp,    EvtNetDHCP, 32)
#define EvtNetDHCP_ShowAssignedAddress      EventID (EventLevelOp,    EvtNetDHCP, 33)
#define EvtNetDHCP_DhcpNakReceived          EventID (EventLevelOp,    EvtNetDHCP, 34)
#define EvtNetDHCP_ShowServerId             EventID (EventLevelOp,    EvtNetDHCP, 35)
#define EvtNetDHCP_ShowNetMask              EventID (EventLevelOp,    EvtNetDHCP, 36)
#define EvtNetDHCP_ShowGatewayAddress       EventID (EventLevelOp,    EvtNetDHCP, 37)
#define EvtNetDHCP_ShowDnsServers           EventID (EventLevelOp,    EvtNetDHCP, 38)
#define EvtNetDHCP_ShowLeaseTime            EventID (EventLevelOp,    EvtNetDHCP, 39)
#define EvtNetDHCP_ShowTimeT1               EventID (EventLevelOp,    EvtNetDHCP, 40)
#define EvtNetDHCP_ShowTimeT2               EventID (EventLevelOp,    EvtNetDHCP, 41)
#define EvtNetDHCP_ShowBootfileName         EventID (EventLevelOp,    EvtNetDHCP, 42)
#define EvtNetDHCP_ShowNtpServerList        EventID (EventLevelOp,    EvtNetDHCP, 43)
#endif

/**
  \brief  Event on DHCP client initialize (Op)
  \param  vcid          Vendor Class Identifier option flag
                         - 0:  not enabled
                         - >0: enabled
  \param  option_flags  DHCP client option flags
                         - 0x01: Opt.67 Bootfile name
                         - 0x02: Opt.42 NTP servers
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_InitClient(uint8_t vcid, uint8_t option_flags) {
    EventRecord2 (EvtNetDHCP_InitClient, vcid, option_flags);
  }
#else
  #define EvrNetDHCP_InitClient(vcid, option_flags)
#endif

/**
  \brief  Event on DHCP failed to allocate UDP socket (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_GetSocketFailed(void) {
    EventRecord2 (EvtNetDHCP_GetSocketFailed, 0, 0);
  }
#else
  #define EvrNetDHCP_GetSocketFailed()
#endif

/**
  \brief  Event on DHCP start client (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_StartClient(void) {
    EventRecord2 (EvtNetDHCP_StartClient, 0, 0);
  }
#else
  #define EvrNetDHCP_StartClient()
#endif

/**
  \brief  Event on DHCP stop client (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_StopClient(void) {
    EventRecord2 (EvtNetDHCP_StopClient, 0, 0);
  }
#else
  #define EvrNetDHCP_StopClient()
#endif

/**
  \brief  Event on DHCP indication of client state (Op)
  \param  state         current state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ClientState(uint32_t state) {
    EventRecord2 (EvtNetDHCP_ClientState, state, 0);
  }
#else
  #define EvrNetDHCP_ClientState(state)
#endif

/**
  \brief  Event on DHCP transition to next state (Op)
  \param  state         next state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_NextState(uint32_t state) {
    EventRecord2 (EvtNetDHCP_NextState, state, 0);
  }
#else
  #define EvrNetDHCP_NextState(state)
#endif

/**
  \brief  Event on DHCP retransmit request in current state (Op)
  \param  state         current state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_StateRetransmit(uint32_t state) {
    EventRecord2 (EvtNetDHCP_StateRetransmit, state, 0);
  }
#else
  #define EvrNetDHCP_StateRetransmit(state)
#endif

/**
  \brief  Event on DHCP state timeout and transit to next state (Op)
  \param  current       current state
  \param  next          next state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ChangeStateOnTimeout(uint32_t current, uint32_t next) {
    EventRecord2 (EvtNetDHCP_ChangeStateOnTimeout, current, next);
  }
#else
  #define EvrNetDHCP_ChangeStateOnTimeout(current, next)
#endif

/**
  \brief  Event on DHCP address probe for AutoIP mode (Op)
  \param  ip4_address   pointer to IP address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_AutoIpAddressProbe(const uint8_t *ip4_address) {
    EventRecordData (EvtNetDHCP_AutoIpAddressProbe, ip4_address, 4);
  }
#else
  #define EvrNetDHCP_AutoIpAddressProbe(ip4_address)
#endif

/**
  \brief  Event on DHCP assign AutoIP address success (Op)
  \param  ip4_address   pointer to assigned AutoIP address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_AutoIpSuccess(const uint8_t *ip4_address) {
    EventRecordData (EvtNetDHCP_AutoIpSuccess, ip4_address, 4);
  }
#else
  #define EvrNetDHCP_AutoIpSuccess(ip4_address)
#endif

/**
  \brief  Event on DHCP timer T2 expired (Op)
  \param  state         current state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_T2Expired(uint32_t state) {
    EventRecord2 (EvtNetDHCP_T2Expired, state, 0);
  }
#else
  #define EvrNetDHCP_T2Expired(state)
#endif

/**
  \brief  Event on DHCP address lease time expired (Error)
  \param  state         current state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_LeaseExpired(uint32_t state) {
    EventRecord2 (EvtNetDHCP_LeaseExpired, state, 0);
  }
#else
  #define EvrNetDHCP_LeaseExpired(state)
#endif

/**
  \brief  Event on DHCP send message (Op)
  \param  msg_type      message type
  \param  broadcast     broadcast the message
                         - 0: no
                         - 1: yes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_SendDhcpMessage(uint8_t msg_type, uint8_t broadcast) {
    EventRecord2 (EvtNetDHCP_SendDhcpMessage, msg_type, broadcast);
  }
#else
  #define EvrNetDHCP_SendDhcpMessage(msg_type, broadcast)
#endif

/**
  \brief  Event on DHCP receive frame (Op)
  \param  ip4_address   pointer to IPv4 address of the server
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ReceiveFrame(const uint8_t *ip4_address) {
    EventRecordData (EvtNetDHCP_ReceiveFrame, ip4_address, 4);
  }
#else
  #define EvrNetDHCP_ReceiveFrame(ip4_address)
#endif

/**
  \brief  Event on DHCP wrong UDP server port (Error)
  \param  udp_port      wrong UDP port number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_WrongServerPort(uint16_t udp_port) {
    EventRecord2 (EvtNetDHCP_WrongServerPort, udp_port, 0);
  }
#else
  #define EvrNetDHCP_WrongServerPort(udp_port)
#endif

/**
  \brief  Event on DHCP received frame is too short (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_FrameTooShort(uint32_t length) {
    EventRecord2 (EvtNetDHCP_FrameTooShort, length, 0);
  }
#else
  #define EvrNetDHCP_FrameTooShort(length)
#endif

/**
  \brief  Event on DHCP received a misformed reply (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_MisformedReply(void) {
    EventRecord2 (EvtNetDHCP_MisformedReply, 0, 0);
  }
#else
  #define EvrNetDHCP_MisformedReply()
#endif

/**
  \brief  Event on DHCP wrong Transaction Id (XID) received (Error)
  \param  xid           wrong Transaction Id value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_WrongTransactionId(uint32_t xid) {
    EventRecord2 (EvtNetDHCP_WrongTransactionId, xid, 0);
  }
#else
  #define EvrNetDHCP_WrongTransactionId(xid)
#endif

/**
  \brief  Event on DHCP wrong Client Hardware Address (CHADDR) received (Error)
  \param  chaddr        pointer to received chaddr address (MAC)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_WrongClientHwAddress(const uint8_t *chaddr) {
    EventRecordData (EvtNetDHCP_WrongClientHwAddress, chaddr, 6);
  }
#else
  #define EvrNetDHCP_WrongClientHwAddress(chaddr)
#endif

/**
  \brief  Event on DHCP wrong BOOTP Magic Cookie received (Error)
  \param  magic_cookie  wrong magic cookie value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_WrongMagicCookie(uint32_t magic_cookie) {
    EventRecord2 (EvtNetDHCP_WrongMagicCookie, magic_cookie, 0);
  }
#else
  #define EvrNetDHCP_WrongMagicCookie(magic_cookie)
#endif

/**
  \brief  Event on DHCP received message is not DHCP_OFFER (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_NotDhcpOfferMessage(void) {
    EventRecord2 (EvtNetDHCP_NotDhcpOfferMessage, 0, 0);
  }
#else
  #define EvrNetDHCP_NotDhcpOfferMessage()
#endif

/**
  \brief  Event on DHCP received DHCP_OFFER message (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_DhcpOfferReceived(void) {
    EventRecord2 (EvtNetDHCP_DhcpOfferReceived, 0, 0);
  }
#else
  #define EvrNetDHCP_DhcpOfferReceived()
#endif

/**
  \brief  Event on DHCP received options overloaded to "File" field (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_FileOverloadedOptions(void) {
    EventRecord2 (EvtNetDHCP_FileOverloadedOptions, 0, 0);
  }
#else
  #define EvrNetDHCP_FileOverloadedOptions()
#endif

/**
  \brief  Event on DHCP received options overloaded to "Sname" field (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_SnameOverloadedOptions(void) {
    EventRecord2 (EvtNetDHCP_SnameOverloadedOptions, 0, 0);
  }
#else
  #define EvrNetDHCP_SnameOverloadedOptions()
#endif

/**
  \brief  Event on DHCP received DHCP_OFFER with no Server ID (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_DhcpOfferServerIdMissing(void) {
    EventRecord2 (EvtNetDHCP_DhcpOfferServerIdMissing, 0, 0);
  }
#else
  #define EvrNetDHCP_DhcpOfferServerIdMissing()
#endif

/**
  \brief  Event on DHCP received message is forwarded (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ForwardedMessage(void) {
    EventRecord2 (EvtNetDHCP_ForwardedMessage, 0, 0);
  }
#else
  #define EvrNetDHCP_ForwardedMessage()
#endif

/**
  \brief  Event on DHCP message received from invalid Relay Agent address (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_RelayAgentAddressInvalid(void) {
    EventRecord2 (EvtNetDHCP_RelayAgentAddressInvalid, 0, 0);
  }
#else
  #define EvrNetDHCP_RelayAgentAddressInvalid()
#endif

/**
  \brief  Event on DHCP display relay agent IP address (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ShowRelayAgentAddress(const uint8_t *ip4_address) {
    EventRecordData (EvtNetDHCP_ShowRelayAgentAddress, ip4_address, 4);
  }
#else
  #define EvrNetDHCP_ShowRelayAgentAddress(ip4_address)
#endif

/**
  \brief  Event on DHCP display offered IP address (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ShowOfferedIpAddress(const uint8_t *ip4_address) {
    EventRecordData (EvtNetDHCP_ShowOfferedIpAddress, ip4_address, 4);
  }
#else
  #define EvrNetDHCP_ShowOfferedIpAddress(ip4_address)
#endif

/**
  \brief  Event on DHCP received message is not from selected server (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ServerAddressNotSelected(const uint8_t *ip4_address) {
    EventRecordData (EvtNetDHCP_ServerAddressNotSelected, ip4_address, 4);
  }
#else
  #define EvrNetDHCP_ServerAddressNotSelected(ip4_address)
#endif

/**
  \brief  Event on DHCP assigned IP address in DHCP_ACK not the same as requested (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_AssignedAddrNotRequested(const uint8_t *ip4_address) {
    EventRecordData (EvtNetDHCP_AssignedAddrNotRequested, ip4_address, 4);
  }
#else
  #define EvrNetDHCP_AssignedAddrNotRequested(ip4_address)
#endif

/**
  \brief  Event on DHCP received message is not DHCP_ACK (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_NotDhcpAckMessage(void) {
    EventRecord2 (EvtNetDHCP_NotDhcpAckMessage, 0, 0);
  }
#else
  #define EvrNetDHCP_NotDhcpAckMessage()
#endif

/**
  \brief  Event on DHCP received DHCP_ACK message (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_DhcpAckReceived(void) {
    EventRecord2 (EvtNetDHCP_DhcpAckReceived, 0, 0);
  }
#else
  #define EvrNetDHCP_DhcpAckReceived()
#endif

/**
  \brief  Event on DHCP display assigned IP address (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ShowAssignedAddress(const uint8_t *ip4_address) {
    EventRecordData (EvtNetDHCP_ShowAssignedAddress, ip4_address, 4);
  }
#else
  #define EvrNetDHCP_ShowAssignedAddress(ip4_address)
#endif

/**
  \brief  Event on DHCP received DHCP_NAK message (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_DhcpNakReceived(void) {
    EventRecord2 (EvtNetDHCP_DhcpNakReceived, 0, 0);
  }
#else
  #define EvrNetDHCP_DhcpNakReceived()
#endif

/**
  \brief  Event on DHCP display Server Identifier (IP address) (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ShowServerId(const uint8_t *ip4_address) {
    EventRecordData (EvtNetDHCP_ShowServerId, ip4_address, 4);
  }
#else
  #define EvrNetDHCP_ShowServerId(ip4_address)
#endif

/**
  \brief  Event on DHCP display Network Mask (Op)
  \param  net_mask      pointer to network mask
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ShowNetMask(const uint8_t *net_mask) {
    EventRecordData (EvtNetDHCP_ShowNetMask, net_mask, 4);
  }
#else
  #define EvrNetDHCP_ShowNetMask(net_mask)
#endif

/**
  \brief  Event on DHCP display gateway IPv4 address (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ShowGatewayAddress(const uint8_t *ip4_address) {
    EventRecordData (EvtNetDHCP_ShowGatewayAddress, ip4_address, 4);
  }
#else
  #define EvrNetDHCP_ShowGatewayAddress(ip4_address)
#endif

/**
  \brief  Event on DHCP display DNS server addresses (Op)
  \param  dns_list      pointer to DNS server address list
  \note   Displays primary and secondary DNS server address.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ShowDnsServers(const uint8_t *dns_list) {
    EventRecordData (EvtNetDHCP_ShowDnsServers, dns_list, 8);
  }
#else
  #define EvrNetDHCP_ShowDnsServers(dns_list)
#endif

/**
  \brief  Event on DHCP display address lease time (Op)
  \param  lease_time    lease time in seconds
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ShowLeaseTime(uint32_t lease_time) {
    EventRecord2 (EvtNetDHCP_ShowLeaseTime, lease_time, 0);
  }
#else
  #define EvrNetDHCP_ShowLeaseTime(lease_time)
#endif

/**
  \brief  Event on DHCP display renewal time T1 (Op)
  \param  t1_time       t1 time in seconds
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ShowTimeT1(uint32_t t1_time) {
    EventRecord2 (EvtNetDHCP_ShowTimeT1, t1_time, 0);
  }
#else
  #define EvrNetDHCP_ShowTimeT1(t1_time)
#endif

/**
  \brief  Event on DHCP display rebinding time T2 (Op)
  \param  t2_time       t2 time in seconds
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ShowTimeT2(uint32_t t2_time) {
    EventRecord2 (EvtNetDHCP_ShowTimeT2, t2_time, 0);
  }
#else
  #define EvrNetDHCP_ShowTimeT2(t2_time)
#endif

/**
  \brief  Event on DHCP display Bootfile Name (Op)
  \param  bootfile      bootfile name string
  \param  length        length of the bootfile name string
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ShowBootfileName(const uint8_t *bootfile, uint32_t length) {
    if (length > 128) length = 128;
    EventRecordData (EvtNetDHCP_ShowBootfileName, bootfile, length);
  }
#else
  #define EvrNetDHCP_ShowBootfileName(bootfile, length)
#endif

/**
  \brief  Event on DHCP display a list of NTP server addresses (Op)
  \param  ntp_list      pointer to an array of NTP server IP addresses
  \param  length        length of an array in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP_ShowNtpServerList(const uint8_t *ntp_list, uint32_t length) {
    if (length > 64) length = 64;
    EventRecordData (EvtNetDHCP_ShowNtpServerList, ntp_list, length);
  }
#else
  #define EvrNetDHCP_ShowNtpServerList(ntp_list, length)
#endif


// NetARP event identifiers ----------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetARP_InitCache                 EventID (EventLevelOp,    EvtNetARP,  0)
#define EvtNetARP_ReceiveFrame              EventID (EventLevelOp,    EvtNetARP,  1)
#define EvtNetARP_FrameTooShort             EventID (EventLevelError, EvtNetARP,  2)
#define EvtNetARP_FrameCorrupted            EventID (EventLevelError, EvtNetARP,  3)
#define EvtNetARP_HeaderInfo                EventID (EventLevelDetail,EvtNetARP,  4)
#define EvtNetARP_CacheEntryUpdate          EventID (EventLevelOp,    EvtNetARP,  5)
#define EvtNetARP_ProbeResponseReceived     EventID (EventLevelOp,    EvtNetARP,  6)
#define EvtNetARP_WrongIpAddress            EventID (EventLevelOp,    EvtNetARP,  7)
#define EvtNetARP_WrongMacAddress           EventID (EventLevelOp,    EvtNetARP,  8)
#define EvtNetARP_OpcodeUnknown             EventID (EventLevelOp,    EvtNetARP,  9)
#define EvtNetARP_SendReply                 EventID (EventLevelOp,    EvtNetARP, 10)
#define EvtNetARP_CacheEntryRefreshed       EventID (EventLevelOp,    EvtNetARP, 11)
#define EvtNetARP_WrongResponse             EventID (EventLevelError, EvtNetARP, 12)
#define EvtNetARP_SendRequest               EventID (EventLevelOp,    EvtNetARP, 13)
#define EvtNetARP_CacheAllocFailed          EventID (EventLevelError, EvtNetARP, 14)
#define EvtNetARP_CacheIpRefreshed          EventID (EventLevelOp,    EvtNetARP, 15)
#define EvtNetARP_CacheAdd                  EventID (EventLevelOp,    EvtNetARP, 16)
#define EvtNetARP_ShowMacAddress            EventID (EventLevelOp,    EvtNetARP, 17)
#define EvtNetARP_GatewayUnknown            EventID (EventLevelError, EvtNetARP, 18)
#define EvtNetARP_EntryAdded                EventID (EventLevelOp,    EvtNetARP, 19)
#define EvtNetARP_CacheEarly                EventID (EventLevelOp,    EvtNetARP, 20)
#define EvtNetARP_CacheFind                 EventID (EventLevelOp,    EvtNetARP, 21)
#define EvtNetARP_UsingGateway              EventID (EventLevelOp,    EvtNetARP, 22)
#define EvtNetARP_UnresolvedMacAddress      EventID (EventLevelError, EvtNetARP, 23)
#define EvtNetARP_EntryFound                EventID (EventLevelOp,    EvtNetARP, 24)
#define EvtNetARP_CacheIp                   EventID (EventLevelAPI,   EvtNetARP, 25)
#define EvtNetARP_CacheIpInvalidParameter   EventID (EventLevelError, EvtNetARP, 26)
#define EvtNetARP_CacheMac                  EventID (EventLevelAPI,   EvtNetARP, 27)
#define EvtNetARP_CacheMacInvalidParameter  EventID (EventLevelError, EvtNetARP, 28)
#define EvtNetARP_UnresolvedIpAddress       EventID (EventLevelError, EvtNetARP, 29)
#define EvtNetARP_GetIp                     EventID (EventLevelAPI,   EvtNetARP, 30)
#define EvtNetARP_GetIpInvalidParameter     EventID (EventLevelError, EvtNetARP, 31)
#define EvtNetARP_ShowIpAddress             EventID (EventLevelOp,    EvtNetARP, 32)
#define EvtNetARP_EntryNotFound             EventID (EventLevelOp,    EvtNetARP, 33)
#define EvtNetARP_GetMac                    EventID (EventLevelAPI,   EvtNetARP, 34)
#define EvtNetARP_GetMacInvalidParameter    EventID (EventLevelError, EvtNetARP, 35)
#define EvtNetARP_Probe                     EventID (EventLevelAPI,   EvtNetARP, 36)
#define EvtNetARP_ProbeInvalidParameter     EventID (EventLevelError, EvtNetARP, 37)
#define EvtNetARP_ProbeBusy                 EventID (EventLevelError, EvtNetARP, 38)
#define EvtNetARP_ProbeRetransmit           EventID (EventLevelOp,    EvtNetARP, 39)
#define EvtNetARP_ProbeTimeout              EventID (EventLevelOp,    EvtNetARP, 40)
#define EvtNetARP_CacheEntryTimeout         EventID (EventLevelOp,    EvtNetARP, 41)
#define EvtNetARP_EntryReleased             EventID (EventLevelOp,    EvtNetARP, 42)
#define EvtNetARP_ResolveEntry              EventID (EventLevelOp,    EvtNetARP, 43)
#define EvtNetARP_RefreshEntry              EventID (EventLevelOp,    EvtNetARP, 44)
#endif

/**
  \brief  Event on ARP cache initialize (Op)
  \param  entries       number of entries available in cache
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_InitCache(uint32_t entries) {
    EventRecord2 (EvtNetARP_InitCache, entries, 0);
  }
#else
  #define EvrNetARP_InitCache(entries)
#endif

/**
  \brief  Event on ARP receive frame (Op)
  \param  arp_opcode    operation code of received message
                         - 0x0001: ARP Request
                         - 0x0002: ARP Reply
                         - 0x0003: Reverse ARP Request
                         - 0x0004: Reverse ARP Reply
                         - 0x0008: Inverse ARP Request
                         - 0x0009: Inverse ARP Response
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_ReceiveFrame(uint16_t arp_opcode) {
    EventRecord2 (EvtNetARP_ReceiveFrame, arp_opcode, 0);
  }
#else
  #define EvrNetARP_ReceiveFrame(arp_opcode)
#endif

/**
  \brief  Event on ARP received frame is too short (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_FrameTooShort(uint32_t length) {
    EventRecord2 (EvtNetARP_FrameTooShort, length, 0);
  }
#else
  #define EvrNetARP_FrameTooShort(length)
#endif

/**
  \brief  Event on ARP received frame corrupted (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_FrameCorrupted(void) {
    EventRecord2 (EvtNetARP_FrameCorrupted, 0, 0);
  }
#else
  #define EvrNetARP_FrameCorrupted()
#endif

/**
  \brief  Event on ARP send/receive frame header info (Detail)
  \param  arp_header    pointer to ARP frame header of 28 bytes
                         - HwAddrSpace   (2 bytes)
                         - ProtAddrSpace (2 bytes)
                         - HwLen         (1 byte)
                         - ProtLen       (1 byte)
                         - OpCode        (2 bytes)
                         - SrcHwAddr     (6 bytes)
                         - SrcIpAddr     (4 bytes)
                         - DstHwAddr     (6 bytes)
                         - DstIpAddr     (4 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_HeaderInfo(const void *arp_header) {
    EventRecordData (EvtNetARP_HeaderInfo, arp_header, 28);
  }
#else
  #define EvrNetARP_HeaderInfo(arp_header)
#endif

/**
  \brief  Event on ARP cache entry update (Op)
  \param  entry         cache entry number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_CacheEntryUpdate(uint32_t entry) {
    EventRecord2 (EvtNetARP_CacheEntryUpdate, entry, 0);
  }
#else
  #define EvrNetARP_CacheEntryUpdate(entry)
#endif

/**
  \brief  Event on ARP probe response received (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_ProbeResponseReceived(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_ProbeResponseReceived, ip4_address, 4);
  }
#else
  #define EvrNetARP_ProbeResponseReceived(ip4_address)
#endif

/**
  \brief  Event on ARP wrong destination IPv4 address received (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_WrongIpAddress(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_WrongIpAddress, ip4_address, 4);
  }
#else
  #define EvrNetARP_WrongIpAddress(ip4_address)
#endif

/**
  \brief  Event on ARP wrong destination MAC address received (Op)
  \param  mac_address   pointer to MAC address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_WrongMacAddress(const uint8_t *mac_address) {
    EventRecordData (EvtNetARP_WrongMacAddress, mac_address, 6);
  }
#else
  #define EvrNetARP_WrongMacAddress(mac_address)
#endif

/**
  \brief  Event on ARP unknown opcode received (Op)
  \param  arp_opcode    unknown operation code value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_OpcodeUnknown(uint16_t arp_opcode) {
    EventRecord2 (EvtNetARP_OpcodeUnknown, arp_opcode, 0);
  }
#else
  #define EvrNetARP_OpcodeUnknown(arp_opcode)
#endif

/**
  \brief  Event on ARP send reply message (Op)
  \param  arp_opcode    operation code of sending message
                         - 0x0002: ARP Reply
                         - 0x0009: Inverse ARP Response
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_SendReply(uint16_t arp_opcode) {
    EventRecord2 (EvtNetARP_SendReply, arp_opcode, 0);
  }
#else
  #define EvrNetARP_SendReply(arp_opcode)
#endif

/**
  \brief  Event on ARP cache entry refreshed (Op)
  \param  entry         cache entry number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_CacheEntryRefreshed(uint32_t entry) {
    EventRecord2 (EvtNetARP_CacheEntryRefreshed, entry, 0);
  }
#else
  #define EvrNetARP_CacheEntryRefreshed(entry)
#endif

/**
  \brief  Event on ARP wrong response received (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_WrongResponse(void) {
    EventRecord2 (EvtNetARP_WrongResponse, 0, 0);
  }
#else
  #define EvrNetARP_WrongResponse()
#endif

/**
  \brief  Event on ARP send request message (Op)
  \param  arp_opcode    operation code of sending message
                         - 0x0001: ARP Request
                         - 0x0008: Inverse ARP Request
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_SendRequest(uint16_t arp_opcode) {
    EventRecord2 (EvtNetARP_SendRequest, arp_opcode, 0);
  }
#else
  #define EvrNetARP_SendRequest(arp_opcode)
#endif

/**
  \brief  Event on ARP allocate free cache entry failed (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_CacheAllocFailed(void) {
    EventRecord2 (EvtNetARP_CacheAllocFailed, 0, 0);
  }
#else
  #define EvrNetARP_CacheAllocFailed()
#endif

/**
  \brief  Event on ARP cached IP address refreshed (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_CacheIpRefreshed(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_CacheIpRefreshed, ip4_address, 4);
  }
#else
  #define EvrNetARP_CacheIpRefreshed(ip4_address)
#endif

/**
  \brief  Event on ARP cache add IP address (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_CacheAdd(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_CacheAdd, ip4_address, 4);
  }
#else
  #define EvrNetARP_CacheAdd(ip4_address)
#endif

/**
  \brief  Event on ARP cache display MAC address (Op)
  \param  mac_address   pointer to MAC address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_ShowMacAddress(const uint8_t *mac_address) {
    EventRecordData (EvtNetARP_ShowMacAddress, mac_address, 6);
  }
#else
  #define EvrNetARP_ShowMacAddress(mac_address)
#endif

/**
  \brief  Event on ARP cache add gateway unknown (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_GatewayUnknown(void) {
    EventRecord2 (EvtNetARP_GatewayUnknown, 0, 0);
  }
#else
  #define EvrNetARP_GatewayUnknown()
#endif

/**
  \brief  Event on ARP cache entry added (Op)
  \param  entry         cache entry number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_EntryAdded(uint32_t entry) {
    EventRecord2 (EvtNetARP_EntryAdded, entry, 0);
  }
#else
  #define EvrNetARP_EntryAdded(entry)
#endif

/**
  \brief  Event on ARP early cache IP address of the sender (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_CacheEarly(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_CacheEarly, ip4_address, 4);
  }
#else
  #define EvrNetARP_CacheEarly(ip4_address)
#endif

/**
  \brief  Event on ARP find IP address in cache (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_CacheFind(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_CacheFind, ip4_address, 4);
  }
#else
  #define EvrNetARP_CacheFind(ip4_address)
#endif

/**
  \brief  Event on ARP using gateway to access external address (Op)
  \param  ip4_address   pointer to IPv4 address of a gateway
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_UsingGateway(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_UsingGateway, ip4_address, 4);
  }
#else
  #define EvrNetARP_UsingGateway(ip4_address)
#endif

/**
  \brief  Event on ARP unresolved MAC address in cache (Op)
  \param  ip4_address   pointer to requested IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_UnresolvedMacAddress(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_UnresolvedMacAddress, ip4_address, 4);
  }
#else
  #define EvrNetARP_UnresolvedMacAddress(ip4_address)
#endif

/**
  \brief  Event on ARP cache entry found (Op)
  \param  entry         cache entry number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_EntryFound(uint32_t entry) {
    EventRecord2 (EvtNetARP_EntryFound, entry, 0);
  }
#else
  #define EvrNetARP_EntryFound(entry)
#endif

/**
  \brief  Event on \ref netARP_CacheIP start (API)
  \param  ip4_address   pointer to requested IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_CacheIp(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_CacheIp, ip4_address, 4);
  }
#else
  #define EvrNetARP_CacheIp(ip4_address)
#endif

/**
  \brief  Event on \ref netARP_CacheIP invalid parameter (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_CacheIpInvalidParameter(void) {
    EventRecord2 (EvtNetARP_CacheIpInvalidParameter, 0, 0);
  }
#else
  #define EvrNetARP_CacheIpInvalidParameter()
#endif

/**
  \brief  Event on \ref netARP_CacheMAC start (API)
  \param  mac_address   pointer to requested MAC address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_CacheMac(const uint8_t *mac_address) {
    EventRecordData (EvtNetARP_CacheMac, mac_address, 6);
  }
#else
  #define EvrNetARP_CacheMac(mac_address)
#endif

/**
  \brief  Event on \ref netARP_CacheMAC invalid parameter (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_CacheMacInvalidParameter(void) {
    EventRecord2 (EvtNetARP_CacheMacInvalidParameter, 0, 0);
  }
#else
  #define EvrNetARP_CacheMacInvalidParameter()
#endif

/**
  \brief  Event on ARP unresolved IP address in cache (Op)
  \param  mac_address   pointer to MAC cache address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_UnresolvedIpAddress(const uint8_t *mac_address) {
    EventRecordData (EvtNetARP_UnresolvedIpAddress, mac_address, 6);
  }
#else
  #define EvrNetARP_UnresolvedIpAddress(mac_address)
#endif

/**
  \brief  Event on \ref netARP_GetIP start (API)
  \param  mac_address   pointer to requested MAC address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_GetIp(const uint8_t *mac_address) {
    EventRecordData (EvtNetARP_GetIp, mac_address, 6);
  }
#else
  #define EvrNetARP_GetIp(mac_address)
#endif

/**
  \brief  Event on \ref netARP_GetIP invalid parameter (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_GetIpInvalidParameter(void) {
    EventRecord2 (EvtNetARP_GetIpInvalidParameter, 0, 0);
  }
#else
  #define EvrNetARP_GetIpInvalidParameter()
#endif

/**
  \brief  Event on ARP cache display IP address (Op)
  \param  ip4_address   pointer to IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_ShowIpAddress(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_ShowIpAddress, ip4_address, 4);
  }
#else
  #define EvrNetARP_ShowIpAddress(ip4_address)
#endif

/**
  \brief  Event on ARP cache entry not found (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_EntryNotFound(void) {
    EventRecord2 (EvtNetARP_EntryNotFound, 0, 0);
  }
#else
  #define EvrNetARP_EntryNotFound()
#endif

/**
  \brief  Event on \ref netARP_GetMAC start (API)
  \param  ip4_address   pointer to requested IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_GetMac(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_GetMac, ip4_address, 4);
  }
#else
  #define EvrNetARP_GetMac(ip4_address)
#endif

/**
  \brief  Event on \ref netARP_GetMAC invalid parameter (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_GetMacInvalidParameter(void) {
    EventRecord2 (EvtNetARP_GetMacInvalidParameter, 0, 0);
  }
#else
  #define EvrNetARP_GetMacInvalidParameter()
#endif

/**
  \brief  Event on \ref netARP_Probe start (API)
  \param  ip4_address   pointer to requested IPv4 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_Probe(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_Probe, ip4_address, 4);
  }
#else
  #define EvrNetARP_Probe(ip4_address)
#endif

/**
  \brief  Event on \ref netARP_Probe invalid parameter (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_ProbeInvalidParameter(void) {
    EventRecord2 (EvtNetARP_ProbeInvalidParameter, 0, 0);
  }
#else
  #define EvrNetARP_ProbeInvalidParameter()
#endif

/**
  \brief  Event on \ref netARP_Probe process busy (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_ProbeBusy(void) {
    EventRecord2 (EvtNetARP_ProbeBusy, 0, 0);
  }
#else
  #define EvrNetARP_ProbeBusy()
#endif

/**
  \brief  Event on ARP probe retransmit (Op)
  \param  ip4_address   pointer to IPv4 address of probed host
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_ProbeRetransmit(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_ProbeRetransmit, ip4_address, 4);
  }
#else
  #define EvrNetARP_ProbeRetransmit(ip4_address)
#endif

/**
  \brief  Event on ARP probe timeout (Op)
  \param  ip4_address   pointer to IPv4 address of probed host
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_ProbeTimeout(const uint8_t *ip4_address) {
    EventRecordData (EvtNetARP_ProbeTimeout, ip4_address, 4);
  }
#else
  #define EvrNetARP_ProbeTimeout(ip4_address)
#endif

/**
  \brief  Event on ARP cache entry timeout (Op)
  \param  entry         cache entry number
  \param  type          cache entry type
                         - 0: Fixed IP
                         - 1: Temporary IP
                         - 2: In use temporary IP
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_CacheEntryTimeout(uint32_t entry, uint32_t type) {
    EventRecord2 (EvtNetARP_CacheEntryTimeout, entry, type);
  }
#else
  #define EvrNetARP_CacheEntryTimeout(entry, type)
#endif

/**
  \brief  Event on ARP cache entry released (Op)
  \param  entry         cache entry number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_EntryReleased(uint32_t entry) {
    EventRecord2 (EvtNetARP_EntryReleased, entry, 0);
  }
#else
  #define EvrNetARP_EntryReleased(entry)
#endif

/**
  \brief  Event on resolve ARP cache entry (Op)
  \param  entry         cache entry number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_ResolveEntry(uint32_t entry) {
    EventRecord2 (EvtNetARP_ResolveEntry, entry, 0);
  }
#else
  #define EvrNetARP_ResolveEntry(entry)
#endif

/**
  \brief  Event on refresh ARP cache entry (Op)
  \param  entry         cache entry number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetARP_RefreshEntry(uint32_t entry) {
    EventRecord2 (EvtNetARP_RefreshEntry, entry, 0);
  }
#else
  #define EvrNetARP_RefreshEntry(entry)
#endif


// NetIP6 event identifiers ----------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetIP6_InitCore                  EventID (EventLevelOp,    EvtNetIP6,  0)
#define EvtNetIP6_ReceiveFrame              EventID (EventLevelOp,    EvtNetIP6,  1)
#define EvtNetIP6_FrameTooShort             EventID (EventLevelError, EvtNetIP6,  2)
#define EvtNetIP6_InvalidIpVersion          EventID (EventLevelError, EvtNetIP6,  3)
#define EvtNetIP6_HeaderInfo                EventID (EventLevelDetail,EvtNetIP6,  4)
#define EvtNetIP6_WrongDestinationAddress   EventID (EventLevelOp,    EvtNetIP6,  5)
#define EvtNetIP6_InterfaceNotSupported     EventID (EventLevelError, EvtNetIP6,  6)
#define EvtNetIP6_WrongMulticastProtocol    EventID (EventLevelError, EvtNetIP6,  7)
#define EvtNetIP6_SendFrame                 EventID (EventLevelOp,    EvtNetIP6,  8)
#define EvtNetIP6_ProtocolUnknown           EventID (EventLevelError, EvtNetIP6,  9)
#define EvtNetIP6_SourceAddressNull         EventID (EventLevelError, EvtNetIP6, 10)
#define EvtNetIP6_DestinationAddressNull    EventID (EventLevelError, EvtNetIP6, 11)
#endif

/**
  \brief  Event on IPv6 core initialize (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP6_InitCore(void) {
    EventRecord2 (EvtNetIP6_InitCore, 0, 0);
  }
#else
  #define EvrNetIP6_InitCore()
#endif

/**
  \brief  Event on IPv6 receive frame (Op)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP6_ReceiveFrame(uint32_t length) {
    EventRecord2 (EvtNetIP6_ReceiveFrame, length, 0);
  }
#else
  #define EvrNetIP6_ReceiveFrame(length)
#endif

/**
  \brief  Event on IPv6 received frame too short (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP6_FrameTooShort(uint32_t length) {
    EventRecord2 (EvtNetIP6_FrameTooShort, length, 0);
  }
#else
  #define EvrNetIP6_FrameTooShort(length)
#endif

/**
  \brief  Event on IPv6 invalid protocol version (Error)
  \param  ip_version    not IPv6 protocol version value
                         - 0..5
                         - 7..15
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP6_InvalidIpVersion(uint8_t ip_version) {
    EventRecord2 (EvtNetIP6_InvalidIpVersion, ip_version, 0);
  }
#else
  #define EvrNetIP6_InvalidIpVersion(ip_version)
#endif

/**
  \brief  Event on IPv6 frame header info (Detail)
  \param  ip6_header    pointer to IPv6 frame header of 40 bytes
                         - VerClass  (1 byte)
                         - ClassFlow (1 byte)
                         - Flow      (2 bytes)
                         - Len       (2 bytes)
                         - NextHdr   (1 byte)
                         - HopLim    (1 byte)
                         - SrcAddr   (16 bytes)
                         - DstAddr   (16 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP6_HeaderInfo(const void *ip6_header) {
    EventRecordData (EvtNetIP6_HeaderInfo, ip6_header, 40);
  }
#else
  #define EvrNetIP6_HeaderInfo(ip6_header)
#endif

/**
  \brief  Event on IPv6 wrong destination address (Op)
  \param  ip6_address   pointer to IPv6 destination address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP6_WrongDestinationAddress(const uint8_t *ip6_address) {
    EventRecordData (EvtNetIP6_WrongDestinationAddress, ip6_address, 16);
  }
#else
  #define EvrNetIP6_WrongDestinationAddress(ip6_address)
#endif

/**
  \brief  Event on IPv6 network interface not supported (Error)
  \param  interface     network interface
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP6_InterfaceNotSupported(uint32_t interface) {
    EventRecord2 (EvtNetIP6_InterfaceNotSupported, interface, 0);
  }
#else
  #define EvrNetIP6_InterfaceNotSupported(interface)
#endif

/**
  \brief  Event on IPv6 wrong multicast protocol type (Error)
  \param  ip6_protocol  wrong protocol type value
  \note   Only UDP multicast frames are allowed!
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP6_WrongMulticastProtocol(uint8_t ip6_protocol) {
    EventRecord2 (EvtNetIP6_WrongMulticastProtocol, ip6_protocol, 0);
  }
#else
  #define EvrNetIP6_WrongMulticastProtocol(ip6_protocol)
#endif

/**
  \brief  Event on IP6 send frame (Op)
  \param  ip6_protocol  IPv6 protocol type
                         - 6:  TCP
                         - 17: UDP
                         - 58: ICMP6
  \param  length        frame length
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP6_SendFrame(uint8_t ip6_protocol, uint32_t length) {
    EventRecord2 (EvtNetIP6_SendFrame, ip6_protocol, length);
  }
#else
  #define EvrNetIP6_SendFrame(ip6_protocol, length)
#endif

/**
  \brief  Event on IP6 unknown protocol type in sending frame (Error)
  \param  ip6_protocol  unknown IPv6 protocol type value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP6_ProtocolUnknown(uint8_t ip6_protocol) {
    EventRecord2 (EvtNetIP6_ProtocolUnknown, ip6_protocol, 0);
  }
#else
  #define EvrNetIP6_ProtocolUnknown(ip6_protocol)
#endif

/**
  \brief  Event on IP6 source address not provided (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP6_SourceAddressNull(void) {
    EventRecord2 (EvtNetIP6_SourceAddressNull, 0, 0);
  }
#else
  #define EvrNetIP6_SourceAddressNull()
#endif

/**
  \brief  Event on IP6 destination address not provided (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetIP6_DestinationAddressNull(void) {
    EventRecord2 (EvtNetIP6_DestinationAddressNull, 0, 0);
  }
#else
  #define EvrNetIP6_DestinationAddressNull()
#endif


// NetICMP6 event identifiers --------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetICMP6_ReceiveFrame            EventID (EventLevelOp,    EvtNetICMP6,  0)
#define EvtNetICMP6_FrameTooShort           EventID (EventLevelError, EvtNetICMP6,  1)
#define EvtNetICMP6_ChecksumFailed          EventID (EventLevelError, EvtNetICMP6,  2)
#define EvtNetICMP6_EchoRequestWrongCode    EventID (EventLevelError, EvtNetICMP6,  3)
#define EvtNetICMP6_EchoRequestReceived     EventID (EventLevelOp,    EvtNetICMP6,  4)
#define EvtNetICMP6_SendEchoReply           EventID (EventLevelOp,    EvtNetICMP6,  5)
#define EvtNetICMP6_EchoReplyReceived       EventID (EventLevelOp,    EvtNetICMP6,  6)
#define EvtNetICMP6_EchoReplyWrongState     EventID (EventLevelError, EvtNetICMP6,  7)
#define EvtNetICMP6_EchoReplyWrongCode      EventID (EventLevelError, EvtNetICMP6,  8)
#define EvtNetICMP6_EchoReplyWrongIpAddress EventID (EventLevelError, EvtNetICMP6,  9)
#define EvtNetICMP6_EchoReplyWrongId        EventID (EventLevelError, EvtNetICMP6, 10)
#define EvtNetICMP6_EchoReplyWrongPayload   EventID (EventLevelError, EvtNetICMP6, 11)
#define EvtNetICMP6_MessageDiscarded        EventID (EventLevelOp,    EvtNetICMP6, 12)
#define EvtNetICMP6_WrongHopLimit           EventID (EventLevelError, EvtNetICMP6, 13)
#define EvtNetICMP6_WrongCode               EventID (EventLevelError, EvtNetICMP6, 14)
#define EvtNetICMP6_MessageTypeUnknown      EventID (EventLevelOp,    EvtNetICMP6, 15)
#define EvtNetICMP6_SendFrame               EventID (EventLevelOp,    EvtNetICMP6, 16)
#endif

/**
  \brief  Event on ICMP6 receive frame (Op)
  \param  icmp6_header  pointer to ICMP6 frame header of 8 bytes
                         - Type    (1 byte)
                         - Code    (1 byte)
                         - Chksum  (2 bytes)
                         - EchoId  (2 bytes)
                         - EchoSeq (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_ReceiveFrame(const void *icmp6_header) {
    EventRecordData (EvtNetICMP6_ReceiveFrame, icmp6_header, 8);
  }
#else
  #define EvrNetICMP6_ReceiveFrame(icmp6_header)
#endif

/**
  \brief  Event on ICMP6 received frame is too short (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_FrameTooShort(uint32_t length) {
    EventRecord2 (EvtNetICMP6_FrameTooShort, length, 0);
  }
#else
  #define EvrNetICMP6_FrameTooShort(length)
#endif

/**
  \brief  Event on ICMP6 frame checksum check failed (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_ChecksumFailed(uint32_t length) {
    EventRecord2 (EvtNetICMP6_ChecksumFailed, length, 0);
  }
#else
  #define EvrNetICMP6_ChecksumFailed(length)
#endif

/**
  \brief  Event on ICMP6 wrong code in echo request received (Error)
  \param  icmp6_code    wrong ICMP6 code value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_EchoRequestWrongCode(uint8_t icmp6_code) {
    EventRecord2 (EvtNetICMP6_EchoRequestWrongCode, icmp6_code, 0);
  }
#else
  #define EvrNetICMP6_EchoRequestWrongCode(icmp6_code)
#endif

/**
  \brief  Event on ICMP6 echo request received (Op)
  \param  data_length   length of the payload data
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_EchoRequestReceived(uint32_t data_length) {
    EventRecord2 (EvtNetICMP6_EchoRequestReceived, data_length, 0);
  }
#else
  #define EvrNetICMP6_EchoRequestReceived(data_length)
#endif

/**
  \brief  Event on ICMP6 send echo reply (Op)
  \param  icmp6_header  pointer to ICMP6 frame header of 8 bytes
                         - Type    (1 byte)
                         - Code    (1 byte)
                         - Chksum  (2 bytes)
                         - EchoId  (2 bytes)
                         - EchoSeq (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_SendEchoReply(const void *icmp6_header) {
    EventRecordData (EvtNetICMP6_SendEchoReply, icmp6_header, 8);
  }
#else
  #define EvrNetICMP6_SendEchoReply(icmp6_header)
#endif

/**
  \brief  Event on ICMP6 echo reply received (Op)
  \param  data_length   length of the payload data
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_EchoReplyReceived(uint32_t data_length) {
    EventRecord2 (EvtNetICMP6_EchoReplyReceived, data_length, 0);
  }
#else
  #define EvrNetICMP6_EchoReplyReceived(data_length)
#endif

/**
  \brief  Event on ICMP6 echo reply received in wrong ping process state (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_EchoReplyWrongState(void) {
    EventRecord2 (EvtNetICMP6_EchoReplyWrongState, 0, 0);
  }
#else
  #define EvrNetICMP6_EchoReplyWrongState()
#endif

/**
  \brief  Event on ICMP6 wrong code in echo reply received (Error)
  \param  icmp6_code    wrong ICMP code value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_EchoReplyWrongCode(uint8_t icmp6_code) {
    EventRecord2 (EvtNetICMP6_EchoReplyWrongCode, icmp6_code, 0);
  }
#else
  #define EvrNetICMP6_EchoReplyWrongCode(icmp6_code)
#endif

/**
  \brief  Event on ICMP6 wrong source IPv6 address of echo reply (Error)
  \param  ip6_address   pointer to IPv6 address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_EchoReplyWrongIpAddress(const uint8_t *ip6_address) {
    EventRecordData (EvtNetICMP6_EchoReplyWrongIpAddress, ip6_address, 16);
  }
#else
  #define EvrNetICMP6_EchoReplyWrongIpAddress(ip6_address)
#endif

/**
  \brief  Event on ICMP6 wrong echo identifier value in echo reply (Error)
  \param  echo_id       wrong echo identifier value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_EchoReplyWrongId(uint16_t echo_id) {
    EventRecord2 (EvtNetICMP6_EchoReplyWrongId, echo_id, 0);
  }
#else
  #define EvrNetICMP6_EchoReplyWrongId(echo_id)
#endif

/**
  \brief  Event on ICMP6 echo reply payload data invalid (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_EchoReplyWrongPayload(void) {
    EventRecord2 (EvtNetICMP6_EchoReplyWrongPayload, 0, 0);
  }
#else
  #define EvrNetICMP6_EchoReplyWrongPayload()
#endif

/**
  \brief  Event on ICMP6 router solicitation message discarded (Op)
  \param  icmp6_type    ICMP6 message type
  \note   Hosts must silently discard RS messages [RFC4861 page 38]
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_MessageDiscarded(uint8_t icmp6_type) {
    EventRecord2 (EvtNetICMP6_MessageDiscarded, icmp6_type, 0);
  }
#else
  #define EvrNetICMP6_MessageDiscarded(icmp6_type)
#endif

/**
  \brief  Event on ICMP6 wrong hop limit in discover message (Error)
  \param  hop_limit     hop limit value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_WrongHopLimit(uint8_t hop_limit) {
    EventRecord2 (EvtNetICMP6_WrongHopLimit, hop_limit, 0);
  }
#else
  #define EvrNetICMP6_WrongHopLimit(hop_limit)
#endif

/**
  \brief  Event on ICMP6 wrong code in discover message (Error)
  \param  icmp6_code    code value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_WrongCode(uint8_t icmp6_code) {
    EventRecord2 (EvtNetICMP6_WrongCode, icmp6_code, 0);
  }
#else
  #define EvrNetICMP6_WrongCode(icmp6_code)
#endif

/**
  \brief  Event on ICMP6 message type unknown (Op)
  \param  icmp6_type    ICMP6 message type
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_MessageTypeUnknown(uint8_t icmp6_type) {
    EventRecord2 (EvtNetICMP6_MessageTypeUnknown, icmp6_type, 0);
  }
#else
  #define EvrNetICMP6_MessageTypeUnknown(icmp6_type)
#endif

/**
  \brief  Event on ICMP6 send frame (Op)
  \param  icmp6_header  pointer to ICMP6 frame header of 8 bytes
                         - Type    (1 byte)
                         - Code    (1 byte)
                         - Chksum  (2 bytes)
                         - EchoId  (2 bytes)
                         - EchoSeq (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetICMP6_SendFrame(const void *icmp6_header) {
    EventRecordData (EvtNetICMP6_SendFrame, icmp6_header, 8);
  }
#else
  #define EvrNetICMP6_SendFrame(icmp6_header)
#endif


// NetDHCP6 event identifiers --------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetDHCP6_InitClient              EventID (EventLevelOp,    EvtNetDHCP6,  0)
#define EvtNetDHCP6_GetSocketFailed         EventID (EventLevelError, EvtNetDHCP6,  1)
#define EvtNetDHCP6_StartClient             EventID (EventLevelOp,    EvtNetDHCP6,  2)
#define EvtNetDHCP6_StopClient              EventID (EventLevelOp,    EvtNetDHCP6,  3)
#define EvtNetDHCP6_ClientState             EventID (EventLevelOp,    EvtNetDHCP6,  4)
#define EvtNetDHCP6_NextState               EventID (EventLevelOp,    EvtNetDHCP6,  5)
#define EvtNetDHCP6_NextStateDelay          EventID (EventLevelOp,    EvtNetDHCP6,  6)
#define EvtNetDHCP6_ChangeStateLinkDown     EventID (EventLevelOp,    EvtNetDHCP6,  7)
#define EvtNetDHCP6_NoAddressAvailable      EventID (EventLevelOp,    EvtNetDHCP6,  8)
#define EvtNetDHCP6_StateRetransmit         EventID (EventLevelOp,    EvtNetDHCP6,  9)
#define EvtNetDHCP6_StateTimeout            EventID (EventLevelOp,    EvtNetDHCP6, 10)
#define EvtNetDHCP6_ChangeStateOnTimeout    EventID (EventLevelOp,    EvtNetDHCP6, 11)
#define EvtNetDHCP6_T1Expired               EventID (EventLevelOp,    EvtNetDHCP6, 12)
#define EvtNetDHCP6_T2Expired               EventID (EventLevelOp,    EvtNetDHCP6, 13)
#define EvtNetDHCP6_SendDhcpMessage         EventID (EventLevelOp,    EvtNetDHCP6, 14)
#define EvtNetDHCP6_ReceiveFrame            EventID (EventLevelOp,    EvtNetDHCP6, 15)
#define EvtNetDHCP6_FrameTooShort           EventID (EventLevelError, EvtNetDHCP6, 16)
#define EvtNetDHCP6_WrongTransactionId      EventID (EventLevelError, EvtNetDHCP6, 17)
#define EvtNetDHCP6_UnknownMessageType      EventID (EventLevelError, EvtNetDHCP6, 18)
#define EvtNetDHCP6_InvalidMessageType      EventID (EventLevelOp,    EvtNetDHCP6, 19)
#define EvtNetDHCP6_WrongClientId           EventID (EventLevelOp,    EvtNetDHCP6, 20)
#define EvtNetDHCP6_ServerNotChosen         EventID (EventLevelOp,    EvtNetDHCP6, 21)
#define EvtNetDHCP6_StatusCode              EventID (EventLevelOp,    EvtNetDHCP6, 22)
#define EvtNetDHCP6_WrongServerId           EventID (EventLevelOp,    EvtNetDHCP6, 23)
#define EvtNetDHCP6_ShowDnsServers          EventID (EventLevelOp,    EvtNetDHCP6, 24)
#define EvtNetDHCP6_MissingServerId         EventID (EventLevelOp,    EvtNetDHCP6, 25)
#define EvtNetDHCP6_WrongIaid               EventID (EventLevelOp,    EvtNetDHCP6, 26)
#define EvtNetDHCP6_ShowIanaOffer           EventID (EventLevelOp,    EvtNetDHCP6, 27)
#define EvtNetDHCP6_OfferTimerCheckFailed   EventID (EventLevelError, EvtNetDHCP6, 28)
#endif

/**
  \brief  Event on DHCP6 client initialize (Op)
  \param  option_flags  DHCPv6 client option flags
                         - 0x01: Opt.67 Vendor Class
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_InitClient(uint8_t option_flags) {
    EventRecord2 (EvtNetDHCP6_InitClient, option_flags, 0);
  }
#else
  #define EvrNetDHCP6_InitClient(option_flags)
#endif

/**
  \brief  Event on DHCP6 failed to allocate UDP socket (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_GetSocketFailed(void) {
    EventRecord2 (EvtNetDHCP6_GetSocketFailed, 0, 0);
  }
#else
  #define EvrNetDHCP6_GetSocketFailed()
#endif

/**
  \brief  Event on DHCP6 start client (Op)
  \param  mode          client mode
                         - 0: Stateless mode
                         - 1: Stateful mode
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_StartClient(uint32_t mode) {
    EventRecord2 (EvtNetDHCP6_StartClient, mode, 0);
  }
#else
  #define EvrNetDHCP6_StartClient(mode)
#endif

/**
  \brief  Event on DHCP6 stop client (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_StopClient(void) {
    EventRecord2 (EvtNetDHCP6_StopClient, 0, 0);
  }
#else
  #define EvrNetDHCP6_StopClient()
#endif

/**
  \brief  Event on DHCP6 indication of client state (Op)
  \param  state         current state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_ClientState(uint32_t state) {
    EventRecord2 (EvtNetDHCP6_ClientState, state, 0);
  }
#else
  #define EvrNetDHCP6_ClientState(state)
#endif

/**
  \brief  Event on DHCP6 transition to next state (Op)
  \param  state         next state

 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_NextState(uint32_t state) {
    EventRecord2 (EvtNetDHCP6_NextState, state, 0);
  }
#else
  #define EvrNetDHCP6_NextState(state)
#endif

/**
  \brief  Event on DHCP6 transition to next state with random delay(Op)
  \param  state         next state
  \param  delay         start delay (in 100ms ticks)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_NextStateDelay(uint32_t state, uint32_t delay) {
    EventRecord2 (EvtNetDHCP6_NextStateDelay, state, delay);
  }
#else
  #define EvrNetDHCP6_NextStateDelay(state, delay)
#endif

/**
  \brief  Event on DHCP6 change state on link-down (Op)
  \param  state         next state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_ChangeStateLinkDown(uint32_t state) {
    EventRecord2 (EvtNetDHCP6_ChangeStateLinkDown, state, 0);
  }
#else
  #define EvrNetDHCP6_ChangeStateLinkDown(state)
#endif

/**
  \brief  Event on DHCP6 no address available status received (Op)
  \param  state         current state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_NoAddressAvailable(uint32_t state) {
    EventRecord2 (EvtNetDHCP6_NoAddressAvailable, state, 0);
  }
#else
  #define EvrNetDHCP6_NoAddressAvailable(state)
#endif

/**
  \brief  Event on DHCP6 retransmit request in current state (Op)
  \param  state         current state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_StateRetransmit(uint32_t state) {
    EventRecord2 (EvtNetDHCP6_StateRetransmit, state, 0);
  }
#else
  #define EvrNetDHCP6_StateRetransmit(state)
#endif

/**
  \brief  Event on DHCP6 timeout in current state (Op)
  \param  state         current state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_StateTimeout(uint32_t state) {
    EventRecord2 (EvtNetDHCP6_StateTimeout, state, 0);
  }
#else
  #define EvrNetDHCP6_StateTimeout(state)
#endif

/**
  \brief  Event on DHCP6 state timeout and transit to next state (Op)
  \param  current       current state
  \param  next          next state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_ChangeStateOnTimeout(uint32_t current, uint32_t next) {
    EventRecord2 (EvtNetDHCP6_ChangeStateOnTimeout, current, next);
  }
#else
  #define EvrNetDHCP6_ChangeStateOnTimeout(current, next)
#endif

/**
  \brief  Event on DHCP6 timer T1 expired (Op)
  \param  state         current state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_T1Expired(uint32_t state) {
    EventRecord2 (EvtNetDHCP6_T1Expired, state, 0);
  }
#else
  #define EvrNetDHCP6_T1Expired(state)
#endif

/**
  \brief  Event on DHCP6 timer T2 expired (Op)
  \param  state         current state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_T2Expired(uint32_t state) {
    EventRecord2 (EvtNetDHCP6_T2Expired, state, 0);
  }
#else
  #define EvrNetDHCP6_T2Expired(state)
#endif

/**
  \brief  Event on DHCP6 send message (Op)
  \param  msg_type      message type
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_SendDhcpMessage(uint8_t msg_type) {
    EventRecord2 (EvtNetDHCP6_SendDhcpMessage, msg_type, 0);
  }
#else
  #define EvrNetDHCP6_SendDhcpMessage(msg_type)
#endif

/**
  \brief  Event on DHCP6 receive frame (Op)
  \param  msg_type      message type
  \param  length        message length
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_ReceiveFrame(uint8_t msg_type, uint32_t length) {
    EventRecord2 (EvtNetDHCP6_ReceiveFrame, msg_type, length);
  }
#else
  #define EvrNetDHCP6_ReceiveFrame(msg_type, length)
#endif

/**
  \brief  Event on DHCP6 received frame is too short (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_FrameTooShort(uint32_t length) {
    EventRecord2 (EvtNetDHCP6_FrameTooShort, length, 0);
  }
#else
  #define EvrNetDHCP6_FrameTooShort(length)
#endif

/**
  \brief  Event on DHCP6 wrong Transaction Id (XID) received (Error)
  \param  xid           wrong Transaction Id value (3-bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_WrongTransactionId(uint32_t xid) {
    EventRecord2 (EvtNetDHCP6_WrongTransactionId, xid, 0);
  }
#else
  #define EvrNetDHCP6_WrongTransactionId(xid)
#endif

/**
  \brief  Event on DHCP6 unknown message type received (Error)
  \param  msg_type      message type
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_UnknownMessageType(uint8_t msg_type) {
    EventRecord2 (EvtNetDHCP6_UnknownMessageType, msg_type, 0);
  }
#else
  #define EvrNetDHCP6_UnknownMessageType(msg_type)
#endif

/**
  \brief  Event on DHCP6 invalid message type received (Op)
  \param  msg_type      message type
  \note   Silently discard other message types.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_InvalidMessageType(uint8_t msg_type) {
    EventRecord2 (EvtNetDHCP6_InvalidMessageType, msg_type, 0);
  }
#else
  #define EvrNetDHCP6_InvalidMessageType(msg_type)
#endif

/**
  \brief  Event on DHCP6 wrong client identifier received (Op)
  \note   Silently discard the message.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_WrongClientId(void) {
    EventRecord2 (EvtNetDHCP6_WrongClientId, 0, 0);
  }
#else
  #define EvrNetDHCP6_WrongClientId()
#endif

/**
  \brief  Event on DHCP6 server not chosen in DISCOVER, REBIND state (Op)
  \note   Silently discard the message.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_ServerNotChosen(void) {
    EventRecord2 (EvtNetDHCP6_ServerNotChosen, 0, 0);
  }
#else
  #define EvrNetDHCP6_ServerNotChosen()
#endif

/**
  \brief  Event on DHCP6 option status code received (Op)
  \param  status        status code
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_StatusCode(uint16_t status) {
    EventRecord2 (EvtNetDHCP6_StatusCode, status, 0);
  }
#else
  #define EvrNetDHCP6_StatusCode(status)
#endif

/**
  \brief  Event on DHCP6 wrong server identifier received (Op)
  \note   Silently discard the message.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_WrongServerId(void) {
    EventRecord2 (EvtNetDHCP6_WrongServerId, 0, 0);
  }
#else
  #define EvrNetDHCP6_WrongServerId()
#endif

/**
  \brief  Event on DHCP6 display DNS server addresses (Op)
  \param  dns_list      pointer to DNS server address list
  \note   Displays primary and secondary DNS server address.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_ShowDnsServers(const uint8_t *dns_list) {
    EventRecordData (EvtNetDHCP6_ShowDnsServers, dns_list, 32);
  }
#else
  #define EvrNetDHCP6_ShowDnsServers(dns_list)
#endif

/**
  \brief  Event on DHCP6 missing server identifier option (Op)
  \note   Silently discard the message.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_MissingServerId(void) {
    EventRecord2 (EvtNetDHCP6_MissingServerId, 0, 0);
  }
#else
  #define EvrNetDHCP6_MissingServerId()
#endif

/**
  \brief  Event on DHCP6 wrong Identity Association Identifier (IAID) received (Op)
  \param  iaid          wrong IAID value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_WrongIaid(uint32_t iaid) {
    EventRecord2 (EvtNetDHCP6_WrongIaid, iaid, 0);
  }
#else
  #define EvrNetDHCP6_WrongIaid(iaid)
#endif

/**
  \brief  Event on DHCP6 display IANA offer (Op)
  \param  iana_offer    pointer to IANA structure
  \note   IANA: Identity Association for non-temporary Address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_ShowIanaOffer(const void *iana_offer) {
    EventRecordData (EvtNetDHCP6_ShowIanaOffer, iana_offer, 32);
  }
#else
  #define EvrNetDHCP6_ShowIanaOffer(iana_offer)
#endif

/**
  \brief  Event on DHCP6 offer address timer check failed (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetDHCP6_OfferTimerCheckFailed(void) {
    EventRecord2 (EvtNetDHCP6_OfferTimerCheckFailed, 0, 0);
  }
#else
  #define EvrNetDHCP6_OfferTimerCheckFailed()
#endif


// NetNDP event identifiers ----------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetNDP_InitCache                 EventID (EventLevelOp,    EvtNetNDP,  0)
#define EvtNetNDP_FrameCheckFailed          EventID (EventLevelError, EvtNetNDP,  1)
#define EvtNetNDP_AddressNotLinkLocal       EventID (EventLevelOp,    EvtNetNDP,  2)
#define EvtNetNDP_RouterAdvertisement       EventID (EventLevelOp,    EvtNetNDP,  3)
#define EvtNetNDP_OptionMtu                 EventID (EventLevelOp,    EvtNetNDP,  4)
#define EvtNetNDP_OptionSourceMacAddress    EventID (EventLevelOp,    EvtNetNDP,  5)
#define EvtNetNDP_OptionPrefixInfo          EventID (EventLevelOp,    EvtNetNDP,  6)
#define EvtNetNDP_PrefixInfoNotValid        EventID (EventLevelOp,    EvtNetNDP,  7)
#define EvtNetNDP_WrongTargetAddress        EventID (EventLevelOp,    EvtNetNDP,  8)
#define EvtNetNDP_NeighborSolicitation      EventID (EventLevelOp,    EvtNetNDP,  9)
#define EvtNetNDP_ProbeRequest              EventID (EventLevelOp,    EvtNetNDP, 10)
#define EvtNetNDP_NeighborAdvertisement     EventID (EventLevelOp,    EvtNetNDP, 11)
#define EvtNetNDP_ProbeResponse             EventID (EventLevelOp,    EvtNetNDP, 12)
#define EvtNetNDP_WrongDestinationAddress   EventID (EventLevelOp,    EvtNetNDP, 13)
#define EvtNetNDP_SendReply                 EventID (EventLevelOp,    EvtNetNDP, 14)
#define EvtNetNDP_ShowFlags                 EventID (EventLevelOp,    EvtNetNDP, 15)
#define EvtNetNDP_SendRequest               EventID (EventLevelOp,    EvtNetNDP, 16)
#define EvtNetNDP_ShowTargetAddress         EventID (EventLevelOp,    EvtNetNDP, 17)
#define EvtNetNDP_OptionTargetMacAddress    EventID (EventLevelOp,    EvtNetNDP, 18)
#define EvtNetNDP_CacheEntryUpdate          EventID (EventLevelOp,    EvtNetNDP, 19)
#define EvtNetNDP_WrongResponse             EventID (EventLevelError, EvtNetNDP, 20)
#define EvtNetNDP_CreateTempAddress         EventID (EventLevelOp,    EvtNetNDP, 21)
#endif

/**
  \brief  Event on NDP cache initialize (Op)
  \param  entries       number of entries available in NDP cache
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_InitCache(uint32_t entries) {
    EventRecord2 (EvtNetNDP_InitCache, entries, 0);
  }
#else
  #define EvrNetNDP_InitCache(entries)
#endif

/**
  \brief  Event on NDP discovery frame consistency check failed (Error)
  \param  msg_type      discovery message type
                         - 134: Router Advertisement
                         - 135: Neighbor Solicitation
                         - 136: Neighbor Advertisement
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_FrameCheckFailed(uint8_t msg_type) {
    EventRecord2 (EvtNetNDP_FrameCheckFailed, msg_type, 0);
  }
#else
  #define EvrNetNDP_FrameCheckFailed(msg_type)
#endif

/**
  \brief  Event on NDP received address not link-local (Op)
  \param  ip6_address   pointer to IPv6 source address
  \note   Nodes must silently discard RA messages if src IP not link-local.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_AddressNotLinkLocal(const uint8_t *ip6_address) {
    EventRecordData (EvtNetNDP_AddressNotLinkLocal, ip6_address, 16);
  }
#else
  #define EvrNetNDP_AddressNotLinkLocal(ip6_address)
#endif

/**
  \brief  Event on NDP Router Advertisement (RA) message received (Op)
  \param  hop_limit     current hop limit
  \param  flags         advertisement flags
                         - 0x80: M-flag (Managed address configuration)
                         - 0x40: O-flag (Other configuration)
  \param  lifetime      router lifetime in seconds
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_RouterAdvertisement(uint8_t hop_limit, uint8_t flags, uint16_t lifetime) {
    EventRecord4 (EvtNetNDP_RouterAdvertisement, hop_limit, flags, lifetime, 0);
  }
#else
  #define EvrNetNDP_RouterAdvertisement(hop_limit, flags, lifetime)
#endif

/**
  \brief  Event on NDP option Maximum transfer unit (MTU) (Op)
  \param  mtu           maximum transfer unit
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_OptionMtu(uint32_t mtu) {
    EventRecord2 (EvtNetNDP_OptionMtu, mtu, 0);
  }
#else
  #define EvrNetNDP_OptionMtu(mtu)
#endif

/**
  \brief  Event on NDP option Source link-layer (MAC) address (Op)
  \param  src_addr      source link-layer address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_OptionSourceMacAddress(const uint8_t *src_addr) {
    EventRecordData (EvtNetNDP_OptionSourceMacAddress, src_addr, 6);
  }
#else
  #define EvrNetNDP_OptionSourceMacAddress(src_addr)
#endif

/**
  \brief  Event on NDP RA-option address prefix info (Op)
  \param  opt_prefix    pointer to RA prefix option structure (32 bytes)
                         - Type:      1 byte
                         - Length:    1 byte
                         - PrefixLen: 1 byte
                         - Flags:     1 byte
                         - Valid:     4 byte2
                         - Preferred: 4 byte2
                         - Reserved:  4 bytes
                         - Prefix:   16 bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_OptionPrefixInfo(const uint8_t *opt_prefix) {
    EventRecordData (EvtNetNDP_OptionPrefixInfo, opt_prefix, 32);
  }
#else
  #define EvrNetNDP_OptionPrefixInfo(opt_prefix)
#endif

/**
  \brief  Event on NDP prefix information option not valid (Op)
  \note   Nodes must silently discard not valid RA messages.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_PrefixInfoNotValid(void) {
    EventRecordData (EvtNetNDP_PrefixInfoNotValid, 0, 0);
  }
#else
  #define EvrNetNDP_PrefixInfoNotValid()
#endif

/**
  \brief  Event on NDP wrong target address received (Op)
  \param  targ_addr     pointer to target address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_WrongTargetAddress(const uint8_t *targ_addr) {
    EventRecordData (EvtNetNDP_WrongTargetAddress, targ_addr, 16);
  }
#else
  #define EvrNetNDP_WrongTargetAddress(targ_addr)
#endif

/**
  \brief  Event on NDP Neighbor Solicitation (NS) message received (Op)
  \param  targ_addr     pointer to target address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_NeighborSolicitation(const uint8_t *targ_addr) {
    EventRecordData (EvtNetNDP_NeighborSolicitation, targ_addr, 16);
  }
#else
  #define EvrNetNDP_NeighborSolicitation(targ_addr)
#endif

/**
  \brief  Event on NDP probe request received (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_ProbeRequest(void) {
    EventRecord2 (EvtNetNDP_ProbeRequest, 0, 0);
  }
#else
  #define EvrNetNDP_ProbeRequest()
#endif

/**
  \brief  Event on NDP Neighbor Advertisement (NA) message received (Op)
  \param  targ_addr     pointer to target address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_NeighborAdvertisement(const uint8_t *targ_addr) {
    EventRecordData (EvtNetNDP_NeighborAdvertisement, targ_addr, 16);
  }
#else
  #define EvrNetNDP_NeighborAdvertisement(targ_addr)
#endif

/**
  \brief  Event on NDP probe response received (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_ProbeResponse(void) {
    EventRecord2 (EvtNetNDP_ProbeResponse, 0, 0);
  }
#else
  #define EvrNetNDP_ProbeResponse()
#endif

/**
  \brief  Event on NDP wrong destination address received (Op)
  \param  dst_addr      pointer to destination address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_WrongDestinationAddress(const uint8_t *dst_addr) {
    EventRecordData (EvtNetNDP_WrongDestinationAddress, dst_addr, 16);
  }
#else
  #define EvrNetNDP_WrongDestinationAddress(dst_addr)
#endif

/**
  \brief  Event on NDP send advertisement reply to solicitation message (Op)
  \param  targ_addr     pointer to target address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_SendReply(const uint8_t *targ_addr) {
    EventRecordData (EvtNetNDP_SendReply, targ_addr, 16);
  }
#else
  #define EvrNetNDP_SendReply(targ_addr)
#endif

/**
  \brief  Event on NDP display advertisement message flags (Op)
  \param  flags         message flags
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_ShowFlags(uint32_t flags) {
    EventRecord2 (EvtNetNDP_ShowFlags, flags, 0);
  }
#else
  #define EvrNetNDP_ShowFlags(flags)
#endif

/**
  \brief  Event on NDP send solicitation request (Op)
  \param  type          request type
                         - 133: Router Solicitation
                         - 135: Neighbor Solicitation
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_SendRequest(uint32_t type) {
    if (type == 255) type = 135;
    EventRecord2 (EvtNetNDP_SendRequest, type, 0);
  }
#else
  #define EvrNetNDP_SendRequest(type)
#endif

/**
  \brief  Event on NDP display target address (Op)
  \param  targ_addr     pointer to target address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_ShowTargetAddress(const uint8_t *targ_addr) {
    EventRecordData (EvtNetNDP_ShowTargetAddress, targ_addr, 16);
  }
#else
  #define EvrNetNDP_ShowTargetAddress(targ_addr)
#endif

/**
  \brief  Event on NDP option Target link-layer (MAC) address (Op)
  \param  targ_addr     target link-layer address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_OptionTargetMacAddress(const uint8_t *targ_addr) {
    EventRecordData (EvtNetNDP_OptionTargetMacAddress, targ_addr, 6);
  }
#else
  #define EvrNetNDP_OptionTargetMacAddress(targ_addr)
#endif

/**
  \brief  Event on NDP cache entry update (Op)
  \param  entry         cache entry number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_CacheEntryUpdate(uint32_t entry) {
    EventRecord2 (EvtNetNDP_CacheEntryUpdate, entry, 0);
  }
#else
  #define EvrNetNDP_CacheEntryUpdate(entry)
#endif

/**
  \brief  Event on NDP wrong response received (Error)
  \param  msg_type      discovery message type
                         - 136: Neighbor Advertisement
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_WrongResponse(uint8_t msg_type) {
    EventRecord2 (EvtNetNDP_WrongResponse, msg_type, 0);
  }
#else
  #define EvrNetNDP_WrongResponse(msg_type)
#endif

/**
  \brief  Event on NDP create temporary address (SLAAC) using prefix info (Op)
  \param  temp_addr     pointer to temporary address
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetNDP_CreateTempAddress(const uint8_t *temp_addr) {
    EventRecordData (EvtNetNDP_CreateTempAddress, temp_addr, 16);
  }
#else
  #define EvrNetNDP_CreateTempAddress(temp_addr)
#endif



// NetUDP event identifiers ----------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetUDP_InitSockets               EventID (EventLevelOp,    EvtNetUDP,  0)
#define EvtNetUDP_GetSocketInvalidParameter EventID (EventLevelError, EvtNetUDP,  1)
#define EvtNetUDP_SocketAllocated           EventID (EventLevelOp,    EvtNetUDP,  2)
#define EvtNetUDP_NoSocketsAvailable        EventID (EventLevelError, EvtNetUDP,  3)
#define EvtNetUDP_ReleaseSocket             EventID (EventLevelOp,    EvtNetUDP,  4)
#define EvtNetUDP_ReleaseSocketNotValid     EventID (EventLevelError, EvtNetUDP,  5)
#define EvtNetUDP_ReleaseSocketWrongState   EventID (EventLevelError, EvtNetUDP,  6)
#define EvtNetUDP_OpenSocket                EventID (EventLevelOp,    EvtNetUDP,  7)
#define EvtNetUDP_OpenSocketNotValid        EventID (EventLevelError, EvtNetUDP,  8)
#define EvtNetUDP_OpenSocketWrongState      EventID (EventLevelError, EvtNetUDP,  9)
#define EvtNetUDP_OpenLocalPortAssigned     EventID (EventLevelOp,    EvtNetUDP, 10)
#define EvtNetUDP_OpenLocalPortInUse        EventID (EventLevelError, EvtNetUDP, 11)
#define EvtNetUDP_CloseSocket               EventID (EventLevelOp,    EvtNetUDP, 12)
#define EvtNetUDP_CloseSocketNotValid       EventID (EventLevelError, EvtNetUDP, 13)
#define EvtNetUDP_SetOptionSocket           EventID (EventLevelOp,    EvtNetUDP, 14)
#define EvtNetUDP_SetOptionSocketNotValid   EventID (EventLevelError, EvtNetUDP, 15)
#define EvtNetUDP_SetOptionSocketWrongState EventID (EventLevelError, EvtNetUDP, 16)
#define EvtNetUDP_SetOptionTos              EventID (EventLevelOp,    EvtNetUDP, 17)
#define EvtNetUDP_SetOptionTtl              EventID (EventLevelOp,    EvtNetUDP, 18)
#define EvtNetUDP_SetOptionTclass           EventID (EventLevelOp,    EvtNetUDP, 19)
#define EvtNetUDP_SetOptionHopLimit         EventID (EventLevelOp,    EvtNetUDP, 20)
#define EvtNetUDP_SetOptionChecksum         EventID (EventLevelOp,    EvtNetUDP, 21)
#define EvtNetUDP_SetOptionWrongOption      EventID (EventLevelError, EvtNetUDP, 22)
#define EvtNetUDP_SetOptionWrongValue       EventID (EventLevelError, EvtNetUDP, 23)
#define EvtNetUDP_GetBufferFailed           EventID (EventLevelError, EvtNetUDP, 24)
#define EvtNetUDP_SendFrame                 EventID (EventLevelOp,    EvtNetUDP, 25)
#define EvtNetUDP_SendBufferInvalid         EventID (EventLevelError, EvtNetUDP, 26)
#define EvtNetUDP_SendSocketNotValid        EventID (EventLevelError, EvtNetUDP, 27)
#define EvtNetUDP_SendAddressUnspecified    EventID (EventLevelError, EvtNetUDP, 28)
#define EvtNetUDP_SendPortUndefined         EventID (EventLevelError, EvtNetUDP, 29)
#define EvtNetUDP_SendSocketNotOpen         EventID (EventLevelError, EvtNetUDP, 30)
#define EvtNetUDP_SendZeroLengthFrame       EventID (EventLevelOp,    EvtNetUDP, 31)
#define EvtNetUDP_SendSizeTruncated         EventID (EventLevelOp,    EvtNetUDP, 32)
#define EvtNetUDP_HeaderInfo                EventID (EventLevelDetail,EvtNetUDP, 33)
#define EvtNetUDP_ReceiveFrame              EventID (EventLevelOp,    EvtNetUDP, 34)
#define EvtNetUDP_FrameTooShort             EventID (EventLevelError, EvtNetUDP, 35)
#define EvtNetUDP_MappedToSocket            EventID (EventLevelOp,    EvtNetUDP, 36)
#define EvtNetUDP_FrameNotMapped            EventID (EventLevelOp,    EvtNetUDP, 37)
#define EvtNetUDP_ChecksumFailed            EventID (EventLevelError, EvtNetUDP, 38)
#endif

/**
  \brief  Event on UDP socket initialize (Op)
  \param  num_sockets   number of available UDP sockets
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_InitSockets(uint32_t num_sockets) {
    EventRecord2 (EvtNetUDP_InitSockets, num_sockets, 0);
  }
#else
  #define EvrNetUDP_InitSockets(num_sockets)
#endif

/**
  \brief  Event on UDP get socket failed, invalid parameter (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_GetSocketInvalidParameter(void) {
    EventRecord2 (EvtNetUDP_GetSocketInvalidParameter, 0, 0);
  }
#else
  #define EvrNetUDP_GetSocketInvalidParameter()
#endif

/**
  \brief  Event on UDP free socket allocated (Op)
  \param  socket        allocated socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SocketAllocated(int32_t socket) {
    EventRecord2 (EvtNetUDP_SocketAllocated, socket, 0);
  }
#else
  #define EvrNetUDP_SocketAllocated(socket)
#endif

/**
  \brief  Event on UDP get socket failed, no free sockets available (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_NoSocketsAvailable(void) {
    EventRecord2 (EvtNetUDP_NoSocketsAvailable, 0, 0);
  }
#else
  #define EvrNetUDP_NoSocketsAvailable()
#endif

/**
  \brief  Event on UDP release socket (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_ReleaseSocket(int32_t socket) {
    EventRecord2 (EvtNetUDP_ReleaseSocket, socket, 0);
  }
#else
  #define EvrNetUDP_ReleaseSocket(socket)
#endif

/**
  \brief  Event on UDP release failed, not valid socket (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_ReleaseSocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetUDP_ReleaseSocketNotValid, socket, 0);
  }
#else
  #define EvrNetUDP_ReleaseSocketNotValid(socket)
#endif

/**
  \brief  Event on UDP release failed, wrong socket state (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_ReleaseSocketWrongState(int32_t socket) {
    EventRecord2 (EvtNetUDP_ReleaseSocketWrongState, socket, 0);
  }
#else
  #define EvrNetUDP_ReleaseSocketWrongState(socket)
#endif

/**
  \brief  Event on UDP open socket for communication (Op)
  \param  socket        socket handle
  \param  port          local port number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_OpenSocket(int32_t socket, uint16_t port) {
    EventRecord2 (EvtNetUDP_OpenSocket, socket, port);
  }
#else
  #define EvrNetUDP_OpenSocket(socket, port)
#endif

/**
  \brief  Event on UDP open failed, not valid socket (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_OpenSocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetUDP_OpenSocketNotValid, socket, 0);
  }
#else
  #define EvrNetUDP_OpenSocketNotValid(socket)
#endif

/**
  \brief  Event on UDP open socket failed, wrong socket state (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_OpenSocketWrongState(int32_t socket) {
    EventRecord2 (EvtNetUDP_OpenSocketWrongState, socket, 0);
  }
#else
  #define EvrNetUDP_OpenSocketWrongState(socket)
#endif

/**
  \brief  Event on UDP local port assigned in open socket request (Op)
  \param  local_port    assigned local port number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_OpenLocalPortAssigned(uint16_t local_port) {
    EventRecord2 (EvtNetUDP_OpenLocalPortAssigned, local_port, 0);
  }
#else
  #define EvrNetUDP_OpenLocalPortAssigned(local_port)
#endif

/**
  \brief  Event on UDP open socket failed, requested port already used (Error)
  \param  socket        socket handle
  \param  port          local port number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_OpenLocalPortInUse(int32_t socket, uint16_t port) {
    EventRecord2 (EvtNetUDP_OpenLocalPortInUse, socket, port);
  }
#else
  #define EvrNetUDP_OpenLocalPortInUse(socket, port)
#endif

/**
  \brief  Event on UDP close socket (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_CloseSocket(int32_t socket) {
    EventRecord2 (EvtNetUDP_CloseSocket, socket, 0);
  }
#else
  #define EvrNetUDP_CloseSocket(socket)
#endif

/**
  \brief  Event on UDP close socket failed, not valid socket (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_CloseSocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetUDP_CloseSocketNotValid, socket, 0);
  }
#else
  #define EvrNetUDP_CloseSocketNotValid(socket)
#endif

/**
  \brief  Event on UDP set socket option (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SetOptionSocket(int32_t socket) {
    EventRecord2 (EvtNetUDP_SetOptionSocket, socket, 0);
  }
#else
  #define EvrNetUDP_SetOptionSocket(socket)
#endif

/**
  \brief  Event on UDP set socket option failed, not valid socket (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SetOptionSocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetUDP_SetOptionSocketNotValid, socket, 0);
  }
#else
  #define EvrNetUDP_SetOptionSocketNotValid(socket)
#endif

/**
  \brief  Event on UDP set socket option failed, wrong socket state (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SetOptionSocketWrongState(int32_t socket) {
    EventRecord2 (EvtNetUDP_SetOptionSocketWrongState, socket, 0);
  }
#else
  #define EvrNetUDP_SetOptionSocketWrongState(socket)
#endif

/**
  \brief  Event on UDP set socket option Type Of Service for IPv4 (Op)
  \param  ip4_tos       type of service value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SetOptionTos(uint8_t ip4_tos) {
    EventRecord2 (EvtNetUDP_SetOptionTos, ip4_tos, 0);
  }
#else
  #define EvrNetUDP_SetOptionTos(ip4_tos)
#endif

/**
  \brief  Event on UDP set socket option Time To Live for IPv4 (Op)
  \param  ip4_ttl       time to live value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SetOptionTtl(uint8_t ip4_ttl) {
    EventRecord2 (EvtNetUDP_SetOptionTtl, ip4_ttl, 0);
  }
#else
  #define EvrNetUDP_SetOptionTtl(ip4_ttl)
#endif

/**
  \brief  Event on UDP set socket option Traffic Class for IPv6 (Op)
  \param  ip6_tclass    traffic class value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SetOptionTclass(uint8_t ip6_tclass) {
    EventRecord2 (EvtNetUDP_SetOptionTclass, ip6_tclass, 0);
  }
#else
  #define EvrNetUDP_SetOptionTclass(ip6_tclass)
#endif

/**
  \brief  Event on UDP set socket option Hop Limit for IPv6 (Op)
  \param  ip6_hoplimit  hop limit value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SetOptionHopLimit(uint8_t ip6_hoplimit) {
    EventRecord2 (EvtNetUDP_SetOptionHopLimit, ip6_hoplimit, 0);
  }
#else
  #define EvrNetUDP_SetOptionHopLimit(ip6_hoplimit)
#endif

/**
  \brief  Event on UDP set socket option checksum calculation options (Op)
  \param  checksum      checksum calculation options bitmap
                         - 0x01: calculate checksum for send frames
                         - 0x02: verify checksum for received frames
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SetOptionChecksum(uint8_t checksum) {
    EventRecord2 (EvtNetUDP_SetOptionChecksum, checksum & 1, (checksum >> 1) & 1);
  }
#else
  #define EvrNetUDP_SetOptionChecksum(checksum)
#endif

/**
  \brief  Event on UDP wrong set socket option (Error)
  \param  socket        socket handle
  \param  udp_option    wrong set option value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SetOptionWrongOption(int32_t socket, uint8_t udp_option) {
    EventRecord2 (EvtNetUDP_SetOptionWrongOption, socket, udp_option);
  }
#else
  #define EvrNetUDP_SetOptionWrongOption(socket, udp_option)
#endif

/**
  \brief  Event on UDP wrong value for set socket option (Error)
  \param  socket        socket handle
  \param  opt_value     wrong value for set option
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SetOptionWrongValue(int32_t socket, uint8_t opt_value) {
    EventRecord2 (EvtNetUDP_SetOptionWrongValue, socket, opt_value);
  }
#else
  #define EvrNetUDP_SetOptionWrongValue(socket, opt_value)
#endif

/**
  \brief  Event on UDP get buffer failed, out of memory (Error)
  \param  mem_size      requested memory size
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_GetBufferFailed(uint16_t mem_size) {
    EventRecord2 (EvtNetUDP_GetBufferFailed, mem_size, 0);
  }
#else
  #define EvrNetUDP_GetBufferFailed(mem_size)
#endif

/**
  \brief  Event on UDP send frame (Op)
  \param  socket        socket handle
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SendFrame(int32_t socket, uint32_t length) {
    EventRecord2 (EvtNetUDP_SendFrame, socket, length);
  }
#else
  #define EvrNetUDP_SendFrame(socket, length)
#endif

/**
  \brief  Event on UDP send buffer is invalid (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SendBufferInvalid(int32_t socket) {
    EventRecord2 (EvtNetUDP_SendBufferInvalid, socket, 0);
  }
#else
  #define EvrNetUDP_SendBufferInvalid(socket)
#endif

/**
  \brief  Event on UDP send socket handle is not valid (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SendSocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetUDP_SendSocketNotValid, socket, 0);
  }
#else
  #define EvrNetUDP_SendSocketNotValid(socket)
#endif

/**
  \brief  Event on UDP send destination address not specified (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SendAddressUnspecified(int32_t socket) {
    EventRecord2 (EvtNetUDP_SendAddressUnspecified, socket, 0);
  }
#else
  #define EvrNetUDP_SendAddressUnspecified(socket)
#endif

/**
  \brief  Event on UDP send port undefined (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SendPortUndefined(int32_t socket) {
    EventRecord2 (EvtNetUDP_SendPortUndefined, socket, 0);
  }
#else
  #define EvrNetUDP_SendPortUndefined(socket)
#endif

/**
  \brief  Event on UDP send socket not open, invalid socket state (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SendSocketNotOpen(int32_t socket) {
    EventRecord2 (EvtNetUDP_SendSocketNotOpen, socket, 0);
  }
#else
  #define EvrNetUDP_SendSocketNotOpen(socket)
#endif

/**
  \brief  Event on UDP send 0-length frame, frame is dumped (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SendZeroLengthFrame(int32_t socket) {
    EventRecord2 (EvtNetUDP_SendZeroLengthFrame, socket, 0);
  }
#else
  #define EvrNetUDP_SendZeroLengthFrame(socket)
#endif

/**
  \brief  Event on UDP send truncated over-size packet (Op)
  \param  new_length    truncated frame length
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_SendSizeTruncated(uint32_t new_length) {
    EventRecord2 (EvtNetUDP_SendSizeTruncated, new_length, 0);
  }
#else
  #define EvrNetUDP_SendSizeTruncated(new_length)
#endif

/**
  \brief  Event on UDP send/receive frame header info (Detail)
  \param  udp_header    pointer to UDP frame header of 8 bytes
                         - SrcPort (2 bytes)
                         - DstPort (2 bytes)
                         - Len     (2 bytes)
                         - Chksum  (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_HeaderInfo(const void *udp_header) {
    EventRecordData (EvtNetUDP_HeaderInfo, udp_header, 8);
  }
#else
  #define EvrNetUDP_HeaderInfo(udp_header)
#endif

/**
  \brief  Event on UDP receive frame (Op)
  \param  length        frame length in bytes
  \param  ip_version    internet protocol version
                         - 0: IPv4
                         - 1: IPv6
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_ReceiveFrame(uint32_t length, uint8_t ip_version) {
    EventRecord2 (EvtNetUDP_ReceiveFrame, length, ip_version);
  }
#else
  #define EvrNetUDP_ReceiveFrame(length, ip_version)
#endif

/**
  \brief  Event on UDP received frame too short (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_FrameTooShort(uint32_t length) {
    EventRecord2 (EvtNetUDP_FrameTooShort, length, 0);
  }
#else
  #define EvrNetUDP_FrameTooShort(length)
#endif

/**
  \brief  Event on UDP received frame mapped to a socket (Op)
  \param  socket        mapped socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_MappedToSocket(int32_t socket) {
    EventRecord2 (EvtNetUDP_MappedToSocket, socket, 0);
  }
#else
  #define EvrNetUDP_MappedToSocket(socket)
#endif

/**
  \brief  Event on UDP received frame not mapped, no open sockets found (Op)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_FrameNotMapped(uint32_t length) {
    EventRecord2 (EvtNetUDP_FrameNotMapped, length, 0);
  }
#else
  #define EvrNetUDP_FrameNotMapped(length)
#endif

/**
  \brief  Event on UDP frame checksum check failed (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetUDP_ChecksumFailed(int32_t socket) {
    EventRecord2 (EvtNetUDP_ChecksumFailed, socket, 0);
  }
#else
  #define EvrNetUDP_ChecksumFailed(socket)
#endif


// NetTCP event identifiers ----------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetTCP_InitSockets               EventID (EventLevelOp,    EvtNetTCP,  0)
#define EvtNetTCP_GetSocketInvalidParameter EventID (EventLevelError, EvtNetTCP,  1)
#define EvtNetTCP_SocketAllocated           EventID (EventLevelOp,    EvtNetTCP,  2)
#define EvtNetTCP_NoSocketsAvailable        EventID (EventLevelError, EvtNetTCP,  3)
#define EvtNetTCP_ReleaseSocket             EventID (EventLevelOp,    EvtNetTCP,  4)
#define EvtNetTCP_ReleaseSocketNotValid     EventID (EventLevelError, EvtNetTCP,  5)
#define EvtNetTCP_ReleaseSocketWrongState   EventID (EventLevelError, EvtNetTCP,  6)
#define EvtNetTCP_ListenSocket              EventID (EventLevelOp,    EvtNetTCP,  7)
#define EvtNetTCP_ListenSocketNotValid      EventID (EventLevelError, EvtNetTCP,  8)
#define EvtNetTCP_ListenPortUndefined       EventID (EventLevelError, EvtNetTCP,  9)
#define EvtNetTCP_ListenSocketWrongState    EventID (EventLevelError, EvtNetTCP, 10)
#define EvtNetTCP_ConnectSocket             EventID (EventLevelOp,    EvtNetTCP, 11)
#define EvtNetTCP_ConnectSocketNotValid     EventID (EventLevelError, EvtNetTCP, 12)
#define EvtNetTCP_ConnectAddressUnspecified EventID (EventLevelError, EvtNetTCP, 13)
#define EvtNetTCP_ConnectPortUndefined      EventID (EventLevelError, EvtNetTCP, 14)
#define EvtNetTCP_ShowNetAddressIp4         EventID (EventLevelOp,    EvtNetTCP, 15)
#define EvtNetTCP_ShowNetAddressIp6         EventID (EventLevelOp,    EvtNetTCP, 16)
#define EvtNetTCP_ConnectLocalPortInvalid   EventID (EventLevelError, EvtNetTCP, 17)
#define EvtNetTCP_ConnectLocalPortAssigned  EventID (EventLevelOp,    EvtNetTCP, 18)
#define EvtNetTCP_ConnectSocketWrongState   EventID (EventLevelError, EvtNetTCP, 19)
#define EvtNetTCP_ShowRttVariables          EventID (EventLevelDetail,EvtNetTCP, 20)
#define EvtNetTCP_GetBufferFailed           EventID (EventLevelError, EvtNetTCP, 21)
#define EvtNetTCP_SendFrame                 EventID (EventLevelOp,    EvtNetTCP, 22)
#define EvtNetTCP_SendBufferInvalid         EventID (EventLevelError, EvtNetTCP, 23)
#define EvtNetTCP_SendSocketNotValid        EventID (EventLevelError, EvtNetTCP, 24)
#define EvtNetTCP_SendSocketNotConnected    EventID (EventLevelError, EvtNetTCP, 25)
#define EvtNetTCP_SendSocketClosing         EventID (EventLevelError, EvtNetTCP, 26)
#define EvtNetTCP_SendReenteredCall         EventID (EventLevelError, EvtNetTCP, 27)
#define EvtNetTCP_SendDataUnacked           EventID (EventLevelError, EvtNetTCP, 28)
#define EvtNetTCP_SendMssExceeded           EventID (EventLevelError, EvtNetTCP, 29)
#define EvtNetTCP_SendZeroLengthFrame       EventID (EventLevelOp,    EvtNetTCP, 30)
#define EvtNetTCP_CloseSocket               EventID (EventLevelOp,    EvtNetTCP, 31)
#define EvtNetTCP_CloseSocketNotValid       EventID (EventLevelError, EvtNetTCP, 32)
#define EvtNetTCP_CloseDataUnacked          EventID (EventLevelOp,    EvtNetTCP, 33)
#define EvtNetTCP_CloseSocketWrongState     EventID (EventLevelError, EvtNetTCP, 34)
#define EvtNetTCP_AbortSocket               EventID (EventLevelOp,    EvtNetTCP, 35)
#define EvtNetTCP_AbortSocketNotValid       EventID (EventLevelError, EvtNetTCP, 36)
#define EvtNetTCP_AbortSocketWrongState     EventID (EventLevelError, EvtNetTCP, 37)
#define EvtNetTCP_SendReadySocketNotValid   EventID (EventLevelError, EvtNetTCP, 38)
#define EvtNetTCP_SendReadyReenteredCall    EventID (EventLevelError, EvtNetTCP, 39)
#define EvtNetTCP_ResetWindowSocketNotValid EventID (EventLevelError, EvtNetTCP, 40)
#define EvtNetTCP_ResetWindowNotConnected   EventID (EventLevelError, EvtNetTCP, 41)
#define EvtNetTCP_ResetWindowNoFlowControl  EventID (EventLevelError, EvtNetTCP, 42)
#define EvtNetTCP_ResetWindowUpdate         EventID (EventLevelOp,    EvtNetTCP, 43)
#define EvtNetTCP_SetOptionSocket           EventID (EventLevelOp,    EvtNetTCP, 44)
#define EvtNetTCP_SetOptionSocketNotValid   EventID (EventLevelError, EvtNetTCP, 45)
#define EvtNetTCP_SetOptionSocketWrongState EventID (EventLevelError, EvtNetTCP, 46)
#define EvtNetTCP_SetOptionTos              EventID (EventLevelOp,    EvtNetTCP, 47)
#define EvtNetTCP_SetOptionTclass           EventID (EventLevelOp,    EvtNetTCP, 48)
#define EvtNetTCP_SetOptionTimeout          EventID (EventLevelOp,    EvtNetTCP, 49)
#define EvtNetTCP_SetOptionKeepAlive        EventID (EventLevelOp,    EvtNetTCP, 50)
#define EvtNetTCP_SetOptionFlowControl      EventID (EventLevelOp,    EvtNetTCP, 51)
#define EvtNetTCP_SetOptionDelayedAck       EventID (EventLevelOp,    EvtNetTCP, 52)
#define EvtNetTCP_SetOptionWrongOption      EventID (EventLevelError, EvtNetTCP, 53)
#define EvtNetTCP_SetOptionWrongValue       EventID (EventLevelError, EvtNetTCP, 54)
#define EvtNetTCP_SendDelayedAck            EventID (EventLevelOp,    EvtNetTCP, 55)
#define EvtNetTCP_SendKeepAliveProbe        EventID (EventLevelOp,    EvtNetTCP, 56)
#define EvtNetTCP_KeepAliveTimeoutClosing   EventID (EventLevelOp,    EvtNetTCP, 57)
#define EvtNetTCP_CallbackEventAck          EventID (EventLevelOp,    EvtNetTCP, 58)
#define EvtNetTCP_ResendOnTimeout           EventID (EventLevelOp,    EvtNetTCP, 59)
#define EvtNetTCP_ShowCongestionVariables   EventID (EventLevelDetail,EvtNetTCP, 60)
#define EvtNetTCP_TimeoutInState            EventID (EventLevelOp,    EvtNetTCP, 61)
#define EvtNetTCP_TwaitTimeoutClosing       EventID (EventLevelOp,    EvtNetTCP, 62)
#define EvtNetTCP_ClosingTimeout            EventID (EventLevelOp,    EvtNetTCP, 63)
#define EvtNetTCP_NoRetriesLeft             EventID (EventLevelError, EvtNetTCP, 64)
#define EvtNetTCP_ReceiveFrame              EventID (EventLevelOp,    EvtNetTCP, 65)
#define EvtNetTCP_FrameTooShort             EventID (EventLevelError, EvtNetTCP, 66)
#define EvtNetTCP_MappedToSocket            EventID (EventLevelOp,    EvtNetTCP, 67)
#define EvtNetTCP_FrameNotMapped            EventID (EventLevelOp,    EvtNetTCP, 68)
#define EvtNetTCP_ChecksumFailed            EventID (EventLevelError, EvtNetTCP, 69)
#define EvtNetTCP_HeaderInfo                EventID (EventLevelDetail,EvtNetTCP, 70)
#define EvtNetTCP_RstInWindow               EventID (EventLevelOp,    EvtNetTCP, 71)
#define EvtNetTCP_RstNotValid               EventID (EventLevelOp,    EvtNetTCP, 72)
#define EvtNetTCP_RepeatedSynAck            EventID (EventLevelOp,    EvtNetTCP, 73)
#define EvtNetTCP_AckNotSet                 EventID (EventLevelOp,    EvtNetTCP, 74)
#define EvtNetTCP_ShowSendWindow            EventID (EventLevelOp,    EvtNetTCP, 75)
#define EvtNetTCP_KeepAliveSegment          EventID (EventLevelOp,    EvtNetTCP, 76)
#define EvtNetTCP_RetransmittedSegment      EventID (EventLevelOp,    EvtNetTCP, 77)
#define EvtNetTCP_OutOfRangeSegment         EventID (EventLevelError, EvtNetTCP, 78)
#define EvtNetTCP_ZeroWindowProbe           EventID (EventLevelOp,    EvtNetTCP, 79)
#define EvtNetTCP_RemotePeerClosing         EventID (EventLevelOp,    EvtNetTCP, 80)
#define EvtNetTCP_ShowReceiveWindow         EventID (EventLevelOp,    EvtNetTCP, 81)
#define EvtNetTCP_InvalidAck                EventID (EventLevelError, EvtNetTCP, 82)
#define EvtNetTCP_SynNotSet                 EventID (EventLevelError, EvtNetTCP, 83)
#define EvtNetTCP_UserConnectionReject      EventID (EventLevelOp,    EvtNetTCP, 84)
#define EvtNetTCP_NextState                 EventID (EventLevelOp,    EvtNetTCP, 85)
#define EvtNetTCP_WrongSynAck               EventID (EventLevelError, EvtNetTCP, 86)
#define EvtNetTCP_WrongAckNumber            EventID (EventLevelError, EvtNetTCP, 87)
#define EvtNetTCP_WrongSeqNumber            EventID (EventLevelError, EvtNetTCP, 88)
#define EvtNetTCP_RepeatedSyn               EventID (EventLevelOp,    EvtNetTCP, 89)
#define EvtNetTCP_FrameUnrecognised         EventID (EventLevelError, EvtNetTCP, 90)
#define EvtNetTCP_SimultOpenNextState       EventID (EventLevelOp,    EvtNetTCP, 91)
#define EvtNetTCP_WrongFinAck               EventID (EventLevelError, EvtNetTCP, 92)
#define EvtNetTCP_FinAckNextState           EventID (EventLevelOp,    EvtNetTCP, 93)
#define EvtNetTCP_SimultCloseNextState      EventID (EventLevelOp,    EvtNetTCP, 94)
#define EvtNetTCP_AckNextState              EventID (EventLevelOp,    EvtNetTCP, 95)
#define EvtNetTCP_FinNextState              EventID (EventLevelOp,    EvtNetTCP, 96)
#define EvtNetTCP_PshAckInHalfOpen          EventID (EventLevelError, EvtNetTCP, 97)
#define EvtNetTCP_RepeatedFin               EventID (EventLevelOp,    EvtNetTCP, 98)
#define EvtNetTCP_LastAckNextState          EventID (EventLevelOp,    EvtNetTCP, 99)
#define EvtNetTCP_RstReceived               EventID (EventLevelError, EvtNetTCP,100)
#define EvtNetTCP_InvalidState              EventID (EventLevelError, EvtNetTCP,101)
#define EvtNetTCP_SendData                  EventID (EventLevelOp,    EvtNetTCP,102)
#define EvtNetTCP_SendControl               EventID (EventLevelOp,    EvtNetTCP,103)
#define EvtNetTCP_SendReset                 EventID (EventLevelOp,    EvtNetTCP,104)
#define EvtNetTCP_ParseHeaderOptions        EventID (EventLevelOp,    EvtNetTCP,105)
#define EvtNetTCP_OptionMss                 EventID (EventLevelOp,    EvtNetTCP,106)
#define EvtNetTCP_DuplicateAck              EventID (EventLevelOp,    EvtNetTCP,107)
#define EvtNetTCP_FastRetransmit            EventID (EventLevelOp,    EvtNetTCP,108)
#define EvtNetTCP_DataAcked                 EventID (EventLevelOp,    EvtNetTCP,109)
#define EvtNetTCP_ResendData                EventID (EventLevelOp,    EvtNetTCP,110)
#define EvtNetTCP_MapSocketWrongFlagsSet    EventID (EventLevelError, EvtNetTCP,111)
#define EvtNetTCP_MapSocketSynNotSet        EventID (EventLevelError, EvtNetTCP,112)
#define EvtNetTCP_MapSocketNoListenSocket   EventID (EventLevelError, EvtNetTCP,113)
#endif

/**
  \brief  Event on TCP socket initialize (Op)
  \param  num_sockets   number of available TCP sockets
  \param  max_segsize   maximum segment size in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_InitSockets(uint32_t num_sockets, uint16_t max_segsize) {
    EventRecord2 (EvtNetTCP_InitSockets, num_sockets, max_segsize);
  }
#else
  #define EvrNetTCP_InitSockets(num_sockets, max_segsize)
#endif

/**
  \brief  Event on TCP get socket failed, invalid parameter (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_GetSocketInvalidParameter(void) {
    EventRecord2 (EvtNetTCP_GetSocketInvalidParameter, 0, 0);
  }
#else
  #define EvrNetTCP_GetSocketInvalidParameter()
#endif

/**
  \brief  Event on TCP free socket allocated (Op)
  \param  socket        allocated socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SocketAllocated(int32_t socket) {
    EventRecord2 (EvtNetTCP_SocketAllocated, socket, 0);
  }
#else
  #define EvrNetTCP_SocketAllocated(socket)
#endif

/**
  \brief  Event on TCP get socket failed, no free sockets available (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_NoSocketsAvailable(void) {
    EventRecord2 (EvtNetTCP_NoSocketsAvailable, 0, 0);
  }
#else
  #define EvrNetTCP_NoSocketsAvailable()
#endif

/**
  \brief  Event on TCP release socket (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ReleaseSocket(int32_t socket) {
    EventRecord2 (EvtNetTCP_ReleaseSocket, socket, 0);
  }
#else
  #define EvrNetTCP_ReleaseSocket(socket)
#endif

/**
  \brief  Event on TCP release failed, not valid socket (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ReleaseSocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetTCP_ReleaseSocketNotValid, socket, 0);
  }
#else
  #define EvrNetTCP_ReleaseSocketNotValid(socket)
#endif

/**
  \brief  Event on TCP release failed, wrong socket state (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ReleaseSocketWrongState(int32_t socket) {
    EventRecord2 (EvtNetTCP_ReleaseSocketWrongState, socket, 0);
  }
#else
  #define EvrNetTCP_ReleaseSocketWrongState(socket)
#endif

/**
  \brief  Event on TCP listen socket request (Op)
  \param  socket        socket handle
  \param  port          local port number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ListenSocket(int32_t socket, uint16_t port) {
    EventRecord2 (EvtNetTCP_ListenSocket, socket, port);
  }
#else
  #define EvrNetTCP_ListenSocket(socket, port)
#endif

/**
  \brief  Event on TCP listen failed, not valid socket (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ListenSocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetTCP_ListenSocketNotValid, socket, 0);
  }
#else
  #define EvrNetTCP_ListenSocketNotValid(socket)
#endif

/**
  \brief  Event on TCP listen failed, listening port undefined (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ListenPortUndefined(int32_t socket) {
    EventRecord2 (EvtNetTCP_ListenPortUndefined, socket, 0);
  }
#else
  #define EvrNetTCP_ListenPortUndefined(socket)
#endif

/**
  \brief  Event on TCP listen failed, wrong socket state (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ListenSocketWrongState(int32_t socket) {
    EventRecord2 (EvtNetTCP_ListenSocketWrongState, socket, 0);
  }
#else
  #define EvrNetTCP_ListenSocketWrongState(socket)
#endif

/**
  \brief  Event on TCP connect socket request (Op)
  \param  socket        socket handle
  \param  local_port    local port number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ConnectSocket(int32_t socket, uint16_t local_port) {
    EventRecord2 (EvtNetTCP_ConnectSocket, socket, local_port);
  }
#else
  #define EvrNetTCP_ConnectSocket(socket, local_port)
#endif

/**
  \brief  Event on TCP connect failed, not valid socket (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ConnectSocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetTCP_ConnectSocketNotValid, socket, 0);
  }
#else
  #define EvrNetTCP_ConnectSocketNotValid(socket)
#endif

/**
  \brief  Event on TCP connect failed, address unspecified (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ConnectAddressUnspecified(int32_t socket) {
    EventRecord2 (EvtNetTCP_ConnectAddressUnspecified, socket, 0);
  }
#else
  #define EvrNetTCP_ConnectAddressUnspecified(socket)
#endif

/**
  \brief  Event on TCP connect failed, port undefined (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ConnectPortUndefined(int32_t socket) {
    EventRecord2 (EvtNetTCP_ConnectPortUndefined, socket, 0);
  }
#else
  #define EvrNetTCP_ConnectPortUndefined(socket)
#endif

/**
  \brief  Event on TCP display net address IPv4 (Op)
  \param  net_address   pointer to \ref NET_ADDR4 address structure (8 bytes)
  \note   Sends reduced size of net address structure with IPv4 address only.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ShowNetAddressIp4(const void *net_address) {
    EventRecordData (EvtNetTCP_ShowNetAddressIp4, net_address, 8);
  }
#else
  #define EvrNetTCP_ShowNetAddressIp4(net_address)
#endif

/**
  \brief  Event on TCP display net address IPv6 (Op)
  \param  net_address   pointer to \ref NET_ADDR address structure (20 bytes)
  \note   Sends full size of net address structure with IPv6 address only.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ShowNetAddressIp6(const void *net_address) {
    EventRecordData (EvtNetTCP_ShowNetAddressIp6, net_address, 20);
  }
#else
  #define EvrNetTCP_ShowNetAddressIp6(net_address)
#endif

/**
  \brief  Event on TCP connect failed, local port invalid (Error)
  \param  socket        socket handle
  \param  local_port    local port number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ConnectLocalPortInvalid(int32_t socket, uint16_t local_port) {
    EventRecord2 (EvtNetTCP_ConnectLocalPortInvalid, socket, local_port);
  }
#else
  #define EvrNetTCP_ConnectLocalPortInvalid(socket, local_port)
#endif

/**
  \brief  Event on TCP local port assigned in socket connect request (Op)
  \param  local_port    assigned local port number
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ConnectLocalPortAssigned(uint16_t local_port) {
    EventRecord2 (EvtNetTCP_ConnectLocalPortAssigned, local_port, 0);
  }
#else
  #define EvrNetTCP_ConnectLocalPortAssigned(local_port)
#endif

/**
  \brief  Event on TCP connect failed, wrong socket state (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ConnectSocketWrongState(int32_t socket) {
    EventRecord2 (EvtNetTCP_ConnectSocketWrongState, socket, 0);
  }
#else
  #define EvrNetTCP_ConnectSocketWrongState(socket)
#endif

/**
  \brief  Event on TCP display RTT (round trip time) estimation variables (Detail)
  \param  sa            rtt average estimator
  \param  sv            rtt deviation estimator
  \note   Those variables are taken from VJs original code in his paper
          (Congestion avoidance and control, page 20)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ShowRttVariables(int16_t sa, int16_t sv) {
    int32_t rto = ((sa>>3) + sv) * 100;
    EventRecord4 (EvtNetTCP_ShowRttVariables, rto, sa, sv, 0);
  }
#else
  #define EvrNetTCP_ShowRttVariables(sa, sv)
#endif

/**
  \brief  Event on TCP get buffer failed, out of memory (Error)
  \param  mem_size      requested memory size
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_GetBufferFailed(uint16_t mem_size) {
    EventRecord2 (EvtNetTCP_GetBufferFailed, mem_size, 0);
  }
#else
  #define EvrNetTCP_GetBufferFailed(mem_size)
#endif

/**
  \brief  Event on TCP send frame (Op)
  \param  socket        socket handle
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendFrame(int32_t socket, uint32_t length) {
    EventRecord2 (EvtNetTCP_SendFrame, socket, length);
  }
#else
  #define EvrNetTCP_SendFrame(socket, length)
#endif

/**
  \brief  Event on TCP send failed, invalid buffer (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendBufferInvalid(int32_t socket) {
    EventRecord2 (EvtNetTCP_SendBufferInvalid, socket, 0);
  }
#else
  #define EvrNetTCP_SendBufferInvalid(socket)
#endif

/**
  \brief  Event on TCP send failed, socket handle not valid (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendSocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetTCP_SendSocketNotValid, socket, 0);
  }
#else
  #define EvrNetTCP_SendSocketNotValid(socket)
#endif

/**
  \brief  Event on TCP send failed, socket not connected (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendSocketNotConnected(int32_t socket) {
    EventRecord2 (EvtNetTCP_SendSocketNotConnected, socket, 0);
  }
#else
  #define EvrNetTCP_SendSocketNotConnected(socket)
#endif

/**
  \brief  Event on TCP send failed, socket closing (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendSocketClosing(uint32_t socket) {
    EventRecord2 (EvtNetTCP_SendSocketClosing, socket, 0);
  }
#else
  #define EvrNetTCP_SendSocketClosing(socket)
#endif

/**
  \brief  Event on TCP send failed, called from a callback function (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendReenteredCall(uint32_t socket) {
    EventRecord2 (EvtNetTCP_SendReenteredCall, socket, 0);
  }
#else
  #define EvrNetTCP_SendReenteredCall(socket)
#endif

/**
  \brief  Event on TCP send failed, unacked data pending (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendDataUnacked(uint32_t socket) {
    EventRecord2 (EvtNetTCP_SendDataUnacked, socket, 0);
  }
#else
  #define EvrNetTCP_SendDataUnacked(socket)
#endif

/**
  \brief  Event on TCP send failed, Maximum Segment Size exceeded (Error)
  \param  socket        socket handle
  \note   Frame length is larger than MSS.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendMssExceeded(uint32_t socket) {
    EventRecord2 (EvtNetTCP_SendMssExceeded, socket, 0);
  }
#else
  #define EvrNetTCP_SendMssExceeded(socket)
#endif

/**
  \brief  Event on TCP send 0-length frame, frame dumped (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendZeroLengthFrame(int32_t socket) {
    EventRecord2 (EvtNetTCP_SendZeroLengthFrame, socket, 0);
  }
#else
  #define EvrNetTCP_SendZeroLengthFrame(socket)
#endif

/**
  \brief  Event on TCP close socket (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_CloseSocket(int32_t socket) {
    EventRecord2 (EvtNetTCP_CloseSocket, socket, 0);
  }
#else
  #define EvrNetTCP_CloseSocket(socket)
#endif

/**
  \brief  Event on TCP close socket failed, not valid socket (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_CloseSocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetTCP_CloseSocketNotValid, socket, 0);
  }
#else
  #define EvrNetTCP_CloseSocketNotValid(socket)
#endif

/**
  \brief  Event on TCP close pended, unacked data exist (Op)
  \param  unack_length  length of unacked data
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_CloseDataUnacked(uint32_t unack_length) {
    EventRecord2 (EvtNetTCP_CloseDataUnacked, unack_length, 0);
  }
#else
  #define EvrNetTCP_CloseDataUnacked(unack_length)
#endif

/**
  \brief  Event on TCP close failed, wrong socket state (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_CloseSocketWrongState(int32_t socket) {
    EventRecord2 (EvtNetTCP_CloseSocketWrongState, socket, 0);
  }
#else
  #define EvrNetTCP_CloseSocketWrongState(socket)
#endif

/**
  \brief  Event on TCP abort socket (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_AbortSocket(int32_t socket) {
    EventRecord2 (EvtNetTCP_AbortSocket, socket, 0);
  }
#else
  #define EvrNetTCP_AbortSocket(socket)
#endif

/**
  \brief  Event on TCP abort failed, not valid socket (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_AbortSocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetTCP_AbortSocketNotValid, socket, 0);
  }
#else
  #define EvrNetTCP_AbortSocketNotValid(socket)
#endif

/**
  \brief  Event on TCP abort failed, wrong socket state (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_AbortSocketWrongState(int32_t socket) {
    EventRecord2 (EvtNetTCP_AbortSocketWrongState, socket, 0);
  }
#else
  #define EvrNetTCP_AbortSocketWrongState(socket)
#endif

/**
  \brief  Event on TCP send ready failed, not valid socket (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendReadySocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetTCP_SendReadySocketNotValid, socket, 0);
  }
#else
  #define EvrNetTCP_SendReadySocketNotValid(socket)
#endif

/**
  \brief  Event on TCP send ready failed, called from a callback function (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendReadyReenteredCall(uint32_t socket) {
    EventRecord2 (EvtNetTCP_SendReadyReenteredCall, socket, 0);
  }
#else
  #define EvrNetTCP_SendReadyReenteredCall(socket)
#endif

/**
  \brief  Event on TCP reset window failed, not valid socket (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ResetWindowSocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetTCP_ResetWindowSocketNotValid, socket, 0);
  }
#else
  #define EvrNetTCP_ResetWindowSocketNotValid(socket)
#endif

/**
  \brief  Event on TCP reset window failed, invalid socket state (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ResetWindowNotConnected(int32_t socket) {
    EventRecord2 (EvtNetTCP_ResetWindowNotConnected, socket, 0);
  }
#else
  #define EvrNetTCP_ResetWindowNotConnected(socket)
#endif

/**
  \brief  Event on TCP reset window failed, flow-control not enabled (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ResetWindowNoFlowControl(int32_t socket) {
    EventRecord2 (EvtNetTCP_ResetWindowNoFlowControl, socket, 0);
  }
#else
  #define EvrNetTCP_ResetWindowNoFlowControl(socket)
#endif

/**
  \brief  Event on TCP reset window update (Error)
  \param  socket        socket handle
  \param  window_size   updated receive window size
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ResetWindowUpdate(int32_t socket, uint16_t window_size) {
    EventRecord2 (EvtNetTCP_ResetWindowUpdate, socket, window_size);
  }
#else
  #define EvrNetTCP_ResetWindowUpdate(socket, window_size)
#endif

/**
  \brief  Event on TCP set socket option (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SetOptionSocket(int32_t socket) {
    EventRecord2 (EvtNetTCP_SetOptionSocket, socket, 0);
  }
#else
  #define EvrNetTCP_SetOptionSocket(socket)
#endif

/**
  \brief  Event on TCP set socket option failed, not valid socket (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SetOptionSocketNotValid(int32_t socket) {
    EventRecord2 (EvtNetTCP_SetOptionSocketNotValid, socket, 0);
  }
#else
  #define EvrNetTCP_SetOptionSocketNotValid(socket)
#endif

/**
  \brief  Event on TCP set socket option failed, wrong socket state (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SetOptionSocketWrongState(int32_t socket) {
    EventRecord2 (EvtNetTCP_SetOptionSocketWrongState, socket, 0);
  }
#else
  #define EvrNetTCP_SetOptionSocketWrongState(socket)
#endif

/**
  \brief  Event on TCP set socket option Type Of Service for IPv4 (Op)
  \param  ip4_tos       type of service value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SetOptionTos(uint8_t ip4_tos) {
    EventRecord2 (EvtNetTCP_SetOptionTos, ip4_tos, 0);
  }
#else
  #define EvrNetTCP_SetOptionTos(ip4_tos)
#endif

/**
  \brief  Event on TCP set socket option Traffic Class for IPv6 (Op)
  \param  ip6_tclass    traffic class value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SetOptionTclass(uint8_t ip6_tclass) {
    EventRecord2 (EvtNetTCP_SetOptionTclass, ip6_tclass, 0);
  }
#else
  #define EvrNetTCP_SetOptionTclass(ip6_tclass)
#endif

/**
  \brief  Event on TCP set socket option connection timeout (Op)
  \param  timeout       connection or keep-alive timeout in seconds
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SetOptionTimeout(uint16_t timeout) {
    EventRecord2 (EvtNetTCP_SetOptionTimeout, timeout, 0);
  }
#else
  #define EvrNetTCP_SetOptionTimeout(timeout)
#endif

/**
  \brief  Event on TCP set socket keep-alive option (Op)
  \param  enable        keep-alive state
                         - 0: disable
                         - 1: enable
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SetOptionKeepAlive(int32_t enable) {
    EventRecord2 (EvtNetTCP_SetOptionKeepAlive, enable, 0);
  }
#else
  #define EvrNetTCP_SetOptionKeepAlive(enable)
#endif

/**
  \brief  Event on TCP set socket flow-control option (Op)
  \param  enable        flow-control state
                         - 0: disable
                         - 1: enable
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SetOptionFlowControl(int32_t enable) {
    EventRecord2 (EvtNetTCP_SetOptionFlowControl, enable, 0);
  }
#else
  #define EvrNetTCP_SetOptionFlowControl(enable)
#endif

/**
  \brief  Event on TCP set socket delayed-acknowledge option (Op)
  \param  enable        delayed-acknowledge state
                         - 0: disable
                         - 1: enable
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SetOptionDelayedAck(int32_t enable) {
    EventRecord2 (EvtNetTCP_SetOptionDelayedAck, enable, 0);
  }
#else
  #define EvrNetTCP_SetOptionDelayedAck(enable)
#endif

/**
  \brief  Event on TCP wrong set socket option (Error)
  \param  socket        socket handle
  \param  tcp_option    wrong set option value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SetOptionWrongOption(int32_t socket, uint8_t tcp_option) {
    EventRecord2 (EvtNetTCP_SetOptionWrongOption, socket, tcp_option);
  }
#else
  #define EvrNetTCP_SetOptionWrongOption(socket, tcp_option)
#endif

/**
  \brief  Event on TCP wrong value for set socket option (Error)
  \param  socket        socket handle
  \param  opt_value     wrong value for set option
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SetOptionWrongValue(int32_t socket, uint8_t opt_value) {
    EventRecord2 (EvtNetTCP_SetOptionWrongValue, socket, opt_value);
  }
#else
  #define EvrNetTCP_SetOptionWrongValue(socket, opt_value)
#endif

/**
  \brief  Event on TCP send delayed-acknowledge (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendDelayedAck(int32_t socket) {
    EventRecord2 (EvtNetTCP_SendDelayedAck, socket, 0);
  }
#else
  #define EvrNetTCP_SendDelayedAck(socket)
#endif

/**
  \brief  Event on TCP send keep-alive probe (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendKeepAliveProbe(int32_t socket) {
    EventRecord2 (EvtNetTCP_SendKeepAliveProbe, socket, 0);
  }
#else
  #define EvrNetTCP_SendKeepAliveProbe(socket)
#endif

/**
  \brief  Event on TCP keep-alive timeout no response, close socket (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_KeepAliveTimeoutClosing(int32_t socket) {
    EventRecord2 (EvtNetTCP_KeepAliveTimeoutClosing, socket, 0);
  }
#else
  #define EvrNetTCP_KeepAliveTimeoutClosing(socket)
#endif

/**
  \brief  Event on TCP acknowledge callback notification to the user (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_CallbackEventAck(int32_t socket) {
    EventRecord2 (EvtNetTCP_CallbackEventAck, socket, 0);
  }
#else
  #define EvrNetTCP_CallbackEventAck(socket)
#endif

/**
  \brief  Event on TCP resend data on timeout (Op)
  \param  socket        socket handle
  \param  length        length of data to resend
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ResendOnTimeout(int32_t socket, uint32_t length) {
    EventRecord2 (EvtNetTCP_ResendOnTimeout, socket, length);
  }
#else
  #define EvrNetTCP_ResendOnTimeout(socket, length)
#endif

/**
  \brief  Event on TCP display congestion avoidance/control variables (Detail)
  \param  cwnd          congestion window
  \param  ssth          slow start threshold
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ShowCongestionVariables(uint16_t cwnd, uint16_t ssth) {
    EventRecord2 (EvtNetTCP_ShowCongestionVariables, cwnd, ssth);
  }
#else
  #define EvrNetTCP_ShowCongestionVariables(cwnd, ssth)
#endif

/**
  \brief  Event on TCP timeout expired in current state (Op)
  \param  socket        socket handle
  \param  state         current socket state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_TimeoutInState(int32_t socket, uint32_t state) {
    EventRecord2 (EvtNetTCP_TimeoutInState, socket, state);
  }
#else
  #define EvrNetTCP_TimeoutInState(socket, state)
#endif

/**
  \brief  Event on TCP timeout in TIME_WAIT state, closing socket (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_TwaitTimeoutClosing(int32_t socket) {
    EventRecord2 (EvtNetTCP_TwaitTimeoutClosing, socket, 0);
  }
#else
  #define EvrNetTCP_TwaitTimeoutClosing(socket)
#endif

/**
  \brief  Event on TCP timeout in CLOSING, FIN_WAIT_1 or LAST_ACK state (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ClosingTimeout(int32_t socket) {
    EventRecord2 (EvtNetTCP_ClosingTimeout, socket, 0);
  }
#else
  #define EvrNetTCP_ClosingTimeout(socket)
#endif

/**
  \brief  Event on TCP no retries left (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_NoRetriesLeft(int32_t socket) {
    EventRecord2 (EvtNetTCP_NoRetriesLeft, socket, 0);
  }
#else
  #define EvrNetTCP_NoRetriesLeft(socket)
#endif

/**
  \brief  Event on TCP receive frame (Op)
  \param  length        frame length in bytes
  \param  ip_version    internet protocol version
                         - 0: IPv4
                         - 1: IPv6
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ReceiveFrame(uint32_t length, uint8_t ip_version) {
    EventRecord2 (EvtNetTCP_ReceiveFrame, length, ip_version);
  }
#else
  #define EvrNetTCP_ReceiveFrame(length, ip_version)
#endif

/**
  \brief  Event on TCP received frame too short (Error)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_FrameTooShort(uint32_t length) {
    EventRecord2 (EvtNetTCP_FrameTooShort, length, 0);
  }
#else
  #define EvrNetTCP_FrameTooShort(length)
#endif

/**
  \brief  Event on TCP received frame not mapped, no active socket found (Op)
  \param  length        frame length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_FrameNotMapped(uint32_t length) {
    EventRecord2 (EvtNetTCP_FrameNotMapped, length, 0);
  }
#else
  #define EvrNetTCP_FrameNotMapped(length)
#endif

/**
  \brief  Event on TCP received frame mapped to a socket (Op)
  \param  socket        mapped socket handle
  \param  state         current socket state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_MappedToSocket(int32_t socket, uint32_t state) {
    EventRecord2 (EvtNetTCP_MappedToSocket, socket, state);
  }
#else
  #define EvrNetTCP_MappedToSocket(socket, state)
#endif

/**
  \brief  Event on TCP frame checksum check failed (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ChecksumFailed(int32_t socket) {
    EventRecord2 (EvtNetTCP_ChecksumFailed, socket, 0);
  }
#else
  #define EvrNetTCP_ChecksumFailed(socket)
#endif

/**
  \brief  Event on TCP send/receive frame header info (Detail)
  \param  tcp_header    pointer to TCP frame header of 20 bytes
                         - SrcPort (2 bytes)
                         - DstPort (2 bytes)
                         - SeqNr   (4 bytes)
                         - AckNr   (4 bytes)
                         - HLen    (1 byte)
                         - Flags   (1 byte)
                         - Window  (2 bytes)
                         - Chksum  (2 bytes)
                         - UrgPtr  (2 bytes)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_HeaderInfo(const void *tcp_header) {
    EventRecordData (EvtNetTCP_HeaderInfo, tcp_header, 20);
  }
#else
  #define EvrNetTCP_HeaderInfo(tcp_header)
#endif

/**
  \brief  Event on TCP RST-flag received within current receive window (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_RstInWindow(void) {
    EventRecord2 (EvtNetTCP_RstInWindow, 0, 0);
  }
#else
  #define EvrNetTCP_RstInWindow()
#endif

/**
  \brief  Event on TCP RST-flag received outside current receive window (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_RstNotValid(void) {
    EventRecord2 (EvtNetTCP_RstNotValid, 0, 0);
  }
#else
  #define EvrNetTCP_RstNotValid()
#endif

/**
  \brief  Event on TCP repeated SYN+ACK-flags received (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_RepeatedSynAck(void) {
    EventRecord2 (EvtNetTCP_RepeatedSynAck, 0, 0);
  }
#else
  #define EvrNetTCP_RepeatedSynAck()
#endif

/**
  \brief  Event on TCP ACK-flag not set in received frame (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_AckNotSet(void) {
    EventRecord2 (EvtNetTCP_AckNotSet, 0, 0);
  }
#else
  #define EvrNetTCP_AckNotSet()
#endif

/**
  \brief  Event on TCP display current sending window size (Op)
  \param  send_window   current sending window size
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ShowSendWindow(uint16_t send_window) {
    EventRecord2 (EvtNetTCP_ShowSendWindow, send_window, 0);
  }
#else
  #define EvrNetTCP_ShowSendWindow(send_window)
#endif

/**
  \brief  Event on TCP keep-alive frame received (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_KeepAliveSegment(void) {
    EventRecord2 (EvtNetTCP_KeepAliveSegment, 0, 0);
  }
#else
  #define EvrNetTCP_KeepAliveSegment()
#endif

/**
  \brief  Event on TCP retransmitted frame received (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_RetransmittedSegment(void) {
    EventRecord2 (EvtNetTCP_RetransmittedSegment, 0, 0);
  }
#else
  #define EvrNetTCP_RetransmittedSegment()
#endif

/**
  \brief  Event on TCP out of range segment received (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_OutOfRangeSegment(int32_t socket) {
    EventRecord2 (EvtNetTCP_OutOfRangeSegment, socket, 0);
  }
#else
  #define EvrNetTCP_OutOfRangeSegment(socket)
#endif

/**
  \brief  Event on TCP zero-window probe received (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ZeroWindowProbe(void) {
    EventRecord2 (EvtNetTCP_ZeroWindowProbe, 0, 0);
  }
#else
  #define EvrNetTCP_ZeroWindowProbe()
#endif

/**
  \brief  Event on TCP FIN-flag received, remote peer wants to close (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_RemotePeerClosing(void) {
    EventRecord2 (EvtNetTCP_RemotePeerClosing, 0, 0);
  }
#else
  #define EvrNetTCP_RemotePeerClosing()
#endif

/**
  \brief  Event on TCP display current receiving window size (Op)
  \param  rec_window    current receiving window size
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ShowReceiveWindow(uint16_t rec_window) {
    EventRecord2 (EvtNetTCP_ShowReceiveWindow, rec_window, 0);
  }
#else
  #define EvrNetTCP_ShowReceiveWindow(rec_window)
#endif

/**
  \brief  Event on TCP ACK-flag set received, invalid in state LISTEN (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_InvalidAck(int32_t socket) {
    EventRecord2 (EvtNetTCP_InvalidAck, socket, 0);
  }
#else
  #define EvrNetTCP_InvalidAck(socket)
#endif

/**
  \brief  Event on TCP SYN-flag not set in received frame (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SynNotSet(int32_t socket) {
    EventRecord2 (EvtNetTCP_SynNotSet, socket, 0);
  }
#else
  #define EvrNetTCP_SynNotSet(socket)
#endif

/**
  \brief  Event on TCP user rejected inbound connection (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_UserConnectionReject(void) {
    EventRecord2 (EvtNetTCP_UserConnectionReject, 0, 0);
  }
#else
  #define EvrNetTCP_UserConnectionReject()
#endif

/**
  \brief  Event on TCP transition to next state (Op)
  \param  state         next socket state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_NextState(uint32_t state) {
    EventRecord2 (EvtNetTCP_NextState, state, 0);
  }
#else
  #define EvrNetTCP_NextState(state)
#endif

/**
  \brief  Event on TCP SYN+ACK-flags set but wrong ack number (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_WrongSynAck(int32_t socket) {
    EventRecord2 (EvtNetTCP_WrongSynAck, socket, 0);
  }
#else
  #define EvrNetTCP_WrongSynAck(socket)
#endif

/**
  \brief  Event on TCP ACK-flag set but wrong ack number (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_WrongAckNumber(int32_t socket) {
    EventRecord2 (EvtNetTCP_WrongAckNumber, socket, 0);
  }
#else
  #define EvrNetTCP_WrongAckNumber(socket)
#endif

/**
  \brief  Event on TCP ACK-flag set but wrong seq number (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_WrongSeqNumber(int32_t socket) {
    EventRecord2 (EvtNetTCP_WrongSeqNumber, socket, 0);
  }
#else
  #define EvrNetTCP_WrongSeqNumber(socket)
#endif

/**
  \brief  Event on TCP repeated SYN-flag set frame received (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_RepeatedSyn(void) {
    EventRecord2 (EvtNetTCP_RepeatedSyn, 0, 0);
  }
#else
  #define EvrNetTCP_RepeatedSyn()
#endif

/**
  \brief  Event on TCP unrecognised frame received (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_FrameUnrecognised(int32_t socket) {
    EventRecord2 (EvtNetTCP_FrameUnrecognised, socket, 0);
  }
#else
  #define EvrNetTCP_FrameUnrecognised(socket)
#endif

/**
  \brief  Event on TCP SYN-flag set received in simultaneous open (Op)
  \param  state         next socket state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SimultOpenNextState(uint32_t state) {
    EventRecord2 (EvtNetTCP_SimultOpenNextState, state, 0);
  }
#else
  #define EvrNetTCP_SimultOpenNextState(state)
#endif

/**
  \brief  Event on TCP frame with FIN+ACK-flags set but wrong ack number (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_WrongFinAck(int32_t socket) {
    EventRecord2 (EvtNetTCP_WrongFinAck, socket, 0);
  }
#else
  #define EvrNetTCP_WrongFinAck(socket)
#endif

/**
  \brief  Event on TCP frame with FIN+ACK-flags received (Op)
  \param  state         next socket state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_FinAckNextState(uint32_t state) {
    EventRecord2 (EvtNetTCP_FinAckNextState, state, 0);
  }
#else
  #define EvrNetTCP_FinAckNextState(state)
#endif

/**
  \brief  Event on TCP frame with FIN-flag received in simultaneous close (Op)
  \param  state         next socket state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SimultCloseNextState(uint32_t state) {
    EventRecord2 (EvtNetTCP_SimultCloseNextState, state, 0);
  }
#else
  #define EvrNetTCP_SimultCloseNextState(state)
#endif

/**
  \brief  Event on TCP frame with ACK-flag received (Op)
  \param  state         next socket state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_AckNextState(uint32_t state) {
    EventRecord2 (EvtNetTCP_AckNextState, state, 0);
  }
#else
  #define EvrNetTCP_AckNextState(state)
#endif

/**
  \brief  Event on TCP frame with FIN-flag received (Op)
  \param  state         next socket state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_FinNextState(uint32_t state) {
    EventRecord2 (EvtNetTCP_FinNextState, state, 0);
  }
#else
  #define EvrNetTCP_FinNextState(state)
#endif

/**
  \brief  Event on TCP PSH+ACK-flags received in half open state FIN_WAIT_2 (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_PshAckInHalfOpen(int32_t socket) {
    EventRecord2 (EvtNetTCP_PshAckInHalfOpen, socket, 0);
  }
#else
  #define EvrNetTCP_PshAckInHalfOpen(socket)
#endif

/**
  \brief  Event on TCP repeated FIN-flag received (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_RepeatedFin(void) {
    EventRecord2 (EvtNetTCP_RepeatedFin, 0, 0);
  }
#else
  #define EvrNetTCP_RepeatedFin()
#endif

/**
  \brief  Event on TCP last ACK-flag received (Op)
  \param  state         next socket state
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_LastAckNextState(uint32_t state) {
    EventRecord2 (EvtNetTCP_LastAckNextState, state, 0);
  }
#else
  #define EvrNetTCP_LastAckNextState(state)
#endif

/**
  \brief  Event on TCP RST-flag received (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_RstReceived(int32_t socket) {
    EventRecord2 (EvtNetTCP_RstReceived, socket, 0);
  }
#else
  #define EvrNetTCP_RstReceived(socket)
#endif

/**
  \brief  Event on TCP socket in invalid state (Error)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_InvalidState(int32_t socket) {
    EventRecord2 (EvtNetTCP_InvalidState, socket, 0);
  }
#else
  #define EvrNetTCP_InvalidState(socket)
#endif

/**
  \brief  Event on TCP send data frame (Op)
  \param  socket        socket handle
  \param  length        data length in bytes
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendData(int32_t socket, uint16_t length) {
    EventRecord2 (EvtNetTCP_SendData, socket, length);
  }
#else
  #define EvrNetTCP_SendData(socket, length)
#endif

/**
  \brief  Event on TCP send control frame (Op)
  \param  socket        socket handle
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendControl(int32_t socket) {
    EventRecord2 (EvtNetTCP_SendControl, socket, 0);
  }
#else
  #define EvrNetTCP_SendControl(socket)
#endif

/**
  \brief  Event on TCP send reset to remote host for unmapped frame (Op)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_SendReset(void) {
    EventRecord2 (EvtNetTCP_SendReset, 0, 0);
  }
#else
  #define EvrNetTCP_SendReset()
#endif

/**
  \brief  Event on TCP parse header options (Op)
  \param  opt_length    length of header options
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ParseHeaderOptions(uint32_t opt_length) {
    EventRecord2 (EvtNetTCP_ParseHeaderOptions, opt_length, 0);
  }
#else
  #define EvrNetTCP_ParseHeaderOptions(opt_length)
#endif

/**
  \brief  Event on TCP header option MSS (maximum segment size) (Op)
  \param  mss           maximum segment size
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_OptionMss(uint32_t mss) {
    EventRecord2 (EvtNetTCP_OptionMss, mss, 0);
  }
#else
  #define EvrNetTCP_OptionMss(mss)
#endif

/**
  \brief  Event on TCP duplicate acknowledge processing (Op)
  \param  dup_acks      number of duplicate acks
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_DuplicateAck(uint32_t dup_acks) {
    EventRecord2 (EvtNetTCP_DuplicateAck, dup_acks, 0);
  }
#else
  #define EvrNetTCP_DuplicateAck(dup_acks)
#endif

/**
  \brief  Event on TCP fast retransmit, received 3 duplicate acks (Op)
  \param  data_length   length of data to fast retransmit
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_FastRetransmit(uint32_t data_length) {
    EventRecord2 (EvtNetTCP_FastRetransmit, data_length, 0);
  }
#else
  #define EvrNetTCP_FastRetransmit(data_length)
#endif

/**
  \brief  Event on TCP data acknowledge processing (Op)
  \param  ack_length    acknowledged data length
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_DataAcked(uint32_t ack_length) {
    EventRecord2 (EvtNetTCP_DataAcked, ack_length, 0);
  }
#else
  #define EvrNetTCP_DataAcked(ack_length)
#endif

/**
  \brief  Event on TCP resend data from transmit queue (Op)
  \param  socket        socket handle
  \param  length        length of the data to resend
  \param  tout          retry timeout in ms
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_ResendData(int32_t socket, uint32_t length, uint32_t tout) {
    EventRecord4 (EvtNetTCP_ResendData, socket, length, tout, 0);
  }
#else
  #define EvrNetTCP_ResendData(socket, length, tout)
#endif

/**
  \brief  Event on TCP map socket failed, wrong TCP flags set (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_MapSocketWrongFlagsSet(void) {
    EventRecord2 (EvtNetTCP_MapSocketWrongFlagsSet, 0, 0);
  }
#else
  #define EvrNetTCP_MapSocketWrongFlagsSet()
#endif

/**
  \brief  Event on TCP map socket failed, SYN-flag not set (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_MapSocketSynNotSet(void) {
    EventRecord2 (EvtNetTCP_MapSocketSynNotSet, 0, 0);
  }
#else
  #define EvrNetTCP_MapSocketSynNotSet()
#endif

/**
  \brief  Event on TCP map socket failed, no listening sockets found (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetTCP_MapSocketNoListenSocket(void) {
    EventRecord2 (EvtNetTCP_MapSocketNoListenSocket, 0, 0);
  }
#else
  #define EvrNetTCP_MapSocketNoListenSocket()
#endif


// NetBSD event identifiers ----------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetBSD_InitSockets               EventID (EventLevelOp,    EvtNetBSD,  0)
#define EvtNetBSD_SocketInvalidParameter    EventID (EventLevelError, EvtNetBSD,  1)
#define EvtNetBSD_SocketAllocated           EventID (EventLevelOp,    EvtNetBSD,  2)
#define EvtNetBSD_NoSocketsAvailable        EventID (EventLevelError, EvtNetBSD,  3)
#define EvtNetBSD_BindSocket                EventID (EventLevelAPI,   EvtNetBSD,  4)
#define EvtNetBSD_BindSocketNotValid        EventID (EventLevelError, EvtNetBSD,  5)
#define EvtNetBSD_BindInvalidParameter      EventID (EventLevelError, EvtNetBSD,  6)
#define EvtNetBSD_BindSocketNotCreated      EventID (EventLevelError, EvtNetBSD,  7)
#define EvtNetBSD_BindPortInUse             EventID (EventLevelError, EvtNetBSD,  8)
#define EvtNetBSD_ShowNetAddressIp4         EventID (EventLevelOp,    EvtNetBSD,  9)
#define EvtNetBSD_ShowNetAddressIp6         EventID (EventLevelOp,    EvtNetBSD, 10)
#define EvtNetBSD_ListenSocket              EventID (EventLevelAPI,   EvtNetBSD, 11)
#define EvtNetBSD_ListenSocketNotValid      EventID (EventLevelError, EvtNetBSD, 12)
#define EvtNetBSD_ListenInvalidParameter    EventID (EventLevelError, EvtNetBSD, 13)
#define EvtNetBSD_ListenSocketNotBound      EventID (EventLevelError, EvtNetBSD, 14)
#define EvtNetBSD_ListenSocketNotStreamType EventID (EventLevelError, EvtNetBSD, 15)
#define EvtNetBSD_ListenBacklogCreateFailed EventID (EventLevelError, EvtNetBSD, 16)
#define EvtNetBSD_AcceptSocket              EventID (EventLevelAPI,   EvtNetBSD, 17)
#define EvtNetBSD_AcceptSocketNotValid      EventID (EventLevelError, EvtNetBSD, 18)
#define EvtNetBSD_AcceptSocketNotListening  EventID (EventLevelError, EvtNetBSD, 19)
#define EvtNetBSD_AcceptSocketNotStreamType EventID (EventLevelError, EvtNetBSD, 20)
#define EvtNetBSD_AcceptSocketLocked        EventID (EventLevelError, EvtNetBSD, 21)
#define EvtNetBSD_AcceptChildSockConnected  EventID (EventLevelOp,    EvtNetBSD, 22)
#define EvtNetBSD_AcceptSocketClosed        EventID (EventLevelError, EvtNetBSD, 23)
#define EvtNetBSD_AcceptSocketKilled        EventID (EventLevelError, EvtNetBSD, 24)
#define EvtNetBSD_ConnectSocket             EventID (EventLevelAPI,   EvtNetBSD, 25)
#define EvtNetBSD_ConnectSocketNotValid     EventID (EventLevelError, EvtNetBSD, 26)
#define EvtNetBSD_ConnectInvalidParameter   EventID (EventLevelError, EvtNetBSD, 27)
#define EvtNetBSD_ConnectSocketLocked       EventID (EventLevelError, EvtNetBSD, 28)
#define EvtNetBSD_ConnectSocketNotCreated   EventID (EventLevelError, EvtNetBSD, 29)
#define EvtNetBSD_ConnectSocketWrongState   EventID (EventLevelError, EvtNetBSD, 30)
#define EvtNetBSD_ConnectDatagramSuccess    EventID (EventLevelOp,    EvtNetBSD, 31)
#define EvtNetBSD_ConnectStreamSuccess      EventID (EventLevelOp,    EvtNetBSD, 32)
#define EvtNetBSD_ConnectSocketClosed       EventID (EventLevelError, EvtNetBSD, 33)
#define EvtNetBSD_ConnectSocketKilled       EventID (EventLevelError, EvtNetBSD, 34)
#define EvtNetBSD_SendSocket                EventID (EventLevelAPI,   EvtNetBSD, 35)
#define EvtNetBSD_SendSocketNotValid        EventID (EventLevelError, EvtNetBSD, 36)
#define EvtNetBSD_SendInvalidParameter      EventID (EventLevelError, EvtNetBSD, 37)
#define EvtNetBSD_SendSocketNotCreated      EventID (EventLevelError, EvtNetBSD, 38)
#define EvtNetBSD_SendSocketLocked          EventID (EventLevelError, EvtNetBSD, 39)
#define EvtNetBSD_SendSocketClosed          EventID (EventLevelError, EvtNetBSD, 40)
#define EvtNetBSD_SendCompleteNonBlocking   EventID (EventLevelOp,    EvtNetBSD, 41)
#define EvtNetBSD_SendSocketKilled          EventID (EventLevelError, EvtNetBSD, 42)
#define EvtNetBSD_SendStreamError           EventID (EventLevelError, EvtNetBSD, 43)
#define EvtNetBSD_SendtoInvalidParameter    EventID (EventLevelError, EvtNetBSD, 44)
#define EvtNetBSD_SendDatagramError         EventID (EventLevelError, EvtNetBSD, 45)
#define EvtNetBSD_SendCompleteBlocking      EventID (EventLevelOp,    EvtNetBSD, 46)
#define EvtNetBSD_RecvSocket                EventID (EventLevelAPI,   EvtNetBSD, 47)
#define EvtNetBSD_RecvSocketNotValid        EventID (EventLevelError, EvtNetBSD, 48)
#define EvtNetBSD_RecvInvalidParameter      EventID (EventLevelError, EvtNetBSD, 49)
#define EvtNetBSD_RecvSocketNotCreated      EventID (EventLevelError, EvtNetBSD, 50)
#define EvtNetBSD_RecvSocketNotConnected    EventID (EventLevelError, EvtNetBSD, 51)
#define EvtNetBSD_RecvSocketWrongState      EventID (EventLevelError, EvtNetBSD, 52)
#define EvtNetBSD_RecvSocketLocked          EventID (EventLevelError, EvtNetBSD, 53)
#define EvtNetBSD_RecvSocketClosed          EventID (EventLevelError, EvtNetBSD, 54)
#define EvtNetBSD_RecvTimeout               EventID (EventLevelOp,    EvtNetBSD, 55)
#define EvtNetBSD_RecvSocketKilled          EventID (EventLevelError, EvtNetBSD, 56)
#define EvtNetBSD_RecvQueueFree             EventID (EventLevelOp,    EvtNetBSD, 57)
#define EvtNetBSD_RecvComplete              EventID (EventLevelOp,    EvtNetBSD, 58)
#define EvtNetBSD_Closesocket               EventID (EventLevelAPI,   EvtNetBSD, 59)
#define EvtNetBSD_CloseSocketNotValid       EventID (EventLevelError, EvtNetBSD, 60)
#define EvtNetBSD_Getpeername               EventID (EventLevelAPI,   EvtNetBSD, 61)
#define EvtNetBSD_GetpeerSocketNotValid     EventID (EventLevelError, EvtNetBSD, 62)
#define EvtNetBSD_GetpeerInvalidParameter   EventID (EventLevelError, EvtNetBSD, 63)
#define EvtNetBSD_GetpeerSocketNotCreated   EventID (EventLevelError, EvtNetBSD, 64)
#define EvtNetBSD_Getsockname               EventID (EventLevelAPI,   EvtNetBSD, 65)
#define EvtNetBSD_GetsockSocketNotValid     EventID (EventLevelError, EvtNetBSD, 66)
#define EvtNetBSD_GetsockInvalidParameter   EventID (EventLevelError, EvtNetBSD, 67)
#define EvtNetBSD_GetsockSocketNotCreated   EventID (EventLevelError, EvtNetBSD, 68)
#define EvtNetBSD_Setsockopt                EventID (EventLevelAPI,   EvtNetBSD, 69)
#define EvtNetBSD_SetoptSocketNotValid      EventID (EventLevelError, EvtNetBSD, 70)
#define EvtNetBSD_SetoptInvalidParameter    EventID (EventLevelError, EvtNetBSD, 71)
#define EvtNetBSD_SetoptSocketNotCreated    EventID (EventLevelError, EvtNetBSD, 72)
#define EvtNetBSD_SetoptKeepAlive           EventID (EventLevelOp,    EvtNetBSD, 73)
#define EvtNetBSD_SetoptRecvTimeout         EventID (EventLevelOp,    EvtNetBSD, 74)
#define EvtNetBSD_SetoptTos                 EventID (EventLevelOp,    EvtNetBSD, 75)
#define EvtNetBSD_SetoptTtl                 EventID (EventLevelOp,    EvtNetBSD, 76)
#define EvtNetBSD_SetoptTclass              EventID (EventLevelOp,    EvtNetBSD, 77)
#define EvtNetBSD_SetoptHopLimit            EventID (EventLevelOp,    EvtNetBSD, 78)
#define EvtNetBSD_Ioctlsocket               EventID (EventLevelAPI,   EvtNetBSD, 79)
#define EvtNetBSD_IoctlSocketNotValid       EventID (EventLevelError, EvtNetBSD, 80)
#define EvtNetBSD_IoctlInvalidParameter     EventID (EventLevelError, EvtNetBSD, 81)
#define EvtNetBSD_IoctlSocketNotCreated     EventID (EventLevelError, EvtNetBSD, 82)
#define EvtNetBSD_IoctlSocketNotStreamType  EventID (EventLevelError, EvtNetBSD, 83)
#define EvtNetBSD_IoctlNonBlocking          EventID (EventLevelOp,    EvtNetBSD, 84)
#define EvtNetBSD_IoctlDelayAck             EventID (EventLevelOp,    EvtNetBSD, 85)
#define EvtNetBSD_IoctlKeepAlive            EventID (EventLevelOp,    EvtNetBSD, 86)
#define EvtNetBSD_IoctlFlowControl          EventID (EventLevelOp,    EvtNetBSD, 87)
#define EvtNetBSD_CbfuncTcpEvent            EventID (EventLevelOp,    EvtNetBSD, 88)
#define EvtNetBSD_CbfuncTcpQueueAdd         EventID (EventLevelOp,    EvtNetBSD, 89)
#define EvtNetBSD_CbfuncTcpNoMemory         EventID (EventLevelError, EvtNetBSD, 90)
#define EvtNetBSD_CbfuncUdpQueueAdd         EventID (EventLevelOp,    EvtNetBSD, 91)
#define EvtNetBSD_CbfuncUdpDumpData         EventID (EventLevelError, EvtNetBSD, 92)
#endif

/**
  \brief  Event on BSD socket API initialize (Op)
  \param  num_socks     number of available BSD sockets
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_InitSockets(uint32_t num_socks) {
    EventRecord2 (EvtNetBSD_InitSockets, num_socks, 0);
  }
#else
  #define EvrNetBSD_InitSockets(num_socks)
#endif

/**
  \brief  Event on BSD \ref socket failed, invalid parameter (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SocketInvalidParameter(void) {
    EventRecord2 (EvtNetBSD_SocketInvalidParameter, 0, 0);
  }
#else
  #define EvrNetBSD_SocketInvalidParameter()
#endif

/**
  \brief  Event on BSD free socket allocated (Op)
  \param  sock          allocated socket descriptor
  \param  type          socket type
                         - 1: SOCK_STREAM
                         - 2: SOCK_DGRAM
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SocketAllocated(int32_t sock, int32_t type) {
    EventRecord2 (EvtNetBSD_SocketAllocated, sock, type);
  }
#else
  #define EvrNetBSD_SocketAllocated(sock, type)
#endif

/**
  \brief  Event on BSD \ref socket failed, no free sockets available (Error)
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_NoSocketsAvailable(void) {
    EventRecord2 (EvtNetBSD_NoSocketsAvailable, 0, 0);
  }
#else
  #define EvrNetBSD_NoSocketsAvailable()
#endif

/**
  \brief  Event on BSD \ref bind socket (API)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_BindSocket(int32_t sock) {
    EventRecord2 (EvtNetBSD_BindSocket, sock, 0);
  }
#else
  #define EvrNetBSD_BindSocket(sock)
#endif

/**
  \brief  Event on BSD \ref bind failed, socket not valid (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_BindSocketNotValid(int32_t sock) {
    EventRecord2 (EvtNetBSD_BindSocketNotValid, sock, 0);
  }
#else
  #define EvrNetBSD_BindSocketNotValid(sock)
#endif

/**
  \brief  Event on BSD \ref bind failed, invalid parameter (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_BindInvalidParameter(int32_t sock) {
    EventRecord2 (EvtNetBSD_BindInvalidParameter, sock, 0);
  }
#else
  #define EvrNetBSD_BindInvalidParameter(sock)
#endif

/**
  \brief  Event on BSD \ref bind failed, socket not created (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_BindSocketNotCreated(int32_t sock) {
    EventRecord2 (EvtNetBSD_BindSocketNotCreated, sock, 0);
  }
#else
  #define EvrNetBSD_BindSocketNotCreated(sock)
#endif

/**
  \brief  Event on BSD \ref bind failed, port in use (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_BindPortInUse(int32_t sock) {
    EventRecord2 (EvtNetBSD_BindPortInUse, sock, 0);
  }
#else
  #define EvrNetBSD_BindPortInUse(sock)
#endif

/**
  \brief  Event on BSD display net address IPv4 (Op)
  \param  net_address   pointer to \ref NET_ADDR4 address structure (8 bytes)
  \note   Sends reduced size of net address structure with IPv4 address only.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ShowNetAddressIp4(const void *net_address) {
    EventRecordData (EvtNetBSD_ShowNetAddressIp4, net_address, 8);
  }
#else
  #define EvrNetBSD_ShowNetAddressIp4(net_address)
#endif

/**
  \brief  Event on BSD display net address IPv6 (Op)
  \param  net_address   pointer to \ref NET_ADDR address structure (20 bytes)
  \note   Sends full size of net address structure with IPv6 address only.
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ShowNetAddressIp6(const void *net_address) {
    EventRecordData (EvtNetBSD_ShowNetAddressIp6, net_address, 20);
  }
#else
  #define EvrNetBSD_ShowNetAddressIp6(net_address)
#endif

/**
  \brief  Event on BSD \ref listen socket (API)
  \param  sock          socket descriptor
  \param  backlog       max number of queued connection requests
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ListenSocket(int32_t sock, int32_t backlog) {
    EventRecord2 (EvtNetBSD_ListenSocket, sock, backlog);
  }
#else
  #define EvrNetBSD_ListenSocket(sock, backlog)
#endif

/**
  \brief  Event on BSD \ref listen failed, socket not valid (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ListenSocketNotValid(int32_t sock) {
    EventRecord2 (EvtNetBSD_ListenSocketNotValid, sock, 0);
  }
#else
  #define EvrNetBSD_ListenSocketNotValid(sock)
#endif

/**
  \brief  Event on BSD \ref listen failed, invalid parameter (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ListenInvalidParameter(int32_t sock) {
    EventRecord2 (EvtNetBSD_ListenInvalidParameter, sock, 0);
  }
#else
  #define EvrNetBSD_ListenInvalidParameter(sock)
#endif

/**
  \brief  Event on BSD \ref listen failed, socket not bound (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ListenSocketNotBound(int32_t sock) {
    EventRecord2 (EvtNetBSD_ListenSocketNotBound, sock, 0);
  }
#else
  #define EvrNetBSD_ListenSocketNotBound(sock)
#endif

/**
  \brief  Event on BSD \ref listen failed, socket not stream type (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ListenSocketNotStreamType(int32_t sock) {
    EventRecord2 (EvtNetBSD_ListenSocketNotStreamType, sock, 0);
  }
#else
  #define EvrNetBSD_ListenSocketNotStreamType(sock)
#endif

/**
  \brief  Event on BSD \ref listen failed, creating socket backlog failed (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ListenBacklogCreateFailed(int32_t sock) {
    EventRecord2 (EvtNetBSD_ListenBacklogCreateFailed, sock, 0);
  }
#else
  #define EvrNetBSD_ListenBacklogCreateFailed(sock)
#endif

/**
  \brief  Event on BSD \ref accept socket (API)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_AcceptSocket(int32_t sock) {
    EventRecord2 (EvtNetBSD_AcceptSocket, sock, 0);
  }
#else
  #define EvrNetBSD_AcceptSocket(sock)
#endif

/**
  \brief  Event on BSD \ref accept failed, socket not valid (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_AcceptSocketNotValid(int32_t sock) {
    EventRecord2 (EvtNetBSD_AcceptSocketNotValid, sock, 0);
  }
#else
  #define EvrNetBSD_AcceptSocketNotValid(sock)
#endif

/**
  \brief  Event on BSD \ref accept failed, socket not listening (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_AcceptSocketNotListening(int32_t sock) {
    EventRecord2 (EvtNetBSD_AcceptSocketNotListening, sock, 0);
  }
#else
  #define EvrNetBSD_AcceptSocketNotListening(sock)
#endif

/**
  \brief  Event on BSD \ref accept failed, socket not stream type (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_AcceptSocketNotStreamType(int32_t sock) {
    EventRecord2 (EvtNetBSD_AcceptSocketNotStreamType, sock, 0);
  }
#else
  #define EvrNetBSD_AcceptSocketNotStreamType(sock)
#endif

/**
  \brief  Event on BSD \ref accept failed, socket locked from other thread (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_AcceptSocketLocked(int32_t sock) {
    EventRecord2 (EvtNetBSD_AcceptSocketLocked, sock, 0);
  }
#else
  #define EvrNetBSD_AcceptSocketLocked(sock)
#endif

/**
  \brief  Event on BSD \ref accept success, child socket connected (Op)
  \param  child_sock    child socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_AcceptChildSockConnected(int32_t child_sock) {
    EventRecord2 (EvtNetBSD_AcceptChildSockConnected, child_sock, 0);
  }
#else
  #define EvrNetBSD_AcceptChildSockConnected(child_sock)
#endif

/**
  \brief  Event on BSD \ref accept failed, socket has closed (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_AcceptSocketClosed(int32_t sock) {
    EventRecord2 (EvtNetBSD_AcceptSocketClosed, sock, 0);
  }
#else
  #define EvrNetBSD_AcceptSocketClosed(sock)
#endif

/**
  \brief  Event on BSD \ref accept failed, socket killed locally (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_AcceptSocketKilled(int32_t sock) {
    EventRecord2 (EvtNetBSD_AcceptSocketKilled, sock, 0);
  }
#else
  #define EvrNetBSD_AcceptSocketKilled(sock)
#endif

/**
  \brief  Event on BSD \ref connect socket (API)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ConnectSocket(int32_t sock) {
    EventRecord2 (EvtNetBSD_ConnectSocket, sock, 0);
  }
#else
  #define EvrNetBSD_ConnectSocket(sock)
#endif

/**
  \brief  Event on BSD \ref connect failed, socket not valid (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ConnectSocketNotValid(int32_t sock) {
    EventRecord2 (EvtNetBSD_ConnectSocketNotValid, sock, 0);
  }
#else
  #define EvrNetBSD_ConnectSocketNotValid(sock)
#endif

/**
  \brief  Event on BSD \ref connect failed, invalid parameter (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ConnectInvalidParameter(int32_t sock) {
    EventRecord2 (EvtNetBSD_ConnectInvalidParameter, sock, 0);
  }
#else
  #define EvrNetBSD_ConnectInvalidParameter(sock)
#endif

/**
  \brief  Event on BSD \ref connect failed, socket locked from other thread (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ConnectSocketLocked(int32_t sock) {
    EventRecord2 (EvtNetBSD_ConnectSocketLocked, sock, 0);
  }
#else
  #define EvrNetBSD_ConnectSocketLocked(sock)
#endif

/**
  \brief  Event on BSD \ref connect failed, socket not created (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ConnectSocketNotCreated(int32_t sock) {
    EventRecord2 (EvtNetBSD_ConnectSocketNotCreated, sock, 0);
  }
#else
  #define EvrNetBSD_ConnectSocketNotCreated(sock)
#endif

/**
  \brief  Event on BSD \ref connect failed, wrong socket state (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ConnectSocketWrongState(int32_t sock) {
    EventRecord2 (EvtNetBSD_ConnectSocketWrongState, sock, 0);
  }
#else
  #define EvrNetBSD_ConnectSocketWrongState(sock)
#endif

/**
  \brief  Event on BSD \ref connect success, datagram socket connected (Op)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ConnectDatagramSuccess(int32_t sock) {
    EventRecord2 (EvtNetBSD_ConnectDatagramSuccess, sock, 0);
  }
#else
  #define EvrNetBSD_ConnectDatagramSuccess(sock)
#endif

/**
  \brief  Event on BSD \ref connect success, stream socket connected (Op)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ConnectStreamSuccess(int32_t sock) {
    EventRecord2 (EvtNetBSD_ConnectStreamSuccess, sock, 0);
  }
#else
  #define EvrNetBSD_ConnectStreamSuccess(sock)
#endif

/**
  \brief  Event on BSD \ref connect failed, socket has closed (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ConnectSocketClosed(int32_t sock) {
    EventRecord2 (EvtNetBSD_ConnectSocketClosed, sock, 0);
  }
#else
  #define EvrNetBSD_ConnectSocketClosed(sock)
#endif

/**
  \brief  Event on BSD \ref connect failed, socket killed locally (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_ConnectSocketKilled(int32_t sock) {
    EventRecord2 (EvtNetBSD_ConnectSocketKilled, sock, 0);
  }
#else
  #define EvrNetBSD_ConnectSocketKilled(sock)
#endif

/**
  \brief  Event on BSD \ref send socket (API)
  \param  sock          socket descriptor
  \param  length        length of data to send
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SendSocket(int32_t sock, int32_t length) {
    EventRecord2 (EvtNetBSD_SendSocket, sock, length);
  }
#else
  #define EvrNetBSD_SendSocket(sock, length)
#endif

/**
  \brief  Event on BSD \ref send failed, socket not valid (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SendSocketNotValid(int32_t sock) {
    EventRecord2 (EvtNetBSD_SendSocketNotValid, sock, 0);
  }
#else
  #define EvrNetBSD_SendSocketNotValid(sock)
#endif

/**
  \brief  Event on BSD \ref send failed, invalid parameter (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SendInvalidParameter(int32_t sock) {
    EventRecord2 (EvtNetBSD_SendInvalidParameter, sock, 0);
  }
#else
  #define EvrNetBSD_SendInvalidParameter(sock)
#endif

/**
  \brief  Event on BSD \ref send failed, socket not created (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SendSocketNotCreated(int32_t sock) {
    EventRecord2 (EvtNetBSD_SendSocketNotCreated, sock, 0);
  }
#else
  #define EvrNetBSD_SendSocketNotCreated(sock)
#endif

/**
  \brief  Event on BSD \ref send failed, socket locked from other thread (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SendSocketLocked(int32_t sock) {
    EventRecord2 (EvtNetBSD_SendSocketLocked, sock, 0);
  }
#else
  #define EvrNetBSD_SendSocketLocked(sock)
#endif

/**
  \brief  Event on BSD \ref send failed, socket has closed (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SendSocketClosed(int32_t sock) {
    EventRecord2 (EvtNetBSD_SendSocketClosed, sock, 0);
  }
#else
  #define EvrNetBSD_SendSocketClosed(sock)
#endif

/**
  \brief  Event on BSD \ref send complete non-blocking mode (Op)
  \param  num           number of bytes successfully sent
  \param  length        length of data requested to send
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SendCompleteNonBlocking(int32_t num, int32_t length) {
    EventRecord2 (EvtNetBSD_SendCompleteNonBlocking, num, length);
  }
#else
  #define EvrNetBSD_SendCompleteNonBlocking(num, length)
#endif

/**
  \brief  Event on BSD \ref send failed, socket killed locally (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SendSocketKilled(int32_t sock) {
    EventRecord2 (EvtNetBSD_SendSocketKilled, sock, 0);
  }
#else
  #define EvrNetBSD_SendSocketKilled(sock)
#endif

/**
  \brief  Event on BSD \ref send failed, stream socket unspecified error (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SendStreamError(int32_t sock) {
    EventRecord2 (EvtNetBSD_SendStreamError, sock, 0);
  }
#else
  #define EvrNetBSD_SendStreamError(sock)
#endif

/**
  \brief  Event on BSD \ref sendto failed, invalid parameter (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SendtoInvalidParameter(int32_t sock) {
    EventRecord2 (EvtNetBSD_SendtoInvalidParameter, sock, 0);
  }
#else
  #define EvrNetBSD_SendtoInvalidParameter(sock)
#endif

/**
  \brief  Event on BSD \ref send failed, datagram socket unspecified error (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SendDatagramError(int32_t sock) {
    EventRecord2 (EvtNetBSD_SendDatagramError, sock, 0);
  }
#else
  #define EvrNetBSD_SendDatagramError(sock)
#endif

/**
  \brief  Event on BSD \ref send complete blocking mode (Op)
  \param  num           number of bytes successfully sent
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SendCompleteBlocking(int32_t num) {
    EventRecord2 (EvtNetBSD_SendCompleteBlocking, num, 0);
  }
#else
  #define EvrNetBSD_SendCompleteBlocking(num)
#endif

/**
  \brief  Event on BSD \ref recv socket (API)
  \param  sock          socket descriptor
  \param  length        length of data to receive
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_RecvSocket(int32_t sock, int32_t length) {
    EventRecord2 (EvtNetBSD_RecvSocket, sock, length);
  }
#else
  #define EvrNetBSD_RecvSocket(sock, length)
#endif

/**
  \brief  Event on BSD \ref recv failed, socket not valid (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_RecvSocketNotValid(int32_t sock) {
    EventRecord2 (EvtNetBSD_RecvSocketNotValid, sock, 0);
  }
#else
  #define EvrNetBSD_RecvSocketNotValid(sock)
#endif

/**
  \brief  Event on BSD \ref recv failed, invalid parameter (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_RecvInvalidParameter(int32_t sock) {
    EventRecord2 (EvtNetBSD_RecvInvalidParameter, sock, 0);
  }
#else
  #define EvrNetBSD_RecvInvalidParameter(sock)
#endif

/**
  \brief  Event on BSD \ref recv failed, socket not created (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_RecvSocketNotCreated(int32_t sock) {
    EventRecord2 (EvtNetBSD_RecvSocketNotCreated, sock, 0);
  }
#else
  #define EvrNetBSD_RecvSocketNotCreated(sock)
#endif

/**
  \brief  Event on BSD \ref recv failed, socket not connected (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_RecvSocketNotConnected(int32_t sock) {
    EventRecord2 (EvtNetBSD_RecvSocketNotConnected, sock, 0);
  }
#else
  #define EvrNetBSD_RecvSocketNotConnected(sock)
#endif

/**
  \brief  Event on BSD \ref recv failed, wrong socket state (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_RecvSocketWrongState(int32_t sock) {
    EventRecord2 (EvtNetBSD_RecvSocketWrongState, sock, 0);
  }
#else
  #define EvrNetBSD_RecvSocketWrongState(sock)
#endif

/**
  \brief  Event on BSD \ref recv failed, socket locked from other thread (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_RecvSocketLocked(int32_t sock) {
    EventRecord2 (EvtNetBSD_RecvSocketLocked, sock, 0);
  }
#else
  #define EvrNetBSD_RecvSocketLocked(sock)
#endif

/**
  \brief  Event on BSD \ref recv failed, socket has closed (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_RecvSocketClosed(int32_t sock) {
    EventRecord2 (EvtNetBSD_RecvSocketClosed, sock, 0);
  }
#else
  #define EvrNetBSD_RecvSocketClosed(sock)
#endif

/**
  \brief  Event on BSD \ref recv timeout (Op)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_RecvTimeout(int32_t sock) {
    EventRecord2 (EvtNetBSD_RecvTimeout, sock, 0);
  }
#else
  #define EvrNetBSD_RecvTimeout(sock)
#endif

/**
  \brief  Event on BSD \ref recv failed, socket killed locally (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_RecvSocketKilled(int32_t sock) {
    EventRecord2 (EvtNetBSD_RecvSocketKilled, sock, 0);
  }
#else
  #define EvrNetBSD_RecvSocketKilled(sock)
#endif

/**
  \brief  Event on BSD \ref recv queue free (Op)
  \param  sock          socket descriptor
  \param  length        length of data to release
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_RecvQueueFree(int32_t sock, int32_t length) {
    EventRecord2 (EvtNetBSD_RecvQueueFree, sock, length);
  }
#else
  #define EvrNetBSD_RecvQueueFree(sock, length)
#endif

/**
  \brief  Event on BSD \ref recv complete (Op)
  \param  sock          socket descriptor
  \param  length        length of data received
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_RecvComplete(int32_t sock, int32_t length) {
    EventRecord2 (EvtNetBSD_RecvComplete, sock, length);
  }
#else
  #define EvrNetBSD_RecvComplete(sock, length)
#endif

/**
  \brief  Event on BSD \ref closesocket (API)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_Closesocket(int32_t sock) {
    EventRecord2 (EvtNetBSD_Closesocket, sock, 0);
  }
#else
  #define EvrNetBSD_Closesocket(sock)
#endif

/**
  \brief  Event on BSD \ref closesocket failed, socket not valid (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_CloseSocketNotValid(int32_t sock) {
    EventRecord2 (EvtNetBSD_CloseSocketNotValid, sock, 0);
  }
#else
  #define EvrNetBSD_CloseSocketNotValid(sock)
#endif

/**
  \brief  Event on BSD \ref getpeername (API)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_Getpeername(int32_t sock) {
    EventRecord2 (EvtNetBSD_Getpeername, sock, 0);
  }
#else
  #define EvrNetBSD_Getpeername(sock)
#endif

/**
  \brief  Event on BSD \ref getpeername failed, socket not valid (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_GetpeerSocketNotValid(int32_t sock) {
    EventRecord2 (EvtNetBSD_GetpeerSocketNotValid, sock, 0);
  }
#else
  #define EvrNetBSD_GetpeerSocketNotValid(sock)
#endif

/**
  \brief  Event on BSD \ref getpeername failed, invalid parameter (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_GetpeerInvalidParameter(int32_t sock) {
    EventRecord2 (EvtNetBSD_GetpeerInvalidParameter, sock, 0);
  }
#else
  #define EvrNetBSD_GetpeerInvalidParameter(sock)
#endif

/**
  \brief  Event on BSD \ref getpeername failed, socket not created (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_GetpeerSocketNotCreated(int32_t sock) {
    EventRecord2 (EvtNetBSD_GetpeerSocketNotCreated, sock, 0);
  }
#else
  #define EvrNetBSD_GetpeerSocketNotCreated(sock)
#endif

/**
  \brief  Event on BSD \ref getsockname (API)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_Getsockname(int32_t sock) {
    EventRecord2 (EvtNetBSD_Getsockname, sock, 0);
  }
#else
  #define EvrNetBSD_Getsockname(sock)
#endif

/**
  \brief  Event on BSD \ref getsockname failed, socket not valid (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_GetsockSocketNotValid(int32_t sock) {
    EventRecord2 (EvtNetBSD_GetsockSocketNotValid, sock, 0);
  }
#else
  #define EvrNetBSD_GetsockSocketNotValid(sock)
#endif

/**
  \brief  Event on BSD \ref getsockname failed, invalid parameter (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_GetsockInvalidParameter(int32_t sock) {
    EventRecord2 (EvtNetBSD_GetsockInvalidParameter, sock, 0);
  }
#else
  #define EvrNetBSD_GetsockInvalidParameter(sock)
#endif

/**
  \brief  Event on BSD \ref getsockname failed, socket not created (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_GetsockSocketNotCreated(int32_t sock) {
    EventRecord2 (EvtNetBSD_GetsockSocketNotCreated, sock, 0);
  }
#else
  #define EvrNetBSD_GetsockSocketNotCreated(sock)
#endif

/**
  \brief  Event on BSD \ref setsockopt (API)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_Setsockopt(int32_t sock) {
    EventRecord2 (EvtNetBSD_Setsockopt, sock, 0);
  }
#else
  #define EvrNetBSD_Setsockopt(sock)
#endif

/**
  \brief  Event on BSD \ref setsockopt failed, socket not valid (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SetoptSocketNotValid(int32_t sock) {
    EventRecord2 (EvtNetBSD_SetoptSocketNotValid, sock, 0);
  }
#else
  #define EvrNetBSD_SetoptSocketNotValid(sock)
#endif

/**
  \brief  Event on BSD \ref setsockopt failed, invalid parameter (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SetoptInvalidParameter(int32_t sock) {
    EventRecord2 (EvtNetBSD_SetoptInvalidParameter, sock, 0);
  }
#else
  #define EvrNetBSD_SetoptInvalidParameter(sock)
#endif

/**
  \brief  Event on BSD \ref setsockopt failed, socket not created (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SetoptSocketNotCreated(int32_t sock) {
    EventRecord2 (EvtNetBSD_SetoptSocketNotCreated, sock, 0);
  }
#else
  #define EvrNetBSD_SetoptSocketNotCreated(sock)
#endif

/**
  \brief  Event on BSD \ref setsockopt keep-alive option (Op)
  \param  enable        keep-alive state
                         - 0: disable
                         - 1: enable
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SetoptKeepAlive(int32_t enable) {
    EventRecord2 (EvtNetBSD_SetoptKeepAlive, enable, 0);
  }
#else
  #define EvrNetBSD_SetoptKeepAlive(enable)
#endif

/**
  \brief  Event on BSD \ref setsockopt receive timeout (Op)
  \param  timeout       receive timeout in ms
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SetoptRecvTimeout(uint32_t timeout) {
    EventRecord2 (EvtNetBSD_SetoptRecvTimeout, timeout, 0);
  }
#else
  #define EvrNetBSD_SetoptRecvTimeout(timeout)
#endif

/**
  \brief  Event on BSD \ref setsockopt TOS for IPv4 (Op)
  \param  ip4_tos       type of service value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SetoptTos(uint8_t ip4_tos) {
    EventRecord2 (EvtNetBSD_SetoptTos, ip4_tos, 0);
  }
#else
  #define EvrNetBSD_SetoptTos(ip4_tos)
#endif

/**
  \brief  Event on BSD \ref setsockopt TTL for IPv4 (Op)
  \param  ip4_ttl       time to live value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SetoptTtl(uint8_t ip4_ttl) {
    EventRecord2 (EvtNetBSD_SetoptTtl, ip4_ttl, 0);
  }
#else
  #define EvrNetBSD_SetoptTtl(ip4_ttl)
#endif

/**
  \brief  Event on BSD \ref setsockopt Traffic Class for IPv6 (Op)
  \param  ip6_tclass    traffic class value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SetoptTclass(uint8_t ip6_tclass) {
    EventRecord2 (EvtNetBSD_SetoptTclass, ip6_tclass, 0);
  }
#else
  #define EvrNetBSD_SetoptTclass(ip6_tclass)
#endif

/**
  \brief  Event on BSD \ref setsockopt Hop Limit for IPv6 (Op)
  \param  ip6_hoplimit  hop limit value
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_SetoptHopLimit(uint8_t ip6_hoplimit) {
    EventRecord2 (EvtNetBSD_SetoptHopLimit, ip6_hoplimit, 0);
  }
#else
  #define EvrNetBSD_SetoptHopLimit(ip6_hoplimit)
#endif

/**
  \brief  Event on BSD \ref ioctlsocket (API)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_Ioctlsocket(int32_t sock) {
    EventRecord2 (EvtNetBSD_Ioctlsocket, sock, 0);
  }
#else
  #define EvrNetBSD_Ioctlsocket(sock)
#endif

/**
  \brief  Event on BSD \ref ioctlsocket failed, socket not valid (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_IoctlSocketNotValid(int32_t sock) {
    EventRecord2 (EvtNetBSD_IoctlSocketNotValid, sock, 0);
  }
#else
  #define EvrNetBSD_IoctlSocketNotValid(sock)
#endif

/**
  \brief  Event on BSD \ref ioctlsocket failed, invalid parameter (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_IoctlInvalidParameter(int32_t sock) {
    EventRecord2 (EvtNetBSD_IoctlInvalidParameter, sock, 0);
  }
#else
  #define EvrNetBSD_IoctlInvalidParameter(sock)
#endif

/**
  \brief  Event on BSD \ref ioctlsocket failed, socket not created (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_IoctlSocketNotCreated(int32_t sock) {
    EventRecord2 (EvtNetBSD_IoctlSocketNotCreated, sock, 0);
  }
#else
  #define EvrNetBSD_IoctlSocketNotCreated(sock)
#endif

/**
  \brief  Event on BSD \ref ioctlsocket failed, socket not stream type (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_IoctlSocketNotStreamType(int32_t sock) {
    EventRecord2 (EvtNetBSD_IoctlSocketNotStreamType, sock, 0);
  }
#else
  #define EvrNetBSD_IoctlSocketNotStreamType(sock)
#endif

/**
  \brief  Event on BSD \ref ioctlsocket enable non-blocking mode (Op)
  \param  enable        non-blocking state
                         - 0: disable
                         - 1: enable
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_IoctlNonBlocking(int32_t enable) {
    if (enable) enable = 1;
    EventRecord2 (EvtNetBSD_IoctlNonBlocking, enable, 0);
  }
#else
  #define EvrNetBSD_IoctlNonBlocking(enable)
#endif

/**
  \brief  Event on BSD \ref ioctlsocket enable TCP delay-ack mode (Op)
  \param  enable        delay-ack state
                         - 0: disable
                         - 1: enable
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_IoctlDelayAck(int32_t enable) {
    if (enable) enable = 1;
    EventRecord2 (EvtNetBSD_IoctlDelayAck, enable, 0);
  }
#else
  #define EvrNetBSD_IoctlDelayAck(enable)
#endif

/**
  \brief  Event on BSD \ref ioctlsocket enable TCP keep-alive mode (Op)
  \param  enable        keep-alive state
                         - 0: disable
                         - 1: enable
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_IoctlKeepAlive(int32_t enable) {
    if (enable) enable = 1;
    EventRecord2 (EvtNetBSD_IoctlKeepAlive, enable, 0);
  }
#else
  #define EvrNetBSD_IoctlKeepAlive(enable)
#endif

/**
  \brief  Event on BSD \ref ioctlsocket enable TCP flow-control mode (Op)
  \param  enable        flow-control state
                         - 0: disable
                         - 1: enable
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_IoctlFlowControl(int32_t enable) {
    if (enable) enable = 1;
    EventRecord2 (EvtNetBSD_IoctlFlowControl, enable, 0);
  }
#else
  #define EvrNetBSD_IoctlFlowControl(enable)
#endif

/**
  \brief  Event on BSD callback TCP function events (Op)
  \param  sock          socket descriptor
  \param  tcp_event     TCP socket event
                         - 0: netTCP_EventConnect
                         - 1: netTCP_EventEstablished
                         - 2: netTCP_EventClosed
                         - 3: netTCP_EventAborted
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_CbfuncTcpEvent(int32_t sock, int32_t tcp_event) {
    EventRecord2 (EvtNetBSD_CbfuncTcpEvent, sock, tcp_event);
  }
#else
  #define EvrNetBSD_CbfuncTcpEvent(sock, tcp_event)
#endif

/**
  \brief  Event on BSD callback TCP data received (Op)
  \param  sock          socket descriptor
  \param  length        length of data received
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_CbfuncTcpQueueAdd(int32_t sock, uint32_t length) {
    EventRecord2 (EvtNetBSD_CbfuncTcpQueueAdd, sock, length);
  }
#else
  #define EvrNetBSD_CbfuncTcpQueueAdd(sock, length)
#endif

/**
  \brief  Event on BSD callback no memory for TCP data (Error)
  \param  sock          socket descriptor
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_CbfuncTcpNoMemory(int32_t sock) {
    EventRecord2 (EvtNetBSD_CbfuncTcpNoMemory, sock, 0);
  }
#else
  #define EvrNetBSD_CbfuncTcpNoMemory(enable)
#endif

/**
  \brief  Event on BSD callback UDP data received (Op)
  \param  sock          socket descriptor
  \param  length        length of data received
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_CbfuncUdpQueueAdd(int32_t sock, uint32_t length) {
    EventRecord2 (EvtNetBSD_CbfuncUdpQueueAdd, sock, length);
  }
#else
  #define EvrNetBSD_CbfuncUdpQueueAdd(sock, length)
#endif

/**
  \brief  Event on BSD callback no memory for UDP data (Error)
  \param  sock          socket descriptor
  \param  length        length of dumped data
 */
#ifdef DEBUG_EVR
  __STATIC_INLINE void EvrNetBSD_CbfuncUdpDumpData(int32_t sock, uint32_t length) {
    EventRecord2 (EvtNetBSD_CbfuncUdpDumpData, sock, length);
  }
#else
  #define EvrNetBSD_CbfuncUdpDumpData(sock, length)
#endif


// NetHTTP event identifiers ---------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetHTTP_InitServer               EventID (EventLevelOp,    EvtNetHTTP,  0)
#endif


// NetFTPs event identifiers ---------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetFTPs_InitServer               EventID (EventLevelOp,    EvtNetFTPs,  0)
#endif


// NetFTPc event identifiers ---------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetFTPc_InitClient               EventID (EventLevelOp,    EvtNetFTPc,  0)
#endif


// NetTeln event identifiers ---------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetTeln_InitServer               EventID (EventLevelOp,    EvtNetTeln,  0)
#endif


// NetTFTPs event identifiers --------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetTFTPs_InitServer              EventID (EventLevelOp,    EvtNetTFTPs,  0)
#endif


// NetTFTPc event identifiers --------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetTFTPc_InitClient              EventID (EventLevelOp,    EvtNetTFTPc,  0)
#endif


// NetSMTP event identifiers ---------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetSMTP_InitClient               EventID (EventLevelOp,    EvtNetSMTP,  0)
#endif


// NetDNS event identifiers ----------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetDNS_InitClient                EventID (EventLevelOp,    EvtNetDNS,  0)
#endif


// NetSNMP event identifiers ---------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetSNMP_InitAgent                EventID (EventLevelOp,    EvtNetSNMP,  0)
#endif


// NetSNTP event identifiers ---------------------------------------------------
#ifdef DEBUG_EVR
#define EvtNetSNTP_InitClient               EventID (EventLevelOp,    EvtNetSNTP,  0)
#endif
